IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfDocumentContactUpdate')
	BEGIN
		PRINT 'Dropping Procedure adfDocumentContactUpdate'
		DROP  Procedure  adfDocumentContactUpdate
	END

GO

PRINT 'Creating Procedure adfDocumentContactUpdate'
GO
/******************************************************************************
**		File: 
**		Name: adfDocumentContactUpdate
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		12.04.13	SOV				 OpenXml  Xml
*******************************************************************************/
CREATE Procedure adfDocumentContactUpdate
	@DocumentID TIdentifier,
	@DocumentClass TClass,
	@Xml XML
AS
	DECLARE @result INT

	SET NOCOUNT ON

	BEGIN TRANSACTION
	
	DELETE [DocumentContact] WHERE [DocumentID] = @DocumentID AND [DocumentClass] = @DocumentClass
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	INSERT [DocumentContact]
		([DocumentID], [DocumentClass], [BusinessCardID], [BusinessCardClass])
	SELECT DISTINCT
		@DocumentID,
		@DocumentClass,
		[Contactlist].[ID],
		[Contactlist].[Class]
	FROM
	(
		SELECT 
			T.c.value('ID[1]', 'int') AS [ID],
			T.c.value('Class[1]', 'smallint') AS [Class]
		FROM 
			@Xml.nodes('/List/Item') as T(c) 
	) AS [ContactList] 		
		INNER JOIN [Document] 
			ON	[ContactList].[ID] = [Document].[ID] AND
				[ContactList].[Class] = [Document].[Class]

	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
			
	
	COMMIT TRANSACTION
		
	RETURN 0
GO

GRANT EXEC ON adfDocumentContactUpdate TO PUBLIC
GO
