 IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfContactBrowseByCategory')
	BEGIN
		PRINT 'Dropping Procedure adfContactBrowseByCategory'
		DROP  Procedure  adfContactBrowseByCategory
	END

GO

PRINT 'Creating Procedure adfContactBrowseByCategory'
GO
/******************************************************************************
**		File: 
**		Name: adfContactBrowseByCategory
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**     ----------							-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		19.01.11	MAN				  .
**		15.12.11	PAM				   
**		04.03.14	GNV				   (.  .)
*******************************************************************************/
CREATE Procedure adfContactBrowseByCategory
	@Own BIT,
	@StateSelector INT
AS
	SET NOCOUNT ON
	
	--     
	IF dbo.adfHasAccessRightByName('ViewAllContacts') = 0 AND dbo.adfHasAccessRightByName('ManageContacts') = 0
		RETURN 0

	DECLARE @UserID TIdentifier, @EmployeeClass TClass, @Lang TLanguage
	
	SET @UserID = dbo.adfGetCurrentUserID()
	SET @EmployeeClass = dbo.adfGetClassByName('Adf.Employee')
	SET @Lang = dbo.adfGetLanguage()
		
	DECLARE @none nvarchar(6)
	IF dbo.adfGetLanguage() = 'ru'
		SET @none = '()'
	ELSE
		SET @none = '(none)'
	
		
	SELECT
		[Employee].[ID],
		[Employee].[Class],
		[Employee].[State],
		[Employee].[Flag],
		[Employee].[FileAs],
		[Employee].[CompanyID],
		[Employee].[PositionID],
		[Employee].[QualificationID],
		[Employee].[DivisionID],
		[Employee].[Comments],
		[Employee].[Created],
		[Employee].[CreatedBy],
		[Employee].[Modified],
		[Employee].[ModifiedBy],
		[Employee].[Timestamp],
		[Employee].[Title],
		[Employee].[FirstName],
		[Employee].[MiddleName],
		[Employee].[LastName],
		[Employee].[Suffix],
		[Employee].[Initials],
		[Employee].[BirthDate],
		[Employee].[BirthPlace],
		[Employee].[LegalCode],
		(CASE 
			WHEN  CAST([ExtendedProperties] as xml).value('(/ExtendedProperties/Values/Gender)[1]','int') = '1' THEN (CASE WHEN @lang='ru' THEN '.' ELSE 'male' END)
			WHEN  CAST([ExtendedProperties] as xml).value('(/ExtendedProperties/Values/Gender)[1]','int') = '2' THEN (CASE WHEN @lang='ru' THEN '.' ELSE 'female' END)
			ELSE (CASE WHEN @lang='ru' THEN ' ' ELSE 'not set' END)
		END) AS [Gender],
		[#PhoneType#1] as Phone1,
		[#PhoneType#2] as Phone2,
		(SELECT [Street] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 1) as [Street1],
		(SELECT [Street] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 3) as [Street2],
		(SELECT [Country] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 1) as [Country1],
		(SELECT [Country] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 3) as [Country2],
		(SELECT [Region] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 1) as [Region1],
		(SELECT [Region] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 3) as [Region2],
		(SELECT [City] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 1) as [City1],
		(SELECT [City] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 3) as [City2],
		(SELECT [PostalCode] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 1) as [PostalCode1],
		(SELECT [PostalCode] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 3) as [PostalCode2],
		(SELECT [Email] FROM [Email] WHERE [Email].[BusinessCardID] = [Employee].[ID] AND [Email].[BusinessCardClass] = [Employee].[Class] AND [Email].[EmailTypeID] = 1) as Email,
		(SELECT [Email] FROM [Email] WHERE [Email].[BusinessCardID] = [Employee].[ID] AND [Email].[BusinessCardClass] = [Employee].[Class] AND [Email].[EmailTypeID] = 4) as WebPage,
		[Company].[ManagerEmployeeID],
		ISNULL([adfvwDocumentCategory].[CategoryName], @none) as [Category],
		CAST((CASE WHEN [UserContact].[BusinessCardID] IS NULL THEN 0 ELSE 1 END) as bit) as [Private],
		[#PhoneType#1],
		[#PhoneType#2],
		[#PhoneType#3],
		[#PhoneType#4],
		[#PhoneType#5],
		[#PhoneType#6],
		[#PhoneType#7],
		[#PhoneType#8],
		[#PhoneType#9],
		[#PhoneType#10],
		[#PhoneType#11]
	FROM
		[Employee] 
		LEFT OUTER JOIN [vwPhone]
			ON ([Employee].[ID] = [vwPhone].[BusinessCardID] AND [Employee].[Class] = [vwPhone].[BusinessCardClass])
		INNER JOIN [BusinessCard]
			ON ([Employee].[ID] = [BusinessCard].[ID] AND [Employee].[Class] = [BusinessCard].[Class])
		LEFT OUTER JOIN [Company]
			ON ([Employee].[CompanyID] = [Company].[ID])
		LEFT OUTER JOIN [adfvwDocumentCategory]
			ON ([Employee].[Class] = [adfvwDocumentCategory].[DocumentClass] AND [Employee].[ID] = [adfvwDocumentCategory].[DocumentID])			
		LEFT OUTER JOIN [UserContact]
			ON ([Employee].[ID] = [UserContact].[BusinessCardID] AND [UserContact].[BusinessCardClass] = @EmployeeClass AND [UserContact].[UserID] = @UserID)
		LEFT OUTER JOIN [ExtendedProperties]
			ON [Employee].[ID] = [ExtendedProperties].[ID] AND [Employee].[Class] = [ExtendedProperties].[Class]
	WHERE
		(
			(@StateSelector = 0) 
		OR 
			(@StateSelector = 1 AND ([Employee].[State] = 1 AND ( [Company].[State] = 1 OR [Employee].[CompanyID] IS NULL)))
		OR 
			(@StateSelector = 2 AND ([Employee].[State] = 2 OR [Company].[State] = 2))
		)
		AND
		(
			[Company].[Own] = 0
			OR
			[Employee].[CompanyID] IS NULL
		)
		AND
		(	
			@Own = 0
			OR
			(
				@Own != 0 
				AND 
				[UserContact].[BusinessCardID] IS NOT NULL
			)
		)

	RETURN 0
GO

GRANT EXEC ON adfContactBrowseByCategory TO PUBLIC

GO
