IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfSecurityImport')
	BEGIN
		PRINT 'Dropping Procedure adfSecurityImport'
		DROP  Procedure  adfSecurityImport
	END

GO

PRINT 'Creating Procedure adfSecurityImport'
GO
/******************************************************************************
**		File: 
**		Name: adfSecurityImport
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		11.03.13	SOV			 OpenXml  Xml
**		04.06.13	SOV			 \  
**								   - 
**		13.06.13	SOV			     
**		05.06.14	SAP			  Active   Right
**		29.09.14	SAP			  
*******************************************************************************/
CREATE Procedure adfSecurityImport
	@ObjectName TName,
	@Xml XML
AS
	DECLARE @result INT, @pic varbinary(8000)
	SEt ANSI_PADDING ON
	SET NOCOUNT ON
	SET QUOTED_IDENTIFIER ON
	
	IF @ObjectName = 'Right'
	BEGIN
		DECLARE rights_cursor CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
		SELECT 
			[XmlTable].value('ID[1]', 'int'), 
			[XmlTable].value('Name[1]', 'nvarchar(128)'), 
			[XmlTable].value('DisplayName[1]', 'nvarchar(256)'), 
			[XmlTable].value('Comments[1]', 'nvarchar(max)'), 
			[XmlTable].value('Group[1]', 'nvarchar(128)'),
			[XmlTable].value('Active[1]', 'bit')
		FROM 
			@Xml.nodes('/SecurityDataSet/Right') AS List(XmlTable)
		OPEN rights_cursor
		DECLARE @rID INT,
				@rName nvarchar(128),
				@rDisplayName nvarchar(256),
				@rComments nvarchar(max),
				@rGroup nvarchar(128),
				@rActive bit
	
		BEGIN TRANSACTION

		FETCH NEXT FROM rights_cursor INTO @rID, @rName, @rDisplayName, @rComments, @rGroup, @rActive
		WHILE @@FETCH_STATUS = 0
		BEGIN
			IF EXISTS(SELECT * FROM [Right] WHERE [Name]=@rName)
			BEGIN
				UPDATE 
					[Right]
				SET
					[Name] = @rName,
					[DisplayName] = @rDisplayName,
					[Comments] = @rComments,
					[Group] = @rGroup
				WHERE
					[Right].[Name] = @rName
				IF @@ERROR != 0 GOTO ERROR_HANDLER
			END
			ELSE
			BEGIN
				INSERT INTO [Right]
					([Name], [DisplayName], [Comments], [Group], [Active])
				VALUES
					(@rName, @rDisplayName, @rComments, @rGroup, @rActive)
				IF @@ERROR != 0 GOTO ERROR_HANDLER
			END
			FETCH NEXT FROM rights_cursor INTO @rID, @rName, @rDisplayName, @rComments, @rGroup, @rActive
		END
	
		COMMIT TRANSACTION
	
		CLOSE rights_cursor
		DEALLOCATE rights_cursor

	END
	ELSE IF @ObjectName = 'RightGlobal'
	BEGIN
		BEGIN TRANSACTION

		DELETE FROM [RightGlobal]

		IF @@ERROR != 0 GOTO ERROR_HANDLER
	
		INSERT INTO [RightGlobal]
			([ID], [Language], [DisplayName], [Comments])
		SELECT
			(SELECT [ID] FROM [Right] WHERE [Name] = [XmlTable].value('Name[1]', 'nvarchar(128)')),
			[XmlTable].value('Language[1]', 'varchar(2)'), 
			[XmlTable].value('DisplayName[1]', 'nvarchar(256)'), 
			[XmlTable].value('Comments[1]', 'nvarchar(max)')
		FROM
			@Xml.nodes('/SecurityDataSet/RightGlobal') AS List(XmlTable)
		
		IF @@ERROR != 0 GOTO ERROR_HANDLER

		COMMIT TRANSACTION
	END
	ELSE IF @ObjectName = 'Action'
	BEGIN
		DECLARE actions_cursor CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
		SELECT 
			[XmlTable].value('ID[1]', 'int'), 
			[XmlTable].value('Name[1]', 'nvarchar(256)'), 
			[XmlTable].value('Comments[1]', 'nvarchar(max)'), 
			[XmlTable].value('Image[1]', 'varchar(8000)')
		FROM 
			@Xml.nodes('/SecurityDataSet/Action') AS List(XmlTable)
	
		OPEN actions_cursor
		DECLARE @aID INT, 
				@aName nvarchar(256),
				@aComments nvarchar(max),
				@aImage varchar(8000)
	
		SET IDENTITY_INSERT [Action] ON
	
		BEGIN TRANSACTION

		FETCH NEXT FROM actions_cursor INTO @aID, @aName, @aComments, @aImage
		WHILE @@FETCH_STATUS = 0
		BEGIN
			SET @pic = dbo.adfBase64ToBin(@aImage)
			IF EXISTS(SELECT * FROM [Action] WHERE [ID] = @aID)
			BEGIN
				UPDATE 
					[Action]
				SET
					[Name] = @aName,
					[Comments] = @aComments,
					[Image] = @pic
				WHERE
					[ID] = @aID
				IF @@ERROR != 0 GOTO ERROR_HANDLER
			END	
			ELSE
			BEGIN
				INSERT INTO [Action]
					([ID], [Name], [Comments], [Image])
				VALUES
					(@aID, @aName, @aComments, @pic)
				IF @@ERROR != 0 GOTO ERROR_HANDLER
			END
			FETCH NEXT FROM actions_cursor INTO @aID, @aName, @aComments, @aImage
		END

		COMMIT TRANSACTION

		SET IDENTITY_INSERT [Action] OFF

		CLOSE actions_cursor
		DEALLOCATE actions_cursor		
	END
	ELSE IF @ObjectName = 'ActionGlobal'
	BEGIN
		BEGIN TRANSACTION

		DELETE [ActionGlobal]

		IF @@ERROR != 0 GOTO ERROR_HANDLER
	
		INSERT [ActionGlobal]
			([ID], [Language], [Name], [Comments])
		SELECT
			[XmlTable].value('ID[1]', 'int'),
			[XmlTable].value('Language[1]', 'varchar(2)'), 
			[XmlTable].value('Name[1]', 'nvarchar(256)'), 
			[XmlTable].value('Comments[1]', 'nvarchar(max)')
		FROM
			@Xml.nodes('/SecurityDataSet/ActionGlobal') AS List(XmlTable)

		IF @@ERROR != 0 GOTO ERROR_HANDLER
	
		COMMIT TRANSACTION
	END
	ELSE IF @ObjectName = 'Role'
	BEGIN
		DECLARE roles_cursor CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
		SELECT 
			[XmlTable].value('ID[1]', 'int'), 
			[XmlTable].value('Name[1]', 'nvarchar(128)'),  
			[XmlTable].value('DisplayName[1]', 'nvarchar(256)'), 
			[XmlTable].value('Comments[1]', 'nvarchar(max)'),
			[XmlTable].value('Active[1]', 'bit')
		FROM 
			@Xml.nodes('/SecurityDataSet/Role') AS List(XmlTable)
		OPEN roles_cursor
	
		DECLARE @lID TIdentifier,
				@lName TSysname,
				@lDisplayName TName,
				@lComments TNotes,
				@lActive bit

		BEGIN TRANSACTION
				
		FETCH NEXT FROM roles_cursor INTO @lID, @lName, @lDisplayName, @lComments, @lActive
		WHILE @@FETCH_STATUS = 0
		BEGIN
			IF EXISTS(SELECT * FROM [Trustee] WHERE [Name] = @lName)
			BEGIN
				UPDATE
					[Trustee]
				SET
					[DisplayName] = @lDisplayName,
					[Comments] = @lComments,
					[Standard] = 1
				WHERE
					[Name] = @lName
				IF @@ERROR != 0 GOTO ERROR_HANDLER
			END
			ELSE
			BEGIN
				INSERT INTO [Trustee]
					([Name], [DisplayName], [Comments], [Builtin], [Standard], [Active])
				VALUES
					(@lName, @lDisplayName, @lComments, 0, 1, @lActive)
				IF @@ERROR != 0 GOTO ERROR_HANDLER
				
				SET @lID = SCOPE_IDENTITY()
				INSERT INTO [Role] ([ID]) VALUES(@lID)
				IF @@ERROR != 0 GOTO ERROR_HANDLER
			END
			FETCH NEXT FROM roles_cursor INTO @lID, @lName, @lDisplayName, @lComments, @lActive
		END
	
		COMMIT TRANSACTION
	
		CLOSE roles_cursor
		DEALLOCATE roles_cursor
	END
	ELSE IF @ObjectName = 'RoleGlobal'
	BEGIN
		BEGIN TRANSACTION

		DELETE [TrusteeGlobal]

		IF @@ERROR != 0 GOTO ERROR_HANDLER
	
		INSERT INTO [TrusteeGlobal]
			([ID], [Language], [DisplayName], [Comments])
		SELECT
			(SELECT [Role].[ID] FROM [Trustee] INNER JOIN [Role] ON ([Trustee].[ID] = [Role].[ID]) WHERE [Name] = [XmlTable].value('Name[1]', 'nvarchar(128)')),
			[XmlTable].value('Language[1]', 'varchar(2)'), 
			[XmlTable].value('DisplayName[1]', 'nvarchar(256)'), 
			[XmlTable].value('Comments[1]', 'nvarchar(max)')
		FROM
			@Xml.nodes('/SecurityDataSet/RoleGlobal') AS List(XmlTable)
		
		IF @@ERROR != 0 GOTO ERROR_HANDLER

		COMMIT TRANSACTION
	END
	ELSE IF @ObjectName = 'AccessRight'
	BEGIN
		DECLARE accessrights_cursor CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
		SELECT 
			[XmlTable].value('Right[1]', 'nvarchar(128)'), 
			[XmlTable].value('Role[1]', 'nvarchar(128)') 
		FROM
			@Xml.nodes('/SecurityDataSet/AccessRight') AS List(XmlTable)
		OPEN accessrights_cursor 
	
		DECLARE @arRight TSysname,
				@arRole TSysname,
				@arRightID TIdentifier,
				@arRoleID TIdentifier
			
		BEGIN TRANSACTION
		FETCH NEXT FROM accessrights_cursor INTO @arRight, @arRole
		WHILE @@FETCH_STATUS = 0
		BEGIN
			SET @arRightID = dbo.adfGetRightID(@arRight)
			SET @arRoleID = dbo.adfGetRoleID(@arRole)
			IF NOT EXISTS(SELECT * FROM [AccessRight] WHERE [RightID] = @arRightID AND [TrusteeID]=@arRoleID)
			BEGIN
				INSERT INTO [AccessRight] VALUES(@arRightID, @arRoleID, 1)
				IF @@ERROR != 0 GOTO ERROR_HANDLER
			END
			FETCH NEXT FROM accessrights_cursor INTO @arRight, @arRole
		END
		COMMIT TRANSACTION
		CLOSE accessrights_cursor
		DEALLOCATE accessrights_cursor
	END
	ELSE IF @ObjectName = 'Class'
	BEGIN
		DECLARE classes_cursor  CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
			SELECT 
				[XmlTable].value('Class[1]', 'SMALLINT'), 
				[XmlTable].value('Code[1]',	'nvarchar(128)'), 
				[XmlTable].value('Name[1]', 'nvarchar(256)'), 
				[XmlTable].value('Guid[1]', 'uniqueidentifier'), 
				[XmlTable].value('Comments[1]', 'nvarchar(max)'),
				[XmlTable].value('CodeIsUnique[1]', 'bit'),
				[XmlTable].value('CodeIsNullable[1]', 'bit'),
				[XmlTable].value('TableName[1]', 'nvarchar(128)'),
				[XmlTable].value('SmallImage[1]', 'varchar(8000)'),
				[XmlTable].value('LargeImage[1]', 'varchar(8000)'),
				[XmlTable].value('SPBrowse[1]', 'nvarchar(128)'),
				[XmlTable].value('SPGet[1]', 'nvarchar(128)'),
				[XmlTable].value('SPCreate[1]',	'nvarchar(128)'),
				[XmlTable].value('SPUpdate[1]', 'nvarchar(128)'),
				[XmlTable].value('SPChangeState[1]', 'nvarchar(128)'),
				[XmlTable].value('SPDelete[1]', 'nvarchar(128)'),
				[XmlTable].value('SPList[1]', 'nvarchar(128)'),
				[XmlTable].value('SPPrint[1]', 'nvarchar(128)')
			FROM 
				@Xml.nodes('/SecurityDataSet/Class') AS List(XmlTable)
		OPEN classes_cursor
		DECLARE @cClass TClass,
				@cCode TCode,
				@cName TName,
				@cGuid TGuid,
				@cComments TNotes,
				@cCodeIsUnique TBool,
				@cCodeIsNullable TBool,
				@cTableName TSysname,
				@cClassID TIdentifier,
				@cSmallImage varchar(8000),
				@cLargeImage varchar(8000),
				@cSPBrowse TSysname,
				@cSPGet TSysname,
				@cSPCreate TSysname,
				@cSPUpdate TSysname,
				@cSPChangeState TSysname,
				@cSPDelete TSysname,
				@cSPList TSysname,
				@cSPPrint TSysname

		DECLARE @pic1 varbinary(8000)
		BEGIN TRANSACTION	
		FETCH NEXT FROM classes_cursor INTO @cClass, @cCode, @cName, @cGuid, @cComments, @cCodeIsUnique, @cCodeIsNullable,
			@cTableName, @cSmallImage, @cLargeImage,
			@cSPBrowse, @cSPGet, @cSPCreate, @cSPUpdate, @cSPChangeState, @cSPDelete, 
			@cSPList, @cSPPrint

		WHILE @@FETCH_STATUS = 0
		BEGIN
			SET @pic = dbo.adfBase64ToBin(@cSmallImage)
			SET @pic1 = dbo.adfBase64ToBin(@cLargeImage)

			IF NOT EXISTS(SELECT * FROM [Class] WHERE [Guid] = @cGuid)
			BEGIN
				INSERT INTO [Class] 
					([Code], [Name], [Guid], [Comments], [CodeIsUnique], [CodeIsNullable],
					[TableName], [SmallImage], [LargeImage],
					[SPBrowse], [SPGet], [SPCreate], [SPUpdate], [SPChangeState], 
					[SPDelete], [SPList], [SPPrint])
				VALUES
					(@cCode, @cName, @cGuid, @cComments, @cCodeIsUnique, @cCodeIsNullable,
					@cTableName, 
					@pic, @pic1,
					@cSPBrowse, @cSPGet, @cSPCreate, @cSPUpdate, @cSPChangeState, 
					@cSPDelete, @cSPList, @cSPPrint)
				
				IF @@ERROR != 0 GOTO ERROR_HANDLER
			END
			ELSE
			BEGIN
				UPDATE [Class] 
				SET	[Code] = @cCode, 
					[Name] = @cName, 
					[Comments] = @cComments, 
					[CodeIsUnique] = @cCodeIsUnique, 
					[CodeIsNullable] = @cCodeIsNullable,
					[TableName] = @cTableName,
					[SmallImage] = @pic,
					[LargeImage] = @pic1,
					[SPBrowse] = @cSPBrowse,
					[SPGet] = @cSPGet,
					[SPCreate] = @cSPCreate,
					[SPUpdate] = @cSPUpdate,
					[SPChangeState] = @cSPChangeState,
					[SPDelete] = @cSPDelete,
					[SPList] = @cSPList,
					[SPPrint] = @cSPPrint
				WHERE [Guid] = @cGuid
				IF @@ERROR != 0 GOTO ERROR_HANDLER
			END
			SELECT @cClassID = [Class].[Class] FROM [Class] WHERE [Class].[Guid] = @cGuid
		
			FETCH NEXT FROM classes_cursor INTO @cClass, @cCode, @cName, @cGuid, @cComments, @cCodeIsUnique, @cCodeIsNullable,
				@cTableName, @cSmallImage, @cLargeImage,
				@cSPBrowse, @cSPGet, @cSPCreate, @cSPUpdate, @cSPChangeState, @cSPDelete, 
				@cSPList, @cSPPrint
		END
		COMMIT TRANSACTION
		CLOSE classes_cursor
		DEALLOCATE classes_cursor
	END
	ELSE IF @ObjectName = 'ClassGlobal'
	BEGIN
		BEGIN TRANSACTION

		DELETE [ClassGlobal]

		IF @@ERROR != 0 GOTO ERROR_HANDLER
	
		INSERT INTO [ClassGlobal]
			([Class], [Language], [Name], [Comments])
		SELECT
			(SELECT [Class] FROM [Class] WHERE [Class].[Code] = [XmlTable].value('Code[1]', 'nvarchar(128)')),
			[XmlTable].value('Language[1]', 'varchar(2)'), 
			[XmlTable].value('Name[1]', 'nvarchar(256)'), 
			[XmlTable].value('Comments[1]', 'nvarchar(max)')
		FROM
			@Xml.nodes('/SecurityDataSet/ClassGlobal') AS List(XmlTable)

		IF @@ERROR != 0 GOTO ERROR_HANDLER

		COMMIT TRANSACTION
	END		
	ELSE IF @ObjectName = 'State'
	BEGIN
		DECLARE states_cursor CURSOR  LOCAL FAST_FORWARD READ_ONLY FOR
			SELECT 
				[XmlTable].value('Guid[1]', 'uniqueidentifier'), 
				[XmlTable].value('State[1]', 'INT'), 
				[XmlTable].value('Name[1]', 'nvarchar(256)'), 
				[XmlTable].value('Comments[1]', 'nvarchar(max)'),
				[XmlTable].value('UIText[1]', 'nvarchar(256)'),
				[XmlTable].value('Image[1]', 'varchar(8000)')
			FROM 
				@Xml.nodes('/SecurityDataSet/State') AS List(XmlTable)
		OPEN states_cursor
	
		DECLARE @sGuid TGuid,
				@sClass TClass,
				@sState TState,
				@sName TSysname,
				@sComments TNotes,
				@sUIText TName,
				@sImage varchar(8000)
	
		BEGIN TRANSACTION
		FETCH NEXT FROM states_cursor INTO @sGuid, @sState, @sName, @sComments, @sUIText, @sImage
		WHILE @@FETCH_STATUS = 0
		BEGIN
			SET @pic = dbo.adfBase64ToBin(@sImage)
			SELECT @sClass = [Class] FROM [Class] WHERE [Guid] = @sGuid
		
			IF EXISTS (SELECT * FROM [State] WHERE [Class] = @sClass AND [State] = @sState)
			BEGIN
				UPDATE 
					[State]
				SET
					[Name] = @sName,
					[Comments] = @sComments,
					[UIText] = @sUIText,
					[Image] = @pic
				WHERE
					[Class] = @sClass AND [State] = @sState
				IF @@ERROR != 0 GOTO ERROR_HANDLER
			END
			ELSE
			BEGIN
				INSERT INTO [State] 
					([Class], [State], [Name], [Comments], [UIText], [Image])
				VALUES
					(@sClass, @sState, @sName, @sComments, @sUIText, @pic)
				IF @@ERROR != 0 GOTO ERROR_HANDLER
			END
		
			FETCH NEXT FROM states_cursor INTO @sGuid, @sState, @sName, @sComments, @sUIText, @sImage
		END
		COMMIT TRANSACTION
		CLOSE states_cursor
		DEALLOCATE states_cursor
	END
	ELSE IF @ObjectName = 'StateGlobal'
	BEGIN
		BEGIN TRANSACTION
		
		DELETE [StateGlobal]
	
		IF @@ERROR != 0 GOTO ERROR_HANDLER
	
		INSERT INTO [StateGlobal]
			([Class], [State], [Language], [Name], [Comments], [UIText])
		SELECT
			(SELECT [Class] FROM [Class] WHERE [Class].[Code]=[XmlTable].value('Code[1]', 'varchar(32)')),
			[XmlTable].value('State[1]', 'INT'), 
			[XmlTable].value('Language[1]', 'varchar(2)'), 
			[XmlTable].value('Name[1]', 'nvarchar(256)'), 
			[XmlTable].value('Comments[1]', 'nvarchar(max)'),
			[XmlTable].value('UIText[1]', 'nvarchar(256)')
		FROM
			@Xml.nodes('/SecurityDataSet/StateGlobal') AS List(XmlTable)
	
		IF @@ERROR != 0 GOTO ERROR_HANDLER
	
		COMMIT TRANSACTION
	END
	ELSE IF @ObjectName = 'UICommand'
	BEGIN
		DECLARE commands_cursor CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
			SELECT
				[XmlTable].value('ID[1]', 'INT'),
				[XmlTable].value('ActionID[1]', 'nvarchar(128)'),
				[XmlTable].value('Guid[1]', 'uniqueidentifier'),
				[XmlTable].value('Name[1]', 'nvarchar(128)'),
				[XmlTable].value('Text[1]', 'nvarchar(256)'),
				[XmlTable].value('AlternateText[1]', 'nvarchar(256)'),
				[XmlTable].value('Shortcut[1]', 'varchar(256)'),
				[XmlTable].value('Comments[1]', 'nvarchar(max)'),
				[XmlTable].value('Picture[1]', 'varchar(8000)'),
				[XmlTable].value('Position[1]', 'int'),
				(CASE WHEN [XmlTable].value('BeginGroup[1]', 'varchar(5)')='false' THEN 0 ELSE 1 END)
			FROM
				@Xml.nodes('/SecurityDataSet/UICommand') AS List(XmlTable)
		OPEN commands_cursor
		DECLARE @mID INT,
				@mActionID nvarchar(128),
				@mGuid uniqueidentifier,
				@mName nvarchar(128),
				@mText nvarchar(256),
				@mAlternateText nvarchar(256),
				@mShortcut varchar(256),
				@mComments nvarchar(max),
				@mPicture varchar(8000),
				@mClass smallint,
				@mPosition int,
				@mBeginGroup bit
			
		BEGIN TRANSACTION
		FETCH NEXT FROM commands_cursor INTO @mID, @mActionID, @mGuid, @mName, @mText, @mAlternateText,
			@mShortcut, @mComments, @mPicture, @mPosition, @mBeginGroup
		WHILE @@FETCH_STATUS = 0
		BEGIN
			SET @pic = dbo.adfBase64ToBin(@mPicture)

			SELECT @mClass = [Class] FROM [Class] WHERE [Guid] = @mGuid
		
			IF EXISTS(SELECT * FROM [UICommand] WHERE [Name]=@mName)
			BEGIN
				UPDATE 
					[UICommand]
				SET
					[ActionID]=@mActionID,
					[Class] = @mClass,
					[Name] = @mName,
					[Text] = @mText,
					[AlternateText] = @mAlternateText,
					[Shortcut] = @mShortcut,
					[Comments] = @mComments,
					[Picture] = @pic,
					[Position] = @mPosition,
					[BeginGroup] = @mBeginGroup
				WHERE
					[UICommand].[Name] = @mName

				IF @@ERROR != 0	GOTO ERROR_HANDLER
			END
			ELSE
			BEGIN
				INSERT INTO [UICommand]
					([ActionID], [Class], [Name], [Text], [AlternateText], [Shortcut], [Comments], [Picture],
					[Position], [BeginGroup])
				VALUES
					(@mActionID, @mClass, @mName, @mText, @mAlternateText, @mShortcut, @mComments, @pic,
					@mPosition, @mBeginGroup)
				IF @@ERROR != 0	GOTO ERROR_HANDLER
			
			END
			FETCH NEXT FROM commands_cursor INTO @mID, @mActionID, @mGuid, @mName, @mText, @mAlternateText,
				@mShortcut, @mComments, @mPicture, @mPosition, @mBeginGroup
		END
		COMMIT TRANSACTION
	
		CLOSE commands_cursor
		DEALLOCATE commands_cursor
	END
	ELSE IF @ObjectName = 'UICommandGlobal'
	BEGIN
		BEGIN TRANSACTION
	
		DELETE [UICommandGlobal]
		IF @@ERROR != 0 GOTO ERROR_HANDLER
	
		INSERT INTO [UICommandGlobal]
			([ID], [Language], [Text], [AlternateText], [Comments])
		SELECT
			(SELECT [ID] FROM [UICommand] WHERE [Name]=[XmlTable].value('Name[1]', 'nvarchar(128)')),
			[XmlTable].value('Language[1]', 'varchar(2)'),
			[XmlTable].value('Text[1]', 'nvarchar(256)'),
			[XmlTable].value('AlternateText[1]', 'nvarchar(256)'),
			[XmlTable].value('Comments[1]', 'nvarchar(max)')
		FROM
			@Xml.nodes('/SecurityDataSet/UICommandGlobal') AS List(XmlTable)
		IF @@ERROR != 0 GOTO ERROR_HANDLER
		
		COMMIT TRANSACTION
	END
	ELSE IF @ObjectName = 'TransitionTemplate' OR @ObjectName = 'TransitionTemplateGlobal'
	BEGIN
		EXEC @result = adfSecurityImportTransitionTemplates @ObjectName, @Xml
		IF @result != 0 GOTO ERROR_HANDLER_NOROLLBACK
	END
	ELSE IF @ObjectName = 'SecurityPatch'
	BEGIN
		EXEC @result = adfSecurityPatch @Xml
		IF @@error != 0 OR @result != 0
			GOTO ERROR_HANDLER
	END

	RETURN 0

ERROR_HANDLER:
	ROLLBACK TRANSACTION
	
ERROR_HANDLER_NOROLLBACK:
	RETURN 1

GO

GRANT EXEC ON adfSecurityImport TO PUBLIC
GO
