IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'SubprojectID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Task')
	ALTER TABLE [Task] ADD [SubprojectID] TIdentifier NULL
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS where COLUMN_NAME = 'Duration' AND TABLE_NAME = 'Task' AND DATA_TYPE = 'int')
BEGIN
	EXEC sp_executesql N'
	ALTER TABLE [Task] DISABLE TRIGGER ALL
	ALTER TABLE [Task] ALTER COLUMN [Duration] TAmount NOT NULL
	
	UPDATE
		[Task]
	SET
		[Duration] = ([Duration] / 60.0) / 24.0
	
	ALTER TABLE [Task] ENABLE TRIGGER ALL'
END
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'Work' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='BusyEntry')
BEGIN
	EXEC sp_executesql N'ALTER TABLE [BusyEntry] ADD [Work] TCount not null default 0'
END
GO

EXEC sp_executesql N'UPDATE [BusyEntry] SET [Work] = [Planned] - [Canceled] WHERE [Work] = [Planned] - [Canceled]'
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'OvertimeWork' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='BusyEntry')
	ALTER TABLE [BusyEntry] ADD [OvertimeWork] TCount not null default 0
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'ActualWork' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='BusyEntry')
	ALTER TABLE [BusyEntry] ADD [ActualWork] TCount not null default 0
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'ActualOvertimeWork' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='BusyEntry')
	ALTER TABLE [BusyEntry] ADD [ActualOvertimeWork] TCount not null default 0
GO

IF EXISTS (SELECT * FROM syscolumns WHERE [name] = 'Color' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='BusyEntry')
	ALTER TABLE [BusyEntry] DROP COLUMN [Color]
GO

IF EXISTS (SELECT * FROM syscolumns WHERE [name] = 'Subject' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='BusyEntry')
	ALTER TABLE [BusyEntry] DROP COLUMN [Subject]
GO

IF EXISTS (SELECT * FROM syscolumns WHERE [name] = 'Overtime' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='BusyEntry')
BEGIN
	DECLARE @name sysname, @sql varchar(2000)
	SELECT
		@name = sys.default_constraints.[name] 
	FROM
		sys.default_constraints
		INNER JOIN sys.columns
			ON
			sys.default_constraints.object_id = sys.columns.default_object_id AND
			sys.columns.[name] = 'Overtime' AND 
			OBJECTPROPERTY(sys.columns.object_id, N'IsUserTable') = 1 AND 
			OBJECT_NAME(sys.columns.object_id)='BusyEntry'
	SET @sql = N'ALTER TABLE [BusyEntry] DROP CONSTRAINT ' + @name
	EXEC (@sql)
	
	ALTER TABLE [BusyEntry] DROP COLUMN [Overtime]
END
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'RemainingWork' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='TaskAssignment')
	ALTER TABLE [TaskAssignment] ADD [RemainingWork] TAmount null
GO

UPDATE [TaskAssignment] SET [RemainingWork] = 0 WHERE [RemainingWork] IS NULL
GO

DECLARE @default_name TName
SELECT
	@default_name = d.name
FROM 
	sys.default_constraints d
	INNER JOIN sys.columns c
		ON c.[object_id] = d.[parent_object_id] AND d.[object_id]=c.[default_object_id]
WHERE 
	d.[parent_object_id]=object_id('TaskAssignment') AND c.[name] = 'RemainingWork'
	
IF @default_name IS NULL
BEGIN
	EXEC sp_executesql N'ALTER TABLE [TaskAssignment] ADD CONSTRAINT [RemainingWorkDefault] DEFAULT 0 FOR [RemainingWork]'
	EXEC sp_executesql N'ALTER TABLE [TaskAssignment] ALTER COLUMN [RemainingWork] TAmount not null'
END
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'RemainingOvertimeWork' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='TaskAssignment')
	ALTER TABLE [TaskAssignment] ADD [RemainingOvertimeWork] TAmount  null
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'MsAvailable' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='TaskAssignment')
	ALTER TABLE [TaskAssignment] ADD [MsAvailable] TBool not null default 1
GO

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'TaskWbs') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
	/*==============================================================*/
	/* Table: TaskWbs                                               */
	/*==============================================================*/
	create table TaskWbs (
	   TaskID               TIdentifier          not null,
	   TaskIndex            TCount               not null,
	   Wbs                  TName                null,
	   constraint TaskWbsPK primary key  (TaskID)
	)
GO

IF NOT EXISTS(SELECT * FROM TaskWbs)
BEGIN
	DECLARE 
		@ProjectID TIdentifier,
		@TaskID TIdentifier,
		@PrevProjectID TIdentifier,
		@TaskIndex TCount
	SET @PrevProjectID = 0
	
	DECLARE tasks CURSOR LOCAL FAST_FORWARD FOR
		SELECT [ProjectID], [ID] FROM [Task] ORDER BY [ProjectID], [ID]
	
	OPEN tasks
	FETCH NEXT FROM tasks INTO @ProjectID, @TaskID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		IF @PrevProjectID != @ProjectID
			SET @TaskIndex = 1
		ELSE
			SET @TaskIndex = @TaskIndex + 1
			
		INSERT INTO [TaskWbs] ([TaskID], [TaskIndex]) VALUES (@TaskID, @TaskIndex)
		
		SET @PrevProjectID = @ProjectID
		FETCH NEXT FROM tasks INTO @ProjectID, @TaskID
	END
	CLOSE tasks
	DEALLOCATE tasks
END
GO
---------- Planned
IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'State' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='TaskAssignment')
BEGIN	
	EXEC sp_executesql N'ALTER TABLE [TaskAssignment] ADD [State] TState not null default 1'
	
	EXEC sp_executesql N'IF EXISTS (SELECT * FROM sysobjects WHERE type = ''P'' AND name = ''pjm6DeactivateTaskAssignments'')
	BEGIN
		DROP  Procedure  pjm6DeactivateTaskAssignments
	END'
	
	EXEC sp_executesql N'CREATE Procedure pjm6DeactivateTaskAssignments
	@AssignmentID TIdentifier,
	@TaskID TIdentifier = NULL
AS
	SET NOCOUNT ON

	DECLARE
		@rv int,
		@DeactivateDate TDateTime
	
	BEGIN TRANSACTION

	SET @DeactivateDate = DATEADD(day, 1, CAST(CONVERT(varchar(8), GETDATE(), 112) AS DateTime))
	DECLARE	@Tasks TABLE([ID] int)
	
	-- Task list to update
	;
	WITH [PreTasks] ([ID], [ActualWork]) AS
	(
		SELECT 
			[Task].[ID],
			SUM(ISNULL([BusyEntry].[ActualWork], 0) + ISNULL([BusyEntry].[ActualOvertimeWork], 0))
		FROM 
			[Task]
			LEFT OUTER JOIN [BusyEntry]
				ON [BusyEntry].[TaskID] = [Task].[ID]
				AND [BusyEntry].[AssignmentID] = @AssignmentID
		WHERE
			[Task].[State] IN (8,2) AND
			(@TaskID IS NULL OR [Task].[ID] = @TaskID)
		GROUP BY
			[Task].[ID]
	)
	INSERT INTO @Tasks 
	SELECT 
		[PreTasks].[ID]
	FROM 
		[PreTasks]
	WHERE
		[PreTasks].[ActualWork] > 0

	-- Delete BusyEntry later then @DeactivateDate
	DELETE 
		[BusyEntry]
	FROM
		[BusyEntry]
		INNER JOIN @Tasks as [Tasks]
			ON [Tasks].[ID] = [BusyEntry].[TaskID]
	WHERE 
		[BusyEntry].[AssignmentID] = @AssignmentID AND
		[BusyEntry].[Date] >= @DeactivateDate AND
		[BusyEntry].[ActualWork] = 0
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	-- Update to 0 planned in busyentry where actualwork
	UPDATE 
		[BusyEntry]
	SET
		[Planned] = 0
	FROM
		[BusyEntry]
		INNER JOIN @Tasks as [Tasks]
			ON [Tasks].[ID] = [BusyEntry].[TaskID]
	WHERE 
		[BusyEntry].[AssignmentID] = @AssignmentID AND
		[BusyEntry].[Date] >= @DeactivateDate AND
		[BusyEntry].[ActualWork] > 0
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	-- UPDATE TaskAssignments
	;
	WITH [TaskAssignmentWork] ([TaskID], [Work]) AS
	(
		SELECT
			[Tasks].[ID],
			SUM([BusyEntry].[Planned])
		FROM
			@Tasks as [Tasks]
			INNER JOIN [BusyEntry]
				ON [BusyEntry].[TaskID] = [Tasks].[ID]
				AND [BusyEntry].[AssignmentID] = @AssignmentID
		GROUP BY
			[Tasks].[ID]
	)
	UPDATE
		[TaskAssignment]
	SET
		[State] = 2,
		[Work] = [TaskAssignmentWork].[Work],
		[RemainingWork] = 0
	FROM
		[TaskAssignment]
		INNER JOIN [TaskAssignmentWork]
			ON [TaskAssignmentWork].[TaskID] = [TaskAssignment].[TaskID]
	WHERE
		[TaskAssignment].[AssignmentID] = @AssignmentID
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	-- DELETE TaskAssignments Without ActualWork AND timeEntry not like actual

	DELETE
		[TaskAssignment]
	FROM
		[TaskAssignment]
			INNER JOIN [Task]
				ON [Task].[ID] = [TaskAssignment].[TaskID]
				AND [Task].[State] IN (2,8)
	WHERE
		[TaskAssignment].[State] = 1 AND
		[TaskAssignment].[AssignmentID] = @AssignmentID AND
		(@TaskID IS NULL OR [TaskAssignment].[TaskID] = @TaskID)
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END		
	
		
	/*DELETE 
		[TimeEntry]
	FROM
		[TimeEntry]
			INNER JOIN [Task]
				ON [Task].[ID] = [TimeEntry].[TaskID]
				AND [Task].[State] IN (2,8)
	WHERE
		[TimeEntry].[State] NOT IN (2,3,6) AND
		[TimeEntry].[AssignmentID] = @AssignmentID AND
		(@TaskID IS NULL OR [TimeEntry].[TaskID] = @TaskID)
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END*/

-------------------------------

	DECLARE @DueDate TDateTime, @TaskClass TClass
	SET @TaskClass = dbo.adfGetClassByName(''Pjm5.Task'')
					
	;
	WITH [TaskUpdates] ([TaskID], [DueDate], [ManHour], [Budget]) AS
	(
		SELECT
			[Tasks].[ID],
			(SELECT ISNULL(MAX([Date]), [Task].[StartDate]) FROM [BusyEntry] WHERE [BusyEntry].[TaskID] = [Tasks].[ID]),
			SUM([TaskAssignment].[Work]),
			SUM([TaskAssignment].[Work] * [Assignment].[StandardRate]) / 60
		FROM
			@Tasks as [Tasks]
			INNER JOIN [Task]
				ON [Task].[ID] = [Tasks].[ID]
			INNER JOIN [TaskAssignment]
				ON [TaskAssignment].[TaskID] = [Tasks].[ID]
			INNER JOIN [Assignment]
				ON [Assignment].[ID] = [TaskAssignment].[AssignmentID]
		GROUP BY
			[Tasks].[ID],
			[Task].[StartDate]
	)
	UPDATE 
		[Task]
	SET
		[Task].[DueDate] = [TaskUpdates].[DueDate],
		[Task].[Duration] = dbo.fnPjm5GetWorkingDays([Task].[StartDate], [TaskUpdates].[DueDate]),
		[ManHour] = [TaskUpdates].[ManHour],
		[Budget] = [TaskUpdates].[Budget]
	FROM
		[Task]
		INNER JOIN [TaskUpdates]
			ON [TaskUpdates].[TaskID] = [Task].[ID]
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	-------------------------------

	IF EXISTS (
			SELECT
				*
			FROM
				[Reminder]
				INNER JOIN @Tasks as [Tasks]
					ON [DocumentID] = [Tasks].[ID]			
			WHERE 
				[DocumentClass] = @TaskClass AND
				[Subtype] = ''TD''
		)
	BEGIN
		UPDATE 
			[Reminder]
		SET 
			[EventTime] = [Task].[DueDate]
		FROM 
			[Reminder]
			INNER JOIN @Tasks as [Tasks]
				ON [Tasks].[ID] = [Reminder].[DocumentID]
			INNER JOIN [Task]
				ON [Task].[ID] = [Tasks].[ID]
		WHERE
			[DocumentClass] = @TaskClass AND
			[Subtype] = ''TD''
		IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END
	
	DECLARE @taskpcID TIdentifier
	DECLARE itemspc CURSOR LOCAL FAST_FORWARD FOR 
	SELECT 
		[ID] 
	FROM 
		@Tasks as [Tasks]
	OPEN itemspc
	FETCH NEXT FROM itemspc INTO @taskpcID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		EXEC @rv = pjm6TaskPercentUpdate @taskpcID

	--	EXEC pjm6AssignmentCheckBudgetOverdraft @taskpcID, @AssignmentID, NULL
		FETCH NEXT FROM itemspc INTO @taskpcID
	END
	CLOSE itemspc
	DEALLOCATE itemspc

	COMMIT TRANSACTION

-----------------------------
	RETURN 0'

	EXEC sp_executesql N'GRANT EXEC ON pjm6DeactivateTaskAssignments TO PUBLIC'

	EXEC sp_executesql N'ALTER TABLE [Task] DISABLE TRIGGER ALL
	
	DECLARE 
		@AssignmentID TIdentifier
	;
	WITH Tasks([ID], [AssignmentID]) AS
	(
		SELECT 
			[BusyEntry].[TaskID],
			[BusyEntry].[AssignmentID]
		FROM 
			[BusyEntry]
			INNER JOIN [Assignment]
				ON [Assignment].[ID] = [BusyEntry].[AssignmentID]
			LEFT OUTER JOIN [TaskAssignment]
					ON [TaskAssignment].[TaskID] = [BusyEntry].[TaskID]
					AND [TaskAssignment].[AssignmentID] = [BusyEntry].[AssignmentID]
		WHERE
			[TaskAssignment].[TaskID] IS NULL
		GROUP BY
			[BusyEntry].[TaskID],
			[BusyEntry].[AssignmentID]
			
	)
	INSERT INTO [TaskAssignment]
	([TaskID], [AssignmentID], [Work], [State])
	SELECT
		[Tasks].[ID],
		[Tasks].[AssignmentID],
		0,
		2
	FROM
		[Tasks]
		
	DECLARE @ActualWork 
	TABLE(
	[TaskID] int, 
	[AssignmentID] int, 
	[Date] DateTime, 
	[ActualWork] int, 
	[ActualOverTimeWork] int)

	INSERT INTO @ActualWork
	([TaskID], [AssignmentID], [Date], [ActualWork])
	SELECT 
		[TimeEntry].[TaskID],
		[TimeEntry].[AssignmentID],
		CAST(CONVERT(varchar(8), [TimeEntry].[StartTime], 112) as DateTime) as [Date],
		SUM([TimeEntry].[Duration]) as [ActualWork]
	FROM 
		[TimeEntry]
		INNER JOIN [Task]
			ON [Task].[ID] = [TimeEntry].[TaskID]
			AND [Task].[MsTaskID] IS NULL
	WHERE
		[TimeEntry].[State] IN (2, 3, 6) AND
		[Task].[MsTaskID] IS NOT NULL
	GROUP BY
		[TimeEntry].[AssignmentID], 
		[TimeEntry].[TaskID],
		CAST(CONVERT(varchar(8), [TimeEntry].[StartTime], 112) as DateTime)


	;WITH [TaskAssActualWork] ([TaskID], [AssignmentID], [ActualWork], [CurrentActualWork]) As
	(
		SELECT
			[ActualWork].[TaskID],
			[ActualWork].[AssignmentID],
			SUM([ActualWork].[ActualWork]),
			SUM([BusyEntry].[ActualWork])
		FROM @ActualWork as [ActualWork]
			INNER JOIN [BusyEntry]
				ON [BusyEntry].[Date] = [ActualWork].[Date]
				AND [BusyEntry].[TaskID] = [ActualWork].[TaskID]
				AND [BusyEntry].[AssignmentID] = [ActualWork].[AssignmentID]
		GROUP BY
			[ActualWork].[TaskID],
			[ActualWork].[AssignmentID]
	)	
	UPDATE 
		[TaskAssignment]
	SET
		[RemainingWork] = (CASE WHEN [TaskAssignment].[RemainingWork] + 
			[TaskAssActualWork].[CurrentActualWork] - [TaskAssActualWork].[ActualWork] < 0
			THEN 0 ELSE [TaskAssignment].[RemainingWork] + 
			[TaskAssActualWork].[CurrentActualWork] - [TaskAssActualWork].[ActualWork] END)
	FROM 
		[TaskAssignment]
			INNER JOIN [TaskAssActualWork]
				ON [TaskAssActualWork].[TaskID] = [TaskAssignment].[TaskID]
				AND  [TaskAssActualWork].[AssignmentID] = [TaskAssignment].[AssignmentID]

	UPDATE
		[BusyEntry]
	SET
		[BusyEntry].[ActualWork] = [ActualWork].[ActualWork]
	FROM
		[BusyEntry]
		INNER JOIN @ActualWork as [ActualWork]
			ON [ActualWork].[TaskID] = [BusyEntry].[TaskID]
			AND [ActualWork].[AssignmentID] = [BusyEntry].[AssignmentID]
			AND [ActualWork].[Date] = [BusyEntry].[Date]

	INSERT INTO [BusyEntry]
	([ProjectID], [TaskID], [AssignmentID], [Date], [EmployeeID], 
	[Committed], [ActualWork])
	SELECT
		[Task].[ProjectID],
		[ActualWork].[TaskID],
		[ActualWork].[assignmentID],
		[ActualWork].[Date],
		[AssignmentEntry].[EmployeeID],
		1,
		[ActualWork].[ActualWork]
	FROM 
		@ActualWork as [ActualWork]
		LEFT OUTER JOIN [BusyEntry]
			ON  [BusyEntry].[TaskID] = [ActualWork].[TaskID]
			AND [BusyEntry].[AssignmentID] = [ActualWork].[AssignmentID]
			AND [BusyEntry].[Date] = [ActualWork].[Date]
		INNER JOIN [Task]
			ON [Task].[ID] = [ActualWork].[TaskID]
		INNER JOIN [AssignmentEntry]
			ON [AssignmentEntry].[AssignmentID] = [ActualWork].[AssignmentID]
	WHERE
		[BusyEntry].[Date] IS NULL 
	
	DECLARE tasks CURSOR LOCAL FAST_FORWARD FOR
		SELECT DISTINCT 
			[TaskAssignment].[AssignmentID] 
		FROM [TaskAssignment]
			INNER JOIN [Assignment]
				ON [Assignment].[ID] = [TaskAssignment].[AssignmentID]
				AND [Assignment].[State] = 2
		WHERE
			[TaskAssignment].[State] = 1
	
	OPEN tasks
	FETCH NEXT FROM tasks INTO @AssignmentID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		EXEC pjm6DeactivateTaskAssignments @AssignmentID
		
		FETCH NEXT FROM tasks INTO @AssignmentID
	END
	CLOSE tasks
	DEALLOCATE tasks	

			
	ALTER TABLE [Task] ENABLE TRIGGER ALL'
END

go 