﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[ContactBrowse]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure ContactBrowse'
	drop procedure [exch].[ContactBrowse]
end
go

print 'Creating procedure ContactBrowse'
go

create procedure [exch].[ContactBrowse] @UserID int  with execute as 'pjmexchangesync'
as
begin
	set nocount on;

	declare @SyncReminders int;

	select @SyncReminders = isnull(cast([Value] as int), 1) from [UserParameter] where [Name] = 'SyncExchangeNotifications' and [UserID] = @UserID;

	with [Contact] ([Class], [ID], [FileAs], [Title], [FirstName], [MiddleName], [LastName], [Suffix], [Initials], 
					[BirthDate], [BirthPlace], [LegalCode], [Position], [Company], [Division], [Qualification],
					[HireDate], [FireDate], [Comments], [Created], [Modified], [RowVersion], [ExchangeID], [SyncTime]) as
	(
		select
			[E].[Class],
			[E].[ID],
			[E].[FileAs],
			[E].[Title],
			[E].[FirstName],
			[E].[MiddleName],
			[E].[LastName],
			[E].[Suffix],
			[E].[Initials],
			[E].[BirthDate],
			[E].[BirthPlace],
			[E].[LegalCode],
			[P].[FileAs] as [Position],
			[C].[FileAs] as [Company],
			[D].[FileAs] as [Division],
			[Q].[FileAs] as [Qualification],
			[E].[HireDate],
			[E].[FireDate],
			[E].[Comments],
			[E].[Created],
			[E].[Modified],
			cast([E].[Timestamp] as bigint) as [RowVersion],
			[L].[ExchangeID],
			[L].[SyncTime]
		from 
			[dbo].[ExchangeDocumentSync] as [S] inner join [dbo].[Employee] as [E]
				on ([S].[DocumentClass] = [E].[Class] and [S].[DocumentID] = [E].[ID])
			left outer join [dbo].[Position] as [P]
				on ([E].[PositionID] = [P].[ID])
			left outer join [dbo].[Company] as [C]
				on ([E].[CompanyID] = [C].[ID])
			left outer join [dbo].[Division] as [D]
				on ([E].[DivisionID] = [D].[ID])
			left outer join [dbo].[Qualification] as [Q]
				on ([E].[QualificationID] = [Q].[ID])
			left outer join [exch].[ExchangeLink] as [L]
				on ([E].[ID] = [L].[DocumentID] and [E].[Class] = [L].[DocumentClass] and [L].[UserID] = @UserID)
		where
			[S].[UserID] = @UserID
	),
	[Category] ([ID], [Category]) as
	(
		select
			[E].[ID],
			[C].[FileAs]
		from
			[dbo].[ExchangeDocumentSync] as [S] inner join [dbo].[Employee] as [E]
				on ([S].[DocumentClass] = [E].[Class] and [S].[DocumentID] = [E].[ID])
			left outer join [dbo].[DocumentCategory] as [DC]
				on([E].[Class] = [DC].[DocumentClass] and [E].[ID] = [DC].DocumentID)
			left outer join [dbo].[Category] as [C]
				on ([DC].[CategoryID] = [C].[ID])
		where
			[S].[UserID] = @UserID
	),
	[Reminder] ([ID], [EventTime], [OriginalInterval], [NextInterval], [RowVersion]) as
	(
		select
			[R].[DocumentID],
			max([R].[EventTime]),
			max([UR].[NextInterval]),
			max([UR].[OriginalInterval]),
			max(cast([UR].[Timestamp] as bigint))
		from
			[dbo].[ExchangeDocumentSync] as [S] inner join [dbo].[Employee] as [E]
					on ([S].[DocumentClass] = [E].[Class] and [S].[DocumentID] = [E].[ID])
			inner join [dbo].[Reminder] as [R] 
				on ([R].[DocumentClass] = [E].[Class] and [R].[DocumentID] = [E].[ID])
			inner join [UserReminder] as [UR]
				ON ([UR].[ReminderID] = [R].[ID] and [UR].[UserID] = @UserID)
		where
			[S].[UserID] = @UserID
		and
			[UR].[State] = 1
		and
			@SyncReminders = 1
		and
			[R].[Subtype] <> 'CB'
		group by
			[R].[DocumentID]
		having
			count(*) = 1
	),
	[ExtendedProperties] ([ID], [Picture], [PictureHash], [Gender]) as
	(
		select
			[EP].[ID],
			[EP].[ExtendedProperties].value('(/ExtendedProperties/Values/Picture)[1]', 'varbinary(max)'),
			[EP].[ExtendedProperties].value('(/ExtendedProperties/Values/PictureHash)[1]', 'varbinary(max)'),
			[EP].[ExtendedProperties].value('(/ExtendedProperties/Values/Gender)[1]', 'varchar(2)')
		from
			[dbo].[ExchangeDocumentSync] as [S] inner join [dbo].[Employee] as [E]
				on ([S].[DocumentClass] = [E].[Class] and [S].[DocumentID] = [E].[ID])
			inner join [dbo].[ExtendedProperties] as [EP]
				on ([E].[Class] = [EP].[Class] and [E].[ID] = [EP].[ID])
		where
			[S].[UserID] = @UserID
	),
	[Address] ([ID], [TypeID], [Type], [Street], [City], [Region], [PostalCode], [Country], [Mail]) as 
	(
	select
		[A].[BusinessCardID] as [ID],
		[A].[AddressTypeID],
		[AT].[FileAs] as [AddressType],
		[A].[Street],
		[A].[City],
		[A].[Region],
		[A].[PostalCode],
		[A].[Country],
		[A].[Mail]
	from
		[dbo].[ExchangeDocumentSync] as [S] inner join [dbo].[Address] as [A]
			on ([S].[DocumentClass] = [A].[BusinessCardClass] and [S].[DocumentID] = [A].[BusinessCardID])
		inner join [dbo].[AddressType] as [AT]
			on ([A].[AddressTypeID] = [AT].[ID])
	where
		[S].[UserID] = @UserID and [A].[AddressTypeID] in (1, 3, 4)
	),
	[Phone] ([ID], [TypeID], [Type], [Phone]) as 
	(
		select
			[P].[BusinessCardID] as [ID],
			[P].[PhoneTypeID],
			[PT].[FileAs] as [PhoneType],
			[P].[Phone]
		from
			[dbo].[ExchangeDocumentSync] as [S] inner join [dbo].[Phone] as [P]
				on ([S].[DocumentClass] = [P].[BusinessCardClass] and [S].[DocumentID] = [P].[BusinessCardID])
			inner join [dbo].[PhoneType] as [PT]
				on ([P].[PhoneTypeID] = [PT].[ID])
		where
			[S].[UserID] = @UserID
	),
	[Email] ([ID], [TypeID], [Type], [Email], [DisplayAs]) as 
	(
		select
			[E].[BusinessCardID] as [ID],
			[E].[EmailTypeID],
			[ET].[FileAs] as [EmailType],
			[E].[Email],
			[E].[DisplayAs]
		from
			[dbo].[ExchangeDocumentSync] as [S] inner join [dbo].[Email] as [E]
				on ([S].[DocumentClass] = [E].[BusinessCardClass] and [S].[DocumentID] = [E].[BusinessCardID])
			inner join [dbo].[EmailType] as [ET]
				on ([E].[EmailTypeID] = [ET].[ID])
		where
			[S].[UserID] = @UserID
	)
	select
		[Contact].[ID], 
		[Contact].[FileAs], 
		[Contact].[Title], 
		[Contact].[FirstName], 
		[Contact].[MiddleName], 
		[Contact].[LastName], 
		[Contact].[Suffix], 
		[Contact].[Initials], 
		[Contact].[BirthDate], 
		[Contact].[Position], 
		[Contact].[Company], 
		[Contact].[Division], 
		[Contact].[Qualification],
		[Contact].[Comments], 
		[Contact].[Created], 
		[Contact].[Modified], 
		(case when [Contact].[RowVersion] > isnull([Reminder].[RowVersion], 0) then [Contact].[RowVersion] else [Reminder].[RowVersion] end) as [RowVersion],
		[Contact].[ExchangeID],
		[Contact].[SyncTime],
		(select	
			[Phone].[TypeID],
			[Phone].[Phone]
		from
			[Phone]
		where
			[Phone].[ID] = [Contact].[ID]
		for xml auto, type),
		(select	
			[Email].[TypeID],
			[Email].[Email]
		from
			[Email]
		where
			[Email].[ID] = [Contact].[ID]
		for xml auto, type),
		(select	
			[Address].[TypeID],
			[Address].[Street],
			[Address].[City], 
			[Address].[Region], 
			[Address].[PostalCode], 
			[Address].[Country], 
			[Address].[Mail]
		from
			[Address]
		where
			[Address].[ID] = [Contact].[ID]
		for xml auto, type),
		(select 
			[Category].[Category]
		from
			[Category]
		where	
			[Category].[ID] = [Contact].[ID]
		for xml auto, type),
		(select
			[Reminder].[EventTime],
			[Reminder].[NextInterval]
		from
			[Reminder]
		where
			[Reminder].[ID] = [Contact].[ID]
		for xml auto, type),
		(select	
			[ExtendedProperties].[Picture],
			[ExtendedProperties].[PictureHash],
			[ExtendedProperties].[Gender]
		from	
			[ExtendedProperties]
		where
			[ExtendedProperties].[ID] = [Contact].[ID]
		for xml auto, type, binary base64, elements)
	from	
		[Contact] left outer join [ExtendedProperties]	
			on ([Contact].[ID] = [ExtendedProperties].[ID])
		left outer join [Reminder]
			on ([Contact].[ID] = [Reminder].[ID])
	for xml auto, root('Contacts');

	return 0;
end
go

grant execute on [exch].[ContactBrowse] to [projectmateservice];
go
