﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[ContactUpdate]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure ContactUpdate'
	drop procedure [exch].[ContactUpdate]
end
go

print 'Creating procedure ContactUpdate'
go

create procedure [exch].[ContactUpdate]	@UserID TIdentifier, @XContact xml 
with execute as 'pjmexchangesync'
as
begin
	
	set nocount on;

	DECLARE @EmployeeClass TClass, @CurrentUserID TIdentifier
	SET	@EmployeeClass = dbo.adfGetClassByName('Adf.Employee')
	SET @CurrentUserID = dbo.adfGetCurrentUserID()

	DECLARE	@EmployeeID TIdentifier, @FirstName TName, @MiddleName TName, @LastName TName, @FullName TName,
			@BirthDate TDate, @EventTime TDate, @NextInterval int, @Gender int, @Company TName, @Position TName, @UserName TName, @result int,
			@Comments TNotes, @Title TCode, @Suffix TCode, @Initials TCode, @Division TName, @Picture varbinary(max);
	
	SELECT
		@EmployeeID = T.C.value('@ID', 'TIdentifier'),
		@FirstName = T.C.value('@FirstName', 'TName'),
		@MiddleName = T.C.value('@MiddleName', 'TName'),
		@LastName = T.C.value('@LastName', 'TName'),
		@FullName = T.C.value('@FileAs', 'TName'),
		@BirthDate = T.C.value('@BirthDate', 'TDate'),
		@EventTime = CAST(T.C.value('(Reminder/@EventTime)[1]', 'TDateTime') as datetime),
		@NextInterval = T.C.value('(Reminder/@NextInterval)[1]', 'int'),
		@Gender = T.C.value('(ExtendedProperties/Gender)[1]', 'int'),
		@Picture = T.C.value('(ExtendedProperties/Picture)[1]', 'varbinary(max)'),
		@Company = T.C.value('@Company', 'TName'),
		@Position = T.C.value('@Position', 'TName'),
		@Comments = T.C.value('@Comments', 'TNotes'),
		@Title = T.C.value('@Title', 'TCode'),
		@Suffix = T.C.value('@Suffix', 'TCode'),
		@Initials = T.C.value('@Initials', 'TCode'),
		@Division = T.C.value('@Division', 'TName')
	FROM
		@XContact.nodes('Contact') T(C)	

	if exists(SELECT * FROM [Company] WHERE [FileAs] = @Company AND [Own] = 1) or
	   exists(SELECT * FROM [Employee] inner join [Company] on ([Company].[ID] = [Employee].[CompanyID]) where [Employee].[ID] = @EmployeeID AND [Company].[Own] = 1) or
	   exists(select * from [Company] where [ExecutiveEmployeeID] = @EmployeeID or [AccountantEmployeeID] = @EmployeeID)
	begin
		raiserror('#cannotupdateemployee', 18, -1);
		return 1;
	end;

	DECLARE @CompanyID TIdentifier, @PositionID TIdentifier, @DivisionID TIdentifier;
	
	SET @UserName = (SELECT [FileAs] FROM [Employee] WHERE @UserID IS NOT NULL AND [UserID] = @UserID);

	if @FullName is null
	begin
		set @FullName = @FirstName;
		if @FullName is null
			set @FullName = @LastName;
		else
			set @FullName = @FullName + ' ' + @LastName;
	end

	if @FullName is null
	begin
		set @FullName = 'Синхронизация с Microsoft Exchange'
	end


	begin transaction;

	exec @result = [exch].[PositionGetOrCreate] @Position, @UserID, @PositionID output;
	if @@error != 0 or @result != 0
	begin
		rollback transaction;
		return 1;
	end

	exec @result = [exch].[CompanyGetOrCreate] @Company, @UserID, @CompanyID output;
	if @@error != 0 or @result != 0
	begin
		rollback transaction;
		return 1;
	end

	if @CompanyID is not null
	begin
		exec @result = [exch].[DivisionGetOrCreate] @Division, @UserID, @CompanyID, @DivisionID output;
		if @result = 1 or @@error != 0
		begin
			rollback transaction;
			return 1;
		end
	end

	update [Employee]
	set
		[FirstName] = @FirstName,
		[MiddleName] = @MiddleName,
		[LastName] = @LastName,
		[FileAs] = @FullName,
		[BirthDate] = @BirthDate,
		[CompanyID] = @CompanyID,
		[PositionID] = @PositionID,
		[Comments] = @Comments,
		[ModifiedBy] = @CurrentUserID,
		[Modified] = GETDATE(),
		[Title] = @Title,
		[Suffix] = @Suffix,
		[Initials] = @Initials,
		[DivisionID] = @DivisionID
	where
		[ID] = @EmployeeID;

	if @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	update [BusinessCard]
	set
		[FileAs] = @FullName,
		[CompanyID] = @CompanyID,
		[PositionID] = @PositionID,
		[ModifiedBy] = @CurrentUserID,
		[Modified] = getdate()
	where
		[Class] = @EmployeeClass and [ID] = @EmployeeID;

	if @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	exec [exch].[ReminderUpdate] @UserID, @EmployeeClass, @EmployeeID, @EventTime, @NextInterval;
	if @result = 1 or @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	update [ExtendedProperties]
	set
		ExtendedProperties.modify('replace value of (/ExtendedProperties/Values/Gender[1]/text())[1] with sql:variable("@Gender")')
	where 
		[Class] = @EmployeeClass AND [ID] = @EmployeeID
	if @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	if @Picture is not null
	begin
		if exists(select * from [ExtendedProperties] where [Class] = @EmployeeClass AND [ID] = @EmployeeID and [ExtendedProperties].value('(ExtendedProperties/Values/Picture)[1]', 'varbinary(max)') is not null)
		begin
			update [ExtendedProperties]
			set
				ExtendedProperties.modify('replace value of (/ExtendedProperties/Values/Picture[1]/text())[1] with sql:variable("@Picture")')
			where 
				[Class] = @EmployeeClass AND [ID] = @EmployeeID
		end
		else
		begin
			update [ExtendedProperties]
			set
				ExtendedProperties.modify('insert <Picture>{sql:variable("@Picture")}</Picture> into (/ExtendedProperties/Values)[1]')
			where 
				[Class] = @EmployeeClass AND [ID] = @EmployeeID
		end
	end
	else
	begin
		update [ExtendedProperties]
		set
			ExtendedProperties.modify('delete /ExtendedProperties/Values/Picture')
		where 
			[Class] = @EmployeeClass AND [ID] = @EmployeeID
	end
	if @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	exec @result = [exch].[UpdatePhone] @XContact, @EmployeeClass, @EmployeeID;
	if @result = 1 or @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	exec @result = [exch].[UpdateEmail] @XContact, @EmployeeClass, @EmployeeID;
	if @result = 1 or @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	exec @result = [exch].[UpdateAddress] @XContact, @EmployeeClass, @EmployeeID;
	if @result = 1 or @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	if not exists(select * from [dbo].[ExchangeDocumentSync] where [DocumentClass] = @EmployeeClass and [DocumentID] = @EmployeeID and [UserID] = @UserID)
	begin
		insert into [dbo].[ExchangeDocumentSync]
			([DocumentClass], [DocumentID], [UserID])
		values
			(@EmployeeClass, @EmployeeID, @UserID);
		if @@error != 0
		begin
			rollback transaction;
			return 1;
		end
	end

	if not exists(select * from [dbo].[UserContact] where [BusinessCardClass] = @EmployeeClass and [BusinessCardID] = @EmployeeID and [UserID] = @UserID)
	begin
		insert into [dbo].[UserContact] 
			([BusinessCardClass], [BusinessCardID], [UserID])
		values
			(@EmployeeClass, @EmployeeID, @UserID);
		if @@error != 0
		begin
			rollback transaction;
			return 1;
		end
	end


	commit transaction;
	
	exec [exch].[ContactGet] @UserID, @EmployeeID;

	return 0;
end;
go


grant execute on [exch].[ContactUpdate] to [projectmateservice];
go
