﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnPjm7GetBudgetSemaphoreState]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnPjm7GetBudgetSemaphoreState'
		DROP FUNCTION [dbo].[fnPjm7GetBudgetSemaphoreState]
	END

GO

PRINT 'Creating function fnPjm7GetBudgetSemaphoreState'
GO
/******************************************************************************
**		File: fnPjm7GetBudgetSemaphoreState.sql
**		Name: fnPjm7GetBudgetSemaphoreState
**		Desc: Функция возвращает состояние семафора бюджета (в зависимости от
**			сумм)
**
**		This template can be customized:
**              
**		Return values:
**		0 - серый;
**		1 - зеленый;
**		2 - желтый;
**		3 - красный.
**		
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 16.07.2012 17:17:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE FUNCTION fnPjm7GetBudgetSemaphoreState
	(
		@Min					TMoney,
		@Max					TMoney,
		@Total					TMoney,
		@LastCalculationDate	TDate,
		@BudgetState			TState,
		@Enable					TBool
	)
RETURNS int
AS
BEGIN
	
	IF @LastCalculationDate IS NULL OR @BudgetState = 1 OR @Enable = 0
		RETURN 0

	IF (@Total > @Max AND @Total > 0)
		RETURN 3
	ELSE
	BEGIN
		IF  @Min = 0 AND @Total = 0 
			RETURN 1
		ELSE
			IF @Total >= @Min AND @Total <= @Max 
				RETURN 2
		ELSE
			RETURN 1	
	END
	RETURN 1
END
GO
