﻿ IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnPjm6ExchangeSyncAllowCreateProjectEntry]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnPjm6ExchangeSyncAllowCreateProjectEntry'
		DROP FUNCTION [dbo].[fnPjm6ExchangeSyncAllowCreateProjectEntry]
	END

GO

PRINT 'Creating function fnPjm6ExchangeSyncAllowCreateProjectEntry'
GO
/******************************************************************************
**		File: fnPjm6ExchangeSyncAllowCreateProjectEntry.sql
**		Name: fnPjm6ExchangeSyncAllowCreateProjectEntry
**		Desc: Функция проверяет возможность создания и обновления записей для
**				сотрудника при синхронизации записей с Exchange
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: anton.paramonov
**		Date: 13.02.2012
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		01.04.13	SOV				Создание и обновление записей разрешено для пом. рук-ля
*******************************************************************************/
CREATE FUNCTION fnPjm6ExchangeSyncAllowCreateProjectEntry(
	@ProjectID TIdentifier, 
	@EmployeeID TIdentifier
	)
RETURNS BIT
AS
BEGIN
	
	IF @ProjectID IS NULL 
		RETURN 1
	IF dbo.fnPjm5IsProjectMember(@ProjectID, @EmployeeID) = 1 
		RETURN 1
	IF dbo.fnPjm7ExchangeSyncIsProjectManager(@ProjectID, @EmployeeID) = 1 
		RETURN 1
	IF dbo.fnPjm5IsProjectAdministrator(@ProjectID, @EmployeeID) = 1
		RETURN 1
	IF dbo.fnPjm5IsProjectApprover(@ProjectID, @EmployeeID) = 1
		RETURN 1
	IF dbo.fnPjm7IsManagerAssistant(@ProjectID, @EmployeeID) = 1
		RETURN 1

	DECLARE
		@UserID		TIdentifier
	SELECT @UserID = [UserID] FROM [Employee] WHERE [ID] = @EmployeeID AND [State] = 1

	IF @UserID IS NULL
		RETURN 0

	DECLARE
		@ViewAllProjects TBool,
		@Assistant TBool
	SET @ViewAllProjects = dbo.adfHasAccessRightByNameForUser('ViewAllProjects', @UserID) 
	SET @Assistant = dbo.adfHasAccessRightByNameForUser('Assistant', @UserID)
	IF @ViewAllProjects = 1 AND @Assistant = 1
		RETURN 1

	RETURN 0
END
GO

GRANT EXEC ON fnPjm6ExchangeSyncAllowCreateProjectEntry TO PUBLIC
GO
