IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6GetAvailableProjectsForOverdraft]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function pjm6GetAvailableProjectsForOverdraft'
		DROP FUNCTION [dbo].[pjm6GetAvailableProjectsForOverdraft]
	END

GO

PRINT 'Creating function pjm6GetAvailableProjectsForOverdraft'
GO
/******************************************************************************
**		File:	fnPjm6GetAvailableProjectsForOverdraft.sql
**		Name: 	pjm6GetAvailableProjectsForOverdraft
**		Desc:	      
**               c  
**				       
**
*******************************************************************************
**		Date:		Author:		Description:
**		-----		-------		-------------
**    	30.03.09	ENB			 
**		13.07.11	SYV			   UseSubProjects
**		03.04.13	SOV			    . - 
**								     " "
**		04.04.13	SOV			 ,     . - 
*******************************************************************************/
CREATE FUNCTION pjm6GetAvailableProjectsForOverdraft (
	@ManagerID  TIdentifier,
	@ForFinanceManager TBool --   . -
)

RETURNS @Projects TABLE (
		[ID] INT PRIMARY KEY,	
		[RealManHour] TCount NULL, 
		[RealBudget]  TMoney NULL, 
		[EstimatedBudget]  TMoney NULL,
		[ViewFinance] INT NOT NULL DEFAULT 0,
		[ParentProjectID] INT
)

AS 

BEGIN

	DECLARE 
		@today	datetime, 
		@ViewFinance TBool,
		@ViewAllFinance TBool,
		@HasManageProject TBool, 
     	@CurrentEmployeeID  TIdentifier
		--@UseSubProjects		TBool,
		--@value				TVariant

--   
	--EXEC adfParameterGet @Name='UseSubProjects', @Group='Pjm6', @Value = @value OUTPUT
	--SET @UseSubProjects = ISNULL(CAST(@value as bit), 0)
		
	SET @today = GETDATE()
	SET @HasManageProject = dbo.adfHasAccessRight(dbo.adfGetRightID('ManageProject'))
	SET @ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance')) 
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance')) 

	
	INSERT INTO @Projects ( 
		[ID], 
		[RealManHour], 
		[RealBudget], 
		[EstimatedBudget],
		[ViewFinance],
		[ParentProjectID]
	) 
	SELECT
		[Project].[ID],
		dbo.fnPjm6GetProjectManHour([Project].[ID]) / 60.0,
		dbo.fnPjm6GetProjectBudget([Project].[ID]),
		SUM(
			(ISNULL([BusyEntry].[Planned], 0) - ISNULL([BusyEntry].[OvertimeWork], 0)) * ISNULL([Assignment].[StandardRate], 0) +
			 ISNULL([BusyEntry].[OvertimeWork], 0) * COALESCE([Assignment].[OvertimeRate], [Assignment].[StandardRate], 0)
		) / 60.0,
--	 ,     
		CASE 
			WHEN (@ViewAllFinance = 1) 
					OR
				 (@ManagerID IS NOT NULL)
			THEN  
				1
			ELSE
				0
		END,
		[SubProjects].[ProjectID] 
	FROM			
		[Project]
		LEFT OUTER JOIN fnpjm6GetSubprojectsForBrowse() AS [SubProjects]
			ON [SubProjects].[SubprojectID] = [Project].[ID]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		INNER JOIN [Task]
			ON [Task].[ProjectID] = [Project].[ID] AND [Task].[State] IN (2, 3, 5)
		LEFT OUTER JOIN [BusyEntry]
			ON [BusyEntry].[TaskID] = [Task].[ID] AND [BusyEntry].[Date] <= @today
		LEFT OUTER JOIN [Assignment]
			ON [Assignment].[ID] = [BusyEntry].[AssignmentID]
	WHERE
	--   NULL,    ,  ,   
	--    . -	
		(@ManagerID IS NULL OR
		(@ForFinanceManager = 0 AND [Project].[ProjectManagerEmployeeID] = @ManagerID) OR
		(@ForFinanceManager = 1 AND [Project].[FinanceManagerEmployeeID] = @ManagerID)) 
        AND
		[Project].[State] = 2 AND
		ISNULL([ProjectDetail].[PlannedBudget], 0) > 0
	GROUP BY 
		[Project].[ID],
		[SubProjects].[ProjectID]
	HAVING
		dbo.fnPjm6GetProjectBudget([Project].[ID]) >
		SUM(
			(ISNULL([BusyEntry].[Planned], 0) - ISNULL([BusyEntry].[OvertimeWork], 0)) * ISNULL([Assignment].[StandardRate], 0) +
			 ISNULL([BusyEntry].[OvertimeWork], 0) * COALESCE([Assignment].[OvertimeRate], [Assignment].[StandardRate], 0)
		) / 60.0

--  ParentID  NULL   ,    
	--IF @UseSubProjects = 1
	UPDATE @Projects
	SET [ParentProjectID] = NULL
	WHERE
		[ParentProjectID] IS NOT NULL AND
		[ParentProjectID] NOT IN (SELECT [ID] FROM @Projects)

--    ViewFinance
--    ,    
	IF @ViewFinance = 1 AND @ManagerID IS NULL BEGIN
		SELECT 
     		@CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()		
		UPDATE @Projects 
		SET	[ViewFinance] = 1
		WHERE ID IN (
			SELECT
				[Assignment].[ProjectID]
			FROM
				[Assignment] 
			WHERE 	
				[Assignment].[ID] IN (
					SELECT [AssignmentEntry].[AssignmentID]
					FROM   [AssignmentEntry]
					WHERE  
						[AssignmentEntry].[EmployeeID] = @CurrentEmployeeID
				) AND
			   ([Assignment].[State] = 1 AND [Assignment].[FinanceManagement] = 1)
		)
	END

	--     ,     
	IF  @ManagerID IS NULL BEGIN
	--   
		SELECT 
     		@CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()		
		UPDATE @Projects 
		SET	[ViewFinance] = 1
		WHERE ID IN (
			SELECT 
				[Project].[ID]
			FROM 
				[Project]
			WHERE
				([ProjectManagerEmployeeID] = @CurrentEmployeeID AND @HasManageProject = 1) OR 
				([FinanceManagerEmployeeID] = @CurrentEmployeeID AND @ViewFinance = 1)
		)
	END

	RETURN

END
	
GO
