IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnPjm6GetAvailableProjectsForSubProjectBrowse]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnPjm6GetAvailableProjectsForSubProjectBrowse'
		DROP FUNCTION [dbo].[fnPjm6GetAvailableProjectsForSubProjectBrowse]
	END

GO

PRINT 'Creating function fnPjm6GetAvailableProjectsForSubProjectBrowse'
GO
/******************************************************************************
**		File:	fnPjm6GetAvailableProjectsForSubProjectBrowse.sql
**		Name: 	fnPjm6GetAvailableProjectsForSubProjectBrowse
**		Desc:	       
*******************************************************************************
**		Date:		Author:		Description:
**		-----		-------		-------------
**    	14.11.11	MAN			 
**		13.03.13	SOV			     
**								     
**		15.03.13	SOV			          
**		03.04.13	SOV			    . - 
**								     " "
**		22.04.13	SOV			. -      
**		10.04.13	SOV			 . -     ViewAllFinance
**		28.08.14	SAP			   
*******************************************************************************/
CREATE FUNCTION fnPjm6GetAvailableProjectsForSubProjectBrowse (
	@ProjectSelector	int,
	@ActiveProjectID	TIdentifier,
	@NotActiveProjectID TIdentifier,
	@CanCreateCalculation TBool
)

RETURNS @Projects TABLE ([ID] INT PRIMARY KEY, [CustomerCompanyID] TIdentifier, [ViewFinance] INT NOT NULL DEFAULT 0)

AS 
BEGIN

	DECLARE 
		@ViewAllFinance TBool,
		@ViewAllProjects TBool,
		@ManageProject TBool,
		@ManageAllCalculations TBool,
		@ViewFinance TBool,
		@ManageCalculates TBool,
		@CurrentEmployeeID TIdentifier

	SELECT 
		@ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID ('ViewAllFinance')),
		@ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID( 'ViewAllProjects')),
		@ManageProject = dbo.adfHasAccessRight(dbo.adfGetRightID ('ManageProject')),
		@ManageAllCalculations = dbo.adfHasAccessRight(dbo.adfGetRightID ('ManageAllCalculations')),
		@ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID ('ViewFinance')),
		@ManageCalculates = dbo.adfHasAccessRight(dbo.adfGetRightID('ManageCalculates')),
		@CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()

--   
	IF @ViewAllProjects = 1 AND 
	(
		@CanCreateCalculation = 0 OR 
		(
			@ManageAllCalculations = 1 AND @ViewAllFinance = 1 
		)
	)
	BEGIN
		INSERT INTO @Projects ([ID], [ViewFinance], [CustomerCompanyID])
		SELECT
			[Project].[ID], 0, [Project].[CustomerCompanyID]
		FROM
			[Project]
		WHERE
			(@ProjectSelector = 0) 
				OR
			(@ProjectSelector = 1 AND
				( 
					(@ActiveProjectID IS NULL AND [Project].[State] = 2) OR
					(@ActiveProjectID IS NOT NULL AND [Project].[ID] = @ActiveProjectID)
				)
			) 
				OR
			(@ProjectSelector = 2 AND 
				(
					(@NotActiveProjectID IS NULL AND [Project].[State] != 2) OR
					(@NotActiveProjectID IS NOT NULL AND [Project].[ID] = @NotActiveProjectID)
				)
			)
		--    (      )
		IF @ProjectSelector = 0
			INSERT INTO @Projects ([ID], [ViewFinance])
			VALUES (-1, 0)
	END
	ELSE BEGIN 
	
	--  ,    
		INSERT INTO @Projects ([ID], [ViewFinance], [CustomerCompanyID])
		SELECT [Project].[ID], 0, [Project].[CustomerCompanyID]
		FROM   [Project]
			INNER JOIN (	
				SELECT
					[Assignment].[ProjectID]
				FROM
					[Assignment] 
				WHERE 	
					[Assignment].[ID] IN (
						SELECT [AssignmentEntry].[AssignmentID]
						FROM   [AssignmentEntry]
						WHERE  
							[AssignmentEntry].[EmployeeID] = @CurrentEmployeeID
					) AND
				   ([Assignment].[State] = 1)
			--  ,   ,     , 
			--           
				   AND 
				   (
						@CanCreateCalculation = 0 OR
						(
							(@ManageCalculates = 1 OR @ManageAllCalculations = 1)
							AND 
							((@ViewFinance = 1 AND [Assignment].[FinanceManagement] = 1) OR 
							@ViewAllFinance = 1)
						)
				   )
				) AS AP
			ON [Project].[ID] = [AP].[ProjectID] 
			AND	
			((@ProjectSelector = 0) 
				OR
			(@ProjectSelector = 1 AND
				( 
					(@ActiveProjectID IS NULL AND [Project].[State] = 2) OR
					(@ActiveProjectID IS NOT NULL AND [Project].[ID] = @ActiveProjectID)
				)
			) 
				OR
			(@ProjectSelector = 2 AND 
				(
					(@NotActiveProjectID IS NULL AND [Project].[State] != 2) OR
					(@NotActiveProjectID IS NOT NULL AND [Project].[ID] = @NotActiveProjectID)
				)
			))

	--   ,     . ,     , 
	--  ,    
		IF @ManageProject = 1 OR @ViewFinance = 1 BEGIN
			INSERT INTO @Projects ([ID], [ViewFinance], [CustomerCompanyID])
			SELECT
				[Project].[ID], 0, [Project].[CustomerCompanyID]
			FROM
				[Project]
			WHERE
				(
					[Project].[ID] NOT IN (SELECT [ID] FROM @Projects)
				)	
					AND
				(
					([Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID AND @ManageProject = 1)
					OR
					[Project].[ManagerAssistantEmployeeID] = @CurrentEmployeeID
					OR
					([Project].[FinanceManagerEmployeeID] = @CurrentEmployeeID AND @ViewFinance = 1)
				)
					AND	
				((@ProjectSelector = 0) 
					OR
				(@ProjectSelector = 1 AND
					( 
						(@ActiveProjectID IS NULL AND [Project].[State] = 2) OR
						(@ActiveProjectID IS NOT NULL AND [Project].[ID] = @ActiveProjectID)
					)
				) 
					OR
				(@ProjectSelector = 2 AND 
					(
						(@NotActiveProjectID IS NULL AND [Project].[State] != 2) OR
						(@NotActiveProjectID IS NOT NULL AND [Project].[ID] = @NotActiveProjectID)
					)
				))
		END
	END
	
--	     
	IF @ViewAllFinance = 1 
	
	--   
		UPDATE @Projects SET [ViewFinance] = 1
	
	ELSE BEGIN  

	--    	
	--   ,   , . -  . -
		UPDATE @Projects SET [ViewFinance] = 1
		WHERE ID IN (
			SELECT	
				[ID]
			FROM
				[Project] 
			WHERE	
				([ProjectManagerEmployeeID] = @CurrentEmployeeID AND @ManageProject = 1) OR
				dbo.fnPjm7IsFinanceManager([ID], @CurrentEmployeeID) = 1 OR
				dbo.fnPjm7IsManagerAssistant([ID], @CurrentEmployeeID) = 1
		)

	--        
		IF @ViewFinance = 1 BEGIN
			UPDATE @Projects SET [ViewFinance] = 1
			WHERE ID IN (
				SELECT
					[Assignment].[ProjectID]
				FROM
					[Assignment] 
				WHERE 	
					[Assignment].[ID] IN (
						SELECT [AssignmentEntry].[AssignmentID]
						FROM   [AssignmentEntry]
						WHERE  
							[AssignmentEntry].[EmployeeID] = @CurrentEmployeeID
					) AND
					[Assignment].[FinanceManagement] = 1 AND
				   ([Assignment].[State] = 1)
				)
		END

	--  ,      
		UPDATE @Projects SET [ViewFinance] = 1
		WHERE ID IN (
				SELECT
					[Assignment].[ProjectID]
				FROM
					[Assignment] 
				WHERE 	
					[Assignment].[ID] IN (
						SELECT [AssignmentEntry].[AssignmentID]
						FROM   [AssignmentEntry]
						WHERE  
							[AssignmentEntry].[EmployeeID] = @CurrentEmployeeID
					) AND
				   ([Assignment].[State] = 1)
					AND 
				   ([Assignment].[Approver] = 1)	
				)

	END

	RETURN

END
	
GO
