 IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5JournalEmployeeBrowseSelectorDialog')
	BEGIN
		PRINT 'Dropping Procedure pjm5JournalEmployeeBrowseSelectorDialog'
		DROP  Procedure  pjm5JournalEmployeeBrowseSelectorDialog
	END

GO

PRINT 'Creating Procedure pjm5JournalEmployeeBrowseSelectorDialog'
GO
/******************************************************************************
**		File: 
**		Name: pjm5JournalEmployeeBrowseSelectorDialog
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		31.07.12	SOV				   : [Employee].[State] = 1
**		01.04.13	SOV				 ,    . -
*******************************************************************************/
CREATE Procedure pjm5JournalEmployeeBrowseSelectorDialog
	@ProjectID TIdentifier,
	@TaskID TIdentifier
AS
	SET NOCOUNT ON
	DECLARE @CurrentEmployeeID TIdentifier 
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	
	DECLARE
		@ViewAllProjects TBool,
		@Assistant TBool,
		@ExpenseSecretary TBool
		
	SET @ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects')) 
	SET @Assistant = dbo.adfHasAccessRight(dbo.adfGetRightID('Assistant'))
	SET @ExpenseSecretary = dbo.adfHasAccessRightByName('ManageExpenseWithoutAssignment')

	SELECT DISTINCT
		[Employee].[Class],
		[Employee].[ID],
		[Employee].[State],
		[Employee].[FileAs] as [Name],
		[Company].[FileAs] as [Organization],
		[Qualification].[FileAs] as [Qualification]
	FROM
		[Employee]
		INNER JOIN [vwAssignment] AS [Assignment] 
			ON ([Assignment].[EmployeeID] = [Employee].[ID])
		INNER JOIN [Project]
			ON ([Assignment].[ProjectID] = [Project].[ID])
		INNER JOIN [Company]
			ON ([Employee].[CompanyID] = [Company].[ID])
		LEFT OUTER JOIN [Qualification]
			ON ([Employee].[QualificationID] = [Qualification].[ID])
		LEFT OUTER JOIN [TaskAssignment]
			ON ([TaskAssignment].[AssignmentID] = [Assignment].[ID])
	WHERE
		[Employee].[State] = 1 AND
		(	
			@ExpenseSecretary = 1 OR
			@ViewAllProjects = 1 AND @Assistant = 1 OR
			[Assignment].[EmployeeID] = @CurrentEmployeeID OR
			[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID OR
			dbo.fnPjm5IsProjectAdministrator([Assignment].[ProjectID], @CurrentEmployeeID) = 1 OR
			dbo.fnPjm7IsManagerAssistant([Assignment].[ProjectID], @CurrentEmployeeID) = 1
		)
		AND	([Assignment].[State] = 1)
		AND	(@ProjectID IS NULL OR [Assignment].[ProjectID] = @ProjectID)
		AND (@TaskID IS NULL OR ([TaskAssignment].[TaskID] = @TaskID AND [TaskAssignment].[MsAvailable] = 1
		AND ([TaskAssignment].[RemainingWork] != 0
		OR [TaskAssignment].[RemainingOvertimeWork] !=0
		OR [TaskAssignment].[RemainingOvertimeWork] IS NULL)))
	

	RETURN 0
GO

GRANT EXEC ON pjm5JournalEmployeeBrowseSelectorDialog TO PUBLIC
GO
