﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6BudgetLineAndGroupCopy]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6BudgetLineAndGroupCopy'
		DROP PROCEDURE [dbo].[pjm6BudgetLineAndGroupCopy]
	END
GO

PRINT 'Creating procedure pjm6BudgetLineAndGroupCopy'
GO

/******************************************************************************
**		File: pjm6BudgetLineAndGroupCopy.sql
**		Name: pjm6BudgetLineAndGroupCopy
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 24/09/2010 14:20:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		04.07.13	SOV			При копировании поручений бюджетов происходит поиск
**								их соответствий (актуально в случае создания проекта с бюджетом из шаблона)
**		24.07.13	SOV			Поля планирования для линий затрат копируются с соответствующими
**								изменениями из шаблона бюджета
**		09.06.14	SAP			Изменение вызова функции fnPjm5ShiftDate
*******************************************************************************/
CREATE PROCEDURE [pjm6BudgetLineAndGroupCopy]
	@SourceBudgetID		TIdentifier,
	@ReceiveBudgetID	TIdentifier,
	@ReceiveDocumentID	TIdentifier,
	@CopyActualAsPlan	TBool,
	@CopyDataFromBudget	TBool = 0,
	@ParticipantsXML	XML = NULL -- Список ассоциированных участников проекта шаблона
AS
	SET NOCOUNT ON
	
	DECLARE 
		@SourceBudgetVATRate						TPercent,
		@SourceBudgetRatesWithVAT					TBool,
		@SourceBudgetStartDate						TDate,
		@SourceBudgetGroupStartDate					TDate,
		@SourceBudgetWorkLineStartDate				TDate,
		@SourceBudgetExpenseLineStartDate			TDate,
		@SourceBudgetPlanningActivityForWork		TBool,
		@SourceBudgetPlanningExpenseTypeForExpense	TBool,
		@SourceBudgetUseWorkPlanning				TBool,
		@SourceBudgetUseExpensePlanning				TBool,
		@ReceiveBudgetVATRate						TPercent,
		@ReceiveBudgetRatesWithVAT					TBool,
		@ReceiveBudgetStartDate						TDate,
		@ShiftDays									TCount,
		@BudgetWorkLineInitialState					TState,
		@BudgetWorkExpenseInitialState				TState

	SET @BudgetWorkLineInitialState = dbo.adfwfGetInitialState('af97690a-3eb9-41a4-bb20-bd145b566a85')
	IF @BudgetWorkLineInitialState IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	SET @BudgetWorkExpenseInitialState = dbo.adfwfGetInitialState('b8fd335f-1232-4a5a-a823-92225e38f361')
	IF @BudgetWorkExpenseInitialState IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	--Прочитать параметры бюджета-источника
	SELECT
		@SourceBudgetVATRate						= [Budget].[VATRate],
		@SourceBudgetRatesWithVAT					= [Budget].[VATIsIncluded],
		@SourceBudgetStartDate						= [Budget].[StartDate],
		@SourceBudgetPlanningActivityForWork		= [Budget].[PlanningActivityForWork],
		@SourceBudgetPlanningExpenseTypeForExpense	= [Budget].[PlanningExpenseTypeForExpense],
		@SourceBudgetUseWorkPlanning				= [Budget].[UseWorkPlanning],
		@SourceBudgetUseExpensePlanning				= [Budget].[UseExpensePlanning]
	FROM
		[Budget]
	WHERE
		[Budget].[ID] = @SourceBudgetID

	--Прочитать параметры бюджета-приемника
	SELECT
		@ReceiveBudgetVATRate						= [Budget].[VATRate],
		@ReceiveBudgetRatesWithVAT					= [Budget].[VATIsIncluded],
		@ReceiveBudgetStartDate						= [Budget].[StartDate]
	FROM
		[Budget]
	WHERE
		[Budget].[ID] = @ReceiveBudgetID

	--Расчитать приращение для пересчета дат в линиях и группах
	IF @ReceiveBudgetStartDate IS NOT NULL
		SET @ShiftDays = DATEDIFF(day, @SourceBudgetStartDate, @ReceiveBudgetStartDate)
	ELSE
	BEGIN
		DECLARE
			@SourceBudgetMinStartDate	TDate

		SET @SourceBudgetGroupStartDate = (SELECT MIN([StartDate]) FROM [BudgetLineGroup] WHERE [BudgetID] = @SourceBudgetID
			AND [State] = 1)
		SET @SourceBudgetWorkLineStartDate = (SELECT MIN([StartDate]) FROM [BudgetLineWork] WHERE [BudgetID] = @SourceBudgetID
			AND [State] = 1)
		SET @SourceBudgetExpenseLineStartDate = (SELECT MIN([StartDate]) FROM [BudgetLineExpense] WHERE [BudgetID] = @SourceBudgetID
			AND [State] = 1)

		SET @SourceBudgetMinStartDate = (SELECT MIN([Dates].[StartDate]) FROM 
			(SELECT @SourceBudgetGroupStartDate AS [StartDate] UNION
			SELECT @SourceBudgetWorkLineStartDate AS [StartDate] UNION
			SELECT @SourceBudgetExpenseLineStartDate AS [StartDate]) AS [Dates])
		IF @SourceBudgetMinStartDate IS NOT NULL
			SET @ShiftDays = DATEDIFF(day, @SourceBudgetMinStartDate, @ReceiveBudgetStartDate)
	END

	BEGIN TRANSACTION
	--Скопировать виды деятельности и типы затрат
	IF @CopyDataFromBudget = 1
	BEGIN
	
		IF @SourceBudgetUseWorkPlanning = 1 AND @SourceBudgetPlanningActivityForWork = 1
		BEGIN
			INSERT INTO [ProjectActivityType]
				([ProjectID], [ActivityTypeID], [Billable], [Actively])
			SELECT DISTINCT
				@ReceiveDocumentID, 
				[ActivityTypeID],
				[Billable],
				1
			FROM [BudgetLineWork]
				INNER JOIN [ActivityType]
					ON [BudgetLineWork].[ActivityTypeID] = [ActivityType].[ID] 
			WHERE [BudgetID] = @SourceBudgetID AND [ActivityTypeID] NOT IN (SELECT [ActivityTypeID] FROM [ProjectActivityType] WHERE [ProjectID] = @ReceiveDocumentID)
			IF @@ERROR != 0
				RETURN 1
		END
		IF @SourceBudgetUseExpensePlanning = 1 AND @SourceBudgetPlanningExpenseTypeForExpense = 1
		BEGIN
			INSERT INTO [ProjectExpenseCode]
				([ProjectID], [ExpenseCodeID], [Billable], [Actively])
			SELECT DISTINCT
				@ReceiveDocumentID, 
				[ExpenseCodeID],
				[Billable],
				1
			FROM [BudgetLineExpense]
				INNER JOIN [ExpenseCode]
					ON [BudgetLineExpense].[ExpenseCodeID] = [ExpenseCode].[ID] 
			WHERE [BudgetID] = @SourceBudgetID AND [ExpenseCodeID] NOT IN (SELECT [ExpenseCodeID] FROM [ProjectExpenseCode] WHERE [ProjectID] = @ReceiveDocumentID)
			IF @@ERROR != 0
				RETURN 1
		END
	END
	--Скопировать линии бюджета которые имеют группу
	DECLARE @BudgetGroupID TIdentifier,
			@BudgetGroupType	TIdentifier

	DECLARE SourceBudgetGroupCursor CURSOR FOR
		SELECT [ID], [GroupTypeID] FROM [BudgetLineGroup] WHERE [BudgetID] = @SourceBudgetID AND [State] = 1
		UNION
		SELECT NULL, 1
		UNION
		SELECT NULL, 2
	OPEN SourceBudgetGroupCursor
	FETCH NEXT FROM SourceBudgetGroupCursor INTO @BudgetGroupID, @BudgetGroupType
	WHILE @@FETCH_STATUS = 0
	BEGIN
		--Скопировать группу в новый бюджет
		DECLARE @NewBudgetGroupID	TIdentifier

		IF @BudgetGroupID IS NOT NULL AND ((@BudgetGroupType = 1 AND @SourceBudgetUseWorkPlanning = 1) OR 
			(@BudgetGroupType = 2 AND @SourceBudgetUseExpensePlanning = 1))
		BEGIN
			INSERT INTO [BudgetLineGroup]
				([State], [BudgetID], [FileAs], [StartDate], [EndDate], [Order], [GroupTypeID])
			SELECT
				[State], @ReceiveBudgetID, [FileAs], [StartDate] + @ShiftDays, [EndDate] + @ShiftDays, [Order], [GroupTypeID]
			FROM
				[BudgetLineGroup]
			WHERE
				[BudgetLineGroup].[ID] = @BudgetGroupID
			IF @@ERROR != 0
				RETURN 1
			SET @NewBudgetGroupID = SCOPE_IDENTITY()
		END

		-- Заполнение таблицы аасоциированных участников проекта
		DECLARE @ParticipantTable TABLE
		(
			[AssignmentID] int,
			[EmployeeID] int,
			[MappedEmployeeID] int
		)
	
		INSERT INTO @ParticipantTable
		SELECT
			[XmlTable].value('AssignmentID[1]', 'int'),
			[XmlTable].value('EmployeeID[1]', 'int'),
			[XmlTable].value('MappedEmployeeID[1]', 'int')
		FROM 
			@ParticipantsXML.nodes('ProjectParticipants/Participants') AS List(XmlTable)

		DECLARE @SourceProjectID INT,
				@ProjectShiftDays INT,
				@BaseDate DateTime
				
		-- Выборка информации для корректировки дат линий работ, когда проекты бюджетов разные
		SELECT
			@SourceProjectID = [Budget].[DocumentID],
			@BaseDate = [Project].[Date]
		FROM 
			[Budget] 
			INNER JOIN [Project]
				ON [Project].[ID] = [Budget].[DocumentID]
		WHERE [Budget].[ID] = @SourceBudgetID

		SELECT
			@ProjectShiftDays = DATEDIFF(day, @BaseDate, [Date])
		FROM
			[Project]
		WHERE [ID] = @ReceiveDocumentID

		-- Таблица соответствия поручений, если проекты шаблонов отличаются (в случае создания проекта из шаблона)
		DECLARE @TRTable table
		(
			[Row] int,
			[OldID] int,
			[NewID] int
		)
			
		INSERT INTO @TRTable ([Row], [OldID])
		SELECT ROW_NUMBER() OVER(ORDER BY [ID]), [ID] FROM [TaskRequest] WHERE [ProjectID] = @SourceProjectID

		UPDATE @TRTable
		SET [NewID] = [TNew].[ID]
		FROM
			(SELECT [ID], ROW_NUMBER() OVER(ORDER BY [ID]) AS [RowNew] FROM [TaskRequest] WHERE [ProjectID] = @ReceiveDocumentID) AS [TNew]
		WHERE
			[TNew].[RowNew] = [Row]

		--Скопировать линии бюджета этой группы
		IF @BudgetGroupType = 1 AND @SourceBudgetUseWorkPlanning = 1
		BEGIN	
			DECLARE
				@RateTable TABLE ([ID] TIdentifier, [Rate] TMoney, [PlannedManHour] TAmount)			

			INSERT INTO @RateTable
				([ID], [Rate], [PlannedManHour])
			SELECT
				[ID],
				(CASE WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 1 AND @SourceBudgetRatesWithVAT = 1 THEN
						[Rate]
					WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 1 AND @SourceBudgetRatesWithVAT = 0 THEN
						[Rate] * (1 + @ReceiveBudgetVATRate)
					WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 0 AND @SourceBudgetRatesWithVAT = 1 THEN
						[Rate] / (1 + ISNULL(@SourceBudgetVATRate, 0))
					WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 0 AND @SourceBudgetRatesWithVAT = 0 THEN
						[Rate]
					WHEN @ReceiveBudgetVATRate IS NULL AND @SourceBudgetRatesWithVAT = 1 THEN
						[Rate] / (1 + ISNULL(@SourceBudgetVATRate, 0))
					WHEN @ReceiveBudgetVATRate IS NULL AND @SourceBudgetRatesWithVAT = 0 THEN
						[Rate]
				END) AS [Rate],
				(CASE WHEN @CopyActualAsPlan = 0 THEN [PlannedManHour]
					WHEN @CopyActualAsPlan = 1 THEN [ActualManHour]
				END) AS [PlannedManHour]
			FROM
				[BudgetLineWork]
			WHERE
				[BudgetID] = @SourceBudgetID AND [State] = 1 AND 
					((@BudgetGroupID IS NOT NULL AND [BudgetLineGroupID] = @BudgetGroupID) OR (@BudgetGroupID IS NULL AND [BudgetLineGroupID] IS NULL))
			IF @@ERROR != 0
				RETURN 1

			INSERT INTO [BudgetLineWork]
				([State], [FileAs],[BudgetID],[Comments],[BudgetLineGroupID],[Order],[Rate],
				[EmployeeID],[ActivityTypeID],[QualificationID], [Own], [PlannedManHour],[DocumentClass],[DocumentID],
				[StartDate], [EndDate], [TotalPCPlannedManHour],[TotalWithVATPCPlannedManHour])	
			SELECT DISTINCT
				@BudgetWorkLineInitialState, [FileAs], @ReceiveBudgetID,[Comments],@NewBudgetGroupID,[Order],[Rates].[Rate],
				ISNULL([MappedEmployeeID], ISNULL([Participant].[EmployeeID], [BudgetLineWork].[EmployeeID])),
				[ProjectActivityType].[ActivityTypeID], [QualificationID], [Own], [Rates].[PlannedManHour],[DocumentClass], [NewID],
				CASE 
					WHEN [StartDate] IS NOT NULL THEN dbo.fnPjm5ShiftDate([StartDate], @ProjectShiftDays,1)
					ELSE NULL
				END,
				CASE 
					WHEN [EndDate] IS NOT NULL THEN dbo.fnPjm5ShiftDate([EndDate], @ProjectShiftDays,1)
					ELSE NULL
				END,
				CASE WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 1 THEN
						[Rates].[PlannedManHour] * [Rates].[Rate] - ROUND([Rates].[PlannedManHour] * [Rates].[Rate] * @ReceiveBudgetVATRate, 2) / (1 + @ReceiveBudgetVATRate)
					WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 0 THEN
						[Rates].[PlannedManHour] * [Rates].[Rate]
					WHEN @ReceiveBudgetVATRate IS NULL THEN
						[Rates].[PlannedManHour] * [Rates].[Rate]
				END AS [TotalPCPlannedManHour],
				CASE WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 1 THEN
						[Rates].[PlannedManHour] * [Rates].[Rate]
					WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 0 THEN
						[Rates].[PlannedManHour] * [Rates].[Rate] + ROUND([Rates].[PlannedManHour] * [Rates].[Rate] * @ReceiveBudgetVATRate, 2)
					WHEN @ReceiveBudgetVATRate IS NULL THEN
						[Rates].[PlannedManHour] * [Rates].[Rate]
				END AS [TotalWithVATPCPlannedManHour]
			FROM
				[BudgetLineWork]
			INNER JOIN @RateTable AS [Rates]
				ON [Rates].[ID] = [BudgetLineWork].[ID]
			LEFT OUTER JOIN [ProjectActivityType]
				ON [ProjectActivityType].[ActivityTypeID] = [BudgetLineWork].[ActivityTypeID] AND [ProjectActivityType].[ProjectID] = @ReceiveDocumentID
			LEFT JOIN @TRTable AS [TR]
				ON [TR].[OldID] = [DocumentID]
			LEFT JOIN @ParticipantTable AS [Participant]
				ON [Participant].[AssignmentID] = [BudgetLineWork].[AssignmentID]
			WHERE
				[BudgetID] = @SourceBudgetID AND [State] = 1 AND 
				((@BudgetGroupID IS NOT NULL AND [BudgetLineGroupID] = @BudgetGroupID) OR (@BudgetGroupID IS NULL AND [BudgetLineGroupID] IS NULL))
			IF @@ERROR != 0
				RETURN 1

		END
		ELSE IF @BudgetGroupType = 2 AND @SourceBudgetUseExpensePlanning = 1
		BEGIN
			DECLARE
				@AmountTable TABLE ([ID] TIdentifier, [PlannedAmount] TAmount, [PlanPurchaseAmount] TAmount)

			INSERT INTO @AmountTable
				([ID], [PlannedAmount], [PlanPurchaseAmount])
			SELECT
				[ID],
				(CASE WHEN @CopyActualAsPlan = 0 THEN [PlannedAmount]
					WHEN @CopyActualAsPlan = 1 THEN [ActualAmount]
				END) AS [PlannedAmount],
				[PlanPurchaseAmount]
			FROM
				[BudgetLineExpense]
			WHERE
				[BudgetID] = @SourceBudgetID AND [State] = 1 AND 
				((@BudgetGroupID IS NOT NULL AND [BudgetLineGroupID] = @BudgetGroupID) OR (@BudgetGroupID IS NULL AND [BudgetLineGroupID] IS NULL))
			IF @@ERROR != 0
				RETURN 1

			INSERT INTO [BudgetLineExpense]
				([State],[FileAs],[BudgetID], [EmployeeID], [ExpenseCodeID], [ExpenseID],
				[CurrencyCode], [UOMID], [BudgetLineGroupID], [Order], [Price], [PlanPurchasePrice], [PlannedAmount], [PlanPurchaseAmount], [Comments],
				[VATIsIncluded], [PlanPurchaseVATIsIncluded],[CurrencyRate], [VATRate], [VATPlannedExpense],
				[DocumentClass], [DocumentID], [TotalPCPlannedExpense], [TotalWithVATPCPlannedExpense],
				[VATPlanPurchase], [TotalPlanPurchase], [TotalWithVATPlanPurchase], [VATPCPlanPurchase], [TotalPCPlanPurchase], [TotalWithVATPCPlanPurchase],
				[StartDate], [EndDate])	
			SELECT DISTINCT
				@BudgetWorkExpenseInitialState, [FileAs], @ReceiveBudgetID, 
				ISNULL([MappedEmployeeID], ISNULL([Participant].[EmployeeID], [BudgetLineExpense].[EmployeeID])), 
				[ProjectExpenseCode].[ExpenseCodeID], [ExpenseID],
				[CurrencyCode], [UOMID], @NewBudgetGroupID, [Order], [Price], [PlanPurchasePrice], [Amounts].[PlannedAmount], [Amounts].[PlanPurchaseAmount], [Comments],
				[VATIsIncluded], [PlanPurchaseVATIsIncluded], [CurrencyRate], [VATRate], [VATPlannedExpense],
				[DocumentClass], [NewID], [TotalPCPlannedExpense], [TotalWithVATPCPlannedExpense],
				[VATPlanPurchase], [TotalPlanPurchase], [TotalWithVATPlanPurchase], [VATPCPlanPurchase], [TotalPCPlanPurchase], [TotalWithVATPCPlanPurchase],
				CASE 
					WHEN [StartDate] IS NOT NULL THEN dbo.fnPjm5ShiftDate([StartDate], @ProjectShiftDays,1)
					ELSE NULL
				END,
				CASE 
					WHEN [EndDate] IS NOT NULL THEN dbo.fnPjm5ShiftDate([EndDate], @ProjectShiftDays,1)
					ELSE NULL
				END
			FROM
				[BudgetLineExpense]
			INNER JOIN @AmountTable AS [Amounts]
				ON [Amounts].[ID] = [BudgetLineExpense].[ID]
			LEFT OUTER JOIN [ProjectExpenseCode]
				ON [ProjectExpenseCode].[ExpenseCodeID] = [BudgetLineExpense].[ExpenseCodeID] AND [ProjectExpenseCode].[ProjectID] = @ReceiveDocumentID
			LEFT JOIN @TRTable AS [TR]
				ON [TR].[OldID] = [DocumentID]
			LEFT JOIN @ParticipantTable AS [Participant]
				ON [Participant].[AssignmentID] = [BudgetLineExpense].[AssignmentID]
			WHERE
				[BudgetID] = @SourceBudgetID AND [State] = 1 AND 
				((@BudgetGroupID IS NOT NULL AND [BudgetLineGroupID] = @BudgetGroupID) OR (@BudgetGroupID IS NULL AND [BudgetLineGroupID] IS NULL))
			IF @@ERROR != 0
				RETURN 1

		END
		FETCH NEXT FROM SourceBudgetGroupCursor INTO @BudgetGroupID, @BudgetGroupType
	END
	CLOSE SourceBudgetGroupCursor
	DEALLOCATE SourceBudgetGroupCursor

	COMMIT TRANSACTION

	RETURN 0
GO

GRANT EXECUTE ON pjm6BudgetLineAndGroupCopy TO PUBLIC
GO