IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5CalculationAddServiceRequestLines]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5CalculationAddServiceRequestLines'
		DROP PROCEDURE [dbo].[pjm5CalculationAddServiceRequestLines]
	END
GO

PRINT 'Creating procedure pjm5CalculationAddServiceRequestLines'
GO

/******************************************************************************
**		File: pjm5CalculationAddServiceRequestLines.sql
**		Name: pjm5CalculationAddServiceRequestLines
**		Desc:       
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 05.07.2012 15:06:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		04.03.13	SOV				 OPENXML  XML
**		05.04.13	SOV				   . -
*******************************************************************************/
CREATE PROCEDURE pjm5CalculationAddServiceRequestLines
	@CalculationID TIdentifier,
	@Xml xml
AS
SET NOCOUNT ON
	DECLARE
			@ID TIdentifier,
			@DocumentClass TClass,
			@RatesWithVAT TBool,
			@ProjectID TIdentifier,
			@State	TState,
			@Scale TCount,
			@VATRate TPercent,
			@EmployeeID TIdentifier,
			@doc int

	DECLARE @lines TABLE (
		[DocumentID] int,
		[Description] nvarchar(max)
		)
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()

	SELECT 
		@ID = [Calculation].[ID],
		@DocumentClass = [Calculation].[DocumentClass],
		@RatesWithVAT = [RatesWithVAT],
		@ProjectID = [Calculation].[ProjectID],
		@Scale = [Calculation].[Scale],
		@VATRate = [Calculation].[VATRate],
		@State = [Calculation].[State]
	FROM
		[Calculation]
	WHERE
		[ID] = @CalculationID

	IF dbo.adfHasAccessRightByName('ManageAllCalculations') = 0 AND
		dbo.fnPjm5IsProjectManager(@ProjectID, @EmployeeID) = 0 AND
		dbo.fnPjm5IsProjectMember(@ProjectID, @EmployeeID) = 0  AND
		dbo.fnPjm7IsFinanceManager(@ProjectID, @EmployeeID) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
			
	IF ISNULL(@State, 0) = 3
	BEGIN
		RAISERROR('#TransitionTemplateCouldNotBeFound', 18, -1)
		RETURN 1
	END
	
	INSERT INTO @lines
	SELECT
		list.value('DocumentID[1]', 'int'),
		list.value('Description[1]', 'nvarchar(max)')
	FROM
		@Xml.nodes('/pjm5CalculationGet/CalculationLine') as List(list)
			
	BEGIN TRANSACTION

	INSERT INTO [CalculationLine] ([CalculationID], [DocumentClass], [DocumentID], [Description], [Amount], [Price], [VATIsIncluded], [VAT])
	SELECT
		@ID, 
		@DocumentClass, 
		l.[DocumentID], 
		l.[Description],
		1, 
		CASE 
			WHEN [ServiceRequest].[VATIsIncluded] = 0 OR @VATRate = 0
				THEN [ServiceRequest].[Total]
			ELSE [ServiceRequest].[TotalWithVAT]
		END,		
		[ServiceRequest].[VATIsIncluded], 
		CASE @VATRate 
			WHEN 0 THEN 0
			ELSE [ServiceRequest].[VAT]
		END
	FROM 
		@lines l
		INNER JOIN [ServiceRequest]
			ON  l.[DocumentID] = [ServiceRequest].[ID] AND @DocumentClass = [ServiceRequest].[Class] 
	WHERE 
		[ServiceRequest].[Billable] = 1 AND
		NOT EXISTS (
			SELECT * 
			FROM [CalculationLine] 
			WHERE [CalculationLine].[CalculationID] = @ID AND 
				[DocumentClass] = @DocumentClass AND [DocumentID] = l.[DocumentID])
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
			
	COMMIT TRANSACTION

	RETURN 0
GO

GRANT EXECUTE ON pjm5CalculationAddServiceRequestLines TO PUBLIC
GO