﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7GetDocumentsForChangeBillableFlagOnCalculationApprove]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7GetDocumentsForChangeBillableFlagOnCalculationApprove'
		DROP PROCEDURE [dbo].[pjm7GetDocumentsForChangeBillableFlagOnCalculationApprove]
	END
GO

PRINT 'Creating procedure pjm7GetDocumentsForChangeBillableFlagOnCalculationApprove'
GO

/******************************************************************************
**		File: pjm7GetDocumentsForChangeBillableFlagOnCalculationApprove.sql
**		Name: pjm7GetDocumentsForChangeBillableFlagOnCalculationApprove
**		Desc: Возвращает список ID документов (ЗОВ или затрат), для которых
**				можно снять флаги к оплате
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Sergey Pelevin
**		Date: 15.08.14
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		
*******************************************************************************/
CREATE PROCEDURE pjm7GetDocumentsForChangeBillableFlagOnCalculationApprove
	@CalculationID TIdentifier
AS
	SET NOCOUNT ON

	DECLARE 
		@ProjectID TIdentifier,
		@Date TDate,
		@DocumentClass TClass,
		@PeriodStart TDate,
		@PeriodEnd TDate,
		@TimeEntryClass TClass = [dbo].[adfGetClassByName]('Pjm5.TimeEntry'),
		@ExpenseClass TClass = [dbo].[adfGetClassByName]('Pjm5.Expense')
		
	SELECT	
		@ProjectID = [Calculation].[ProjectID],		
		@DocumentClass = [Calculation].[DocumentClass],
		@PeriodStart = [Calculation].[PeriodStart],
		@PeriodEnd = DATEADD(DAY,1,[Calculation].[PeriodEnd])
	FROM
		[Calculation]
	WHERE
		[Calculation].[ID] = @CalculationID
				

	IF @DocumentClass <> @TimeEntryClass AND @DocumentClass <> @ExpenseClass
	BEGIN
		RAISERROR('#DocumentHasNoBillableFlag', 18, -1)
		RETURN 1
	END

	

	--Установка значений параметров для вызова функции fnPjm7GetAvailableProjectsForCalculationProjectSelectorDialog,
	--которая возвращает список доступных проектов для сотрудника (используется в диалоге выбора проекта при добавлении линии в калькуляцию)
	DECLARE
		@EmployeeID int = NULL,--Текущий пользователь
		@OnlyActive bit = 1,--Только проекты в состоянии 2 (Открыт)
		@ContractOnly bit = 1,-- Только коммерческие проекты (тип Работа по договорам)
		@OnlyProjectMember bit = 0,--Проекты, в которых текущий пользователь является участником, либо РП, либо ФМП
		@ProjectState int = 2,--Служебный фильтр (не состояние проекта), 2 = фильтр отключен
		@ProjectSelector int = 0,--Служебный фильтр (относится к использованию запросов в проекте), 0 = фильтр отключен
		@SupportsRequestManagement bit = 0--Использование запросов в проекте 0 = не важно

	IF @DocumentClass = @TimeEntryClass
	BEGIN
		--Подготовка списка проектов, в которых будем искать ЗОВ	
		;
		WITH [Projects]([ID]) 
		AS
		(
			SELECT DISTINCT 
				[ProjectID] 
			FROM 
				[TimeEntry] 
			WHERE 
				[ID] IN (
							SELECT 
								[DocumentID]
							FROM 
								[CalculationLine] 
							WHERE 
								[CalculationID] = @CalculationID
						)
		),

		[TimeEntriesInRange]([ID])
		AS
		(
			SELECT
				[ID]
			FROM
				[TimeEntry]
			WHERE
				[ProjectID] IN
				(
					SELECT 
						[Projects].[ID] 
					FROM 
						[Projects]
						INNER JOIN dbo.fnPjm7GetAvailableProjectsForCalculationProjectSelectorDialog 
								(
									@EmployeeID,
									@OnlyActive,
									@ContractOnly,
									@OnlyProjectMember,
									@ProjectState,
									@ProjectSelector,
									@SupportsRequestManagement
								) AS [AvialableProjects]
							ON [Projects].[ID] = [AvialableProjects].[ID]
				)
				AND
				[StartTime] >= @PeriodStart
				AND
				[StartTime] < @PeriodEnd
				AND
				[Billable] = 1
				AND 
				([State] <> 6 AND [State] <> 4)
			EXCEPT
			SELECT
				[DocumentID]
			FROM
				[CalculationLine]
			WHERE
				[CalculationID] = @CalculationID
		)
		SELECT 
			[ID] 
		FROM 
			[TimeEntriesInRange]		
	END
	ELSE IF @DocumentClass = @ExpenseClass
	BEGIN			
		;
		WITH [Projects]([ID]) 
		AS
		(
			SELECT DISTINCT 
				[ProjectID] 
			FROM 
				[Expense] 
			WHERE 
				[ID] IN (
							SELECT 
								[DocumentID]
							FROM 
								[CalculationLine] 
							WHERE 
								[CalculationID] = @CalculationID
						)
		),

		[ExpensesInRange]([ID])
		AS
		(
			SELECT
				[ID]
			FROM
				[Expense]
			WHERE
				[ProjectID] IN 
					(
						SELECT 
							[Projects].[ID] 
						FROM 
							[Projects]
							INNER JOIN dbo.fnPjm7GetAvailableProjectsForCalculationProjectSelectorDialog 
								(
									@EmployeeID,
									@OnlyActive,
									@ContractOnly,
									@OnlyProjectMember,
									@ProjectState,
									@ProjectSelector,
									@SupportsRequestManagement
								) AS [AvialableProjects]
							ON [Projects].[ID] = [AvialableProjects].[ID]
					)
				AND
				[Date] >= @PeriodStart
				AND
				[Date] < @PeriodEnd
				AND
				[Billable] = 1
				AND 
				([State] <> 6 AND [State] <> 4)
			EXCEPT
			SELECT
				[DocumentID]
			FROM
				[CalculationLine]
			WHERE
				[CalculationID] = @CalculationID
		)
		SELECT 
			[ID] 
		FROM 
			[ExpensesInRange]		
	END	

	RETURN 0
GO

GRANT EXECUTE ON pjm7GetDocumentsForChangeBillableFlagOnCalculationApprove TO PUBLIC
GO