IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6AssistantRecurrenceInsert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6AssistantRecurrenceInsert'
		DROP PROCEDURE [dbo].[pjm6AssistantRecurrenceInsert]
	END
GO

PRINT 'Creating procedure pjm6AssistantRecurrenceInsert'
GO

CREATE PROCEDURE pjm6AssistantRecurrenceInsert
	@ProjectID TIdentifier,
	@DocumentType TIdentifier,
	@StartDate TDate,
	@EndDate TDate = NULL,
	@Occurrences TCount = NULL,
	@RecurrenceType TIdentifier,
	@Interval TIdentifier,
	@DayOfWeekMask TIdentifier,
	@Instance TIdentifier,
	@MonthOfYear TIdentifier,
	@DayOfMonth TIdentifier,
	@DayTransferRule TIdentifier	
AS
	SET NOCOUNT ON

	INSERT INTO [AssistantRecurrencePattern]
	(
		[StartDate], [EndDate], [Occurrences], [RecurrenceType], [Interval],	[DayOfWeekMask],
		[Instance], [MonthOfYear], [DayOfMonth], [DayTransferRule]
	)
	SELECT
		@StartDate, @EndDate, @Occurrences, @RecurrenceType, @Interval, @DayOfWeekMask,
		@Instance, @MonthOfYear, @DayOfMonth, @DayTransferRule	
			
	DECLARE @Scope TIdentifier
	SET @Scope = SCOPE_IDENTITY()
			
	IF @DocumentType = 0
	BEGIN
		UPDATE [Project] 
		SET [Project].[CalculationRecurrencePatternID] = @Scope
		WHERE [Project].[ID] = @ProjectID
	END
	ELSE IF @DocumentType = 1
	BEGIN
		UPDATE [Project] 
		SET [Project].[StatementRecurrencePatternID] = @Scope
		WHERE [Project].[ID] = @ProjectID
	END
	ELSE IF @DocumentType = 2
	BEGIN
		UPDATE [Project] 
		SET [Project].[InvoiceRecurrencePatternID] = @Scope
		WHERE [Project].[ID] = @ProjectID
	END

	SELECT SCOPE_IDENTITY() 

	RETURN 0
GO

GRANT EXECUTE ON pjm6AssistantRecurrenceInsert TO PUBLIC
GO




IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6AssistantRecurrenceUpdate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6AssistantRecurrenceUpdate'
		DROP PROCEDURE [dbo].[pjm6AssistantRecurrenceUpdate]
	END
GO

PRINT 'Creating procedure pjm6AssistantRecurrenceUpdate'
GO

CREATE PROCEDURE pjm6AssistantRecurrenceUpdate
	@ID TIdentifier,
	@StartDate TDate,
	@EndDate TDate = NULL,
	@Occurrences TCount = NULL,
	@RecurrenceType TIdentifier,
	@Interval TIdentifier,
	@DayOfWeekMask TIdentifier,
	@Instance TIdentifier,
	@MonthOfYear TIdentifier,
	@DayOfMonth TIdentifier,
	@DayTransferRule TIdentifier	
AS
	SET NOCOUNT ON

	UPDATE
		[AssistantRecurrencePattern]
	SET
		[StartDate] = @StartDate,
		[EndDate] = @EndDate,
		[Occurrences] = @Occurrences,
		[RecurrenceType] = @RecurrenceType,
		[Interval] = @Interval,	
		[DayOfWeekMask] = @DayOfWeekMask,
		[Instance] = @Instance, 
		[MonthOfYear] = @MonthOfYear, 
		[DayOfMonth] = @DayOfMonth, 
		[DayTransferRule] = @DayTransferRule
	WHERE [AssistantRecurrencePattern].[ID] = @ID 

	RETURN 0
GO

GRANT EXECUTE ON pjm6AssistantRecurrenceUpdate TO PUBLIC
GO




IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6AssistantRecurrenceDelete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6AssistantRecurrenceDelete'
		DROP PROCEDURE [dbo].[pjm6AssistantRecurrenceDelete]
	END
GO

PRINT 'Creating procedure pjm6AssistantRecurrenceDelete'
GO

CREATE PROCEDURE pjm6AssistantRecurrenceDelete
	@ID TIdentifier,
	@ProjectID TIdentifier,
	@DocumentType TIdentifier
AS
	SET NOCOUNT ON


	IF @DocumentType = 0 
	BEGIN
		UPDATE [Project] 
		SET [Project].[CalculationRecurrencePatternID] = NULL
		WHERE [Project].[ID] = @ProjectID
	END
	ELSE IF @DocumentType = 1
	BEGIN
		UPDATE [Project] 
		SET [Project].[StatementRecurrencePatternID] = NULL
		WHERE [Project].[ID] = @ProjectID
	END
	ELSE IF @DocumentType = 2
	BEGIN
			UPDATE [Project] 
			SET [Project].[InvoiceRecurrencePatternID] = NULL
			WHERE [Project].[ID] = @ProjectID
	END
	
	DELETE FROM [AssistantRecurrencePattern] WHERE [AssistantRecurrencePattern].[ID] = @ID
	
	IF @@ERROR != 0
		RETURN 1

	RETURN 0
GO

GRANT EXECUTE ON pjm6AssistantRecurrenceDelete TO PUBLIC
GO




IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6AssistantRecurrenceGet]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6AssistantRecurrenceGet'
		DROP PROCEDURE [dbo].[pjm6AssistantRecurrenceGet]
	END
GO

PRINT 'Creating procedure pjm6AssistantRecurrenceGet'
GO

CREATE PROCEDURE pjm6AssistantRecurrenceGet
	@ID TIdentifier
AS
	SET NOCOUNT ON
	
	SELECT
		[StartDate],
		[EndDate],
		[Occurrences],
		[RecurrenceType],
		[Interval],
		[DayOfWeekMask],
		[Instance],
		[MonthOfYear],
		[DayOfMonth],
		[DayTransferRule]
	FROM 
		[AssistantRecurrencePattern]
	WHERE
		[AssistantRecurrencePattern].[ID] = @ID

	IF @@ERROR != 0
		RETURN 1

	RETURN 0
GO

GRANT EXECUTE ON pjm6AssistantRecurrenceGet TO PUBLIC
GO


 