﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7EmployeeNormUpdate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7EmployeeNormUpdate'
		DROP PROCEDURE [dbo].[pjm7EmployeeNormUpdate]
	END
GO

PRINT 'Creating procedure pjm7EmployeeNormUpdate'
GO

/******************************************************************************
**		File: pjm7EmployeeNormUpdate.sql
**		Name: pjm7EmployeeNormUpdate
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Nikita.Golyshev
**		Date: 04.07.14
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		24.07.14	GNV			Испраление ошибки
*******************************************************************************/
CREATE PROCEDURE [dbo].[pjm7EmployeeNormUpdate]
	@Xml XML
AS
	SET NOCOUNT ON

	DECLARE
		@ID TIdentifier,
		@FileAs TName,			
		@EmployeeID TIdentifier,
		@StartDate TDate,
		@NormID TIdentifier,
		@Comments nvarchar(max)

	SELECT
		@ID = [XmlTable].value('ID[1]', 'int'),
		@EmployeeID = [XmlTable].value('EmployeeID[1]', 'int'),
		@StartDate = CAST([XmlTable].value('StartDate[1]', 'varchar(19)') as datetime),
		@NormID = [XmlTable].value('NormID[1]', 'int'),
		@Comments = [XmlTable].value('Comments[1]', 'nvarchar(max)')			
	FROM
		@Xml.nodes('/pjm7EmployeeNormGet/EmployeeNorm') AS List(XmlTable)

	
	DECLARE 
		@EmployeeFileAs TName

	SELECT
		@EmployeeFileAs = [FileAs]
	FROM
		[Employee]
	WHERE
		[ID] = @EmployeeID

	SET @FileAs = 'Норма сотрудника ' + ISNULL(@EmployeeFileAs,'') + ' с ' + CAST(DATEPART(DAY, @StartDate) as nvarchar(2)) + '.' + 
	CAST(DATEPART(MONTH, @StartDate) as nvarchar(2)) + '.' + CAST(DATEPART(YEAR, @StartDate) as nvarchar(4))

	
	IF EXISTS (
		SELECT 1 
		FROM 
			[EmployeeNormEntry]
		WHERE 
			[StartDate] = @StartDate
			AND 
			[EmployeeID] = @EmployeeID
			AND 
			[ID] != @ID
	)
	BEGIN
		RAISERROR('#EmployeeNormDateDublicate', 18, -1)
		RETURN 1
	END


	BEGIN TRANSACTION

	UPDATE 
		[EmployeeNormEntry]
	SET
		[EmployeeID] = @EmployeeID,
		[FileAs] = @FileAs, 
		[StartDate] = @StartDate,
		[NormID] = @NormID,
		[Comments] = @Comments
	WHERE
		[ID] = @ID

	IF @@error <> 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	COMMIT TRANSACTION
	

	EXEC pjm7EmployeeNormGet @ID

	RETURN 0
GO

GRANT EXECUTE ON [pjm7EmployeeNormUpdate] TO PUBLIC
GO
