﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7ExchangeSyncStateUpdateNewDocument]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7ExchangeSyncStateUpdateNewDocument'
		DROP PROCEDURE [dbo].[pjm7ExchangeSyncStateUpdateNewDocument]
	END
GO

PRINT 'Creating procedure pjm7ExchangeSyncStateUpdateNewDocument'
GO

/******************************************************************************
**		File: ExchangeSyncStateUpdateNewDocument.sql
**		Name: pjm7ExchangeSyncStateUpdateNewDocument
**		Desc: Процедура обновляет признак "Новая запись из Exchange"
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 02.03.2012 11:02:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE pjm7ExchangeSyncStateUpdateNewDocument
	@DocumentID		TIdentifier,
	@DocumentClass	TClass,
	@EmployeeID		TIdentifier = NULL,
	@NewDocument	TBool = NULL
AS
	SET NOCOUNT ON
	
	DECLARE
		@CurrentUserID	TIdentifier
	
	IF @EmployeeID IS NULL	
		SET @CurrentUserID = dbo.adfGetCurrentUserID()
	ELSE
		SET @CurrentUserID = (SELECT [UserID] FROM [Employee] WHERE [ID] = @EmployeeID)
	
	BEGIN TRANSACTION
	
	IF @NewDocument = 0
	BEGIN
		DELETE 
			[ExchangeNewImportDocument]
		WHERE
			[ExchangeNewImportDocument].[DocumentClass] = @DocumentClass AND
			[ExchangeNewImportDocument].[DocumentID] = @DocumentID AND 
			[ExchangeNewImportDocument].[UserID] = @CurrentUserID
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END
	ELSE
	BEGIN
		INSERT INTO [ExchangeNewImportDocument] ([DocumentClass], [DocumentID], [UserID], [Date])
		VALUES (@DocumentClass, @DocumentID, @CurrentUserID, GETDATE())
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END

	END
	
	COMMIT TRANSACTION

	RETURN 0
GO

GRANT EXECUTE ON pjm7ExchangeSyncStateUpdateNewDocument TO PUBLIC
GO