IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ExpenseUpdateInternal]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ExpenseUpdateInternal'
		DROP PROCEDURE [dbo].[pjm5ExpenseUpdateInternal]
	END
GO

PRINT 'Creating procedure pjm5ExpenseUpdateInternal'
GO

/******************************************************************************
**		File: pjm5ExpenseUpdateInternal.sql
**		Name: pjm5ExpenseUpdateInternal
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: pavel.boruroev
**		Date: 01/20/2005 16:11:01
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		30.07.10	MAN				 ,    
**									 
**		26.02.14	SAP				 
**		21.03.14	SAP				       
*******************************************************************************/
CREATE PROCEDURE pjm5ExpenseUpdateInternal
	@ID TIdentifier,
	@FileAs TName,
	@EmployeeID TIdentifier,
	@ProjectID TIdentifier,
	@DocumentClass TClass,
	@DocumentID TIdentifier,
	@TaskID TIdentifier,
	@ExpenseCodeID TIdentifier,
	@Date TDateTime,
	@UOMID TIdentifier,
	@Amount TAmount,
	@Billable TBool,
	@Price TMoney,
	@FromCurrencyCode TCode3,
	@ToCurrencyCode TCode3,
	@CurrencyRate TAmount,
	@VATRate TPercent,
	@VATIsIncluded TBool,
	@Vat TMoney,
	@Comments TNotes
AS
	SET NOCOUNT ON
	DECLARE 
		@var TVariant,
		@CurrentEmployeeID TIdentifier,
		@ExpenseSecretary TBool
	
	IF @ProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotDefined', 18, -1)
		RETURN 1
	END

	IF (@DocumentID IS NOT NULL 
		AND @DocumentClass IS NOT NULL
		AND NOT EXISTS(SELECT TOP(1) [ID] FROM [Document] WHERE [Class] = @DocumentClass AND [ID] = @DocumentID))
	BEGIN
		RAISERROR('#CannotRetrieveDeletedDocument', 18, -1)
		RETURN 1
	END

	IF @EmployeeID IS NULL
		SET @EmployeeID = dbo.adfGetCurrentEmployeeID()

	IF @EmployeeID IS NULL
	BEGIN
		RAISERROR('#assignmentnotfound', 18, -1)
		RETURN 1
	END
	
	IF NOT EXISTS(SELECT * FROM [vwAssignment] WHERE [ProjectID] = @ProjectID AND [EmployeeID] = @EmployeeID AND [State]=1)
	BEGIN
		RAISERROR('#notassignedtospecifiedproject', 18, -1)
		RETURN 1
	END

	SET @ExpenseSecretary = dbo.adfHasAccessRightByName('ManageExpenseWithoutAssignment')
	IF dbo.fnPjm5AllowCreateProjectEntry(@ProjectID, @EmployeeID) = 0 AND @ExpenseSecretary = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	IF @Amount IS NULL OR @Amount < 0.0000
	BEGIN
		RAISERROR('#AmountCannotBeNull', 18, -1)
		RETURN 1
	END

	IF @CurrencyRate = 0
	BEGIN
		RAISERROR('#CurrencyRateCannotBeNull', 18, -1)
		RETURN 1
	END
	IF NOT EXISTS (SELECT * FROM [Project] WHERE [ID] = @ProjectID AND [State] = 2)
	BEGIN
		RAISERROR('#ProjectIsNotActive', 18, -1)
		RETURN 1
	END

	IF @TaskID IS NOT NULL AND
		EXISTS (SELECT * FROM [Task] WHERE [ID] = @TaskID AND [State] = 8)
	BEGIN
		RAISERROR('#TaskIsDraft', 18, -1)
		RETURN 1
	END

	IF @ExpenseCodeID IS NULL
	BEGIN
		EXEC adfParameterGet 'ExpenseCodeIsMandatory', 'Pjm5', @var OUTPUT
		IF @var IS NULL OR CAST(@var as BIT) = 1
		BEGIN
			RAISERROR('#expensecodecannotbenull', 18, -1)
			RETURN 1
		END
	END
	
	DECLARE @nationalCurrency TCode3
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @var OUTPUT
	SET @nationalCurrency = CAST(@var as varchar(3))

	DECLARE @TotalWithVATPC TAmount, @TotalPC TAmount
	IF @VATIsIncluded = 1
	BEGIN
		SET @TotalPC = ROUND(@Amount * @Price - @Vat,2)
		SET @TotalWithVATPC = ROUND(@Amount * @Price,2)
	END
	ELSE
	BEGIN
		SET @TotalPC = ROUND(@Amount * @Price,2)
		SET @TotalWithVATPC = ROUND(@Amount * @Price + @Vat,2)
	END

	IF @FromCurrencyCode != @ToCurrencyCode
	BEGIN
		DECLARE 
			@TVWPC money,
			@TVW money,
			@Ttl money,
			@V money			
					
		
		SET @TVWPC = @TotalWithVATPC
		IF @FromCurrencyCode = @nationalCurrency
			SET @TVW = ROUND(@TVWPC / @CurrencyRate,2)
		ELSE
			SET @TVW = ROUND(@TVWPC * @CurrencyRate,2)
		SET @V = ROUND(@TVW*@VATRate/(1+@VATRate),2)
		SET @Ttl = @TVW - @V		
		
		
		SET @TotalWithVATPC = @TVW
		SET @TotalPC = @Ttl		
	END

	UPDATE 
		[Expense]
	SET
		[Expense].[FileAs] = @FileAs,
		[Expense].[EmployeeID] = @EmployeeID,
		[Expense].[ProjectID] = @ProjectID,
		[Expense].[DocumentClass] = @DocumentClass,
		[Expense].[DocumentID] = @DocumentID,
		[Expense].[TaskID] = @TaskID,
		[Expense].[ExpenseCodeID] = @ExpenseCodeID,
		[Expense].[Date] = @Date,
		[Expense].[UOMID] = @UOMID,
		[Expense].[Amount] = @Amount,
		[Expense].[Billable] = @Billable,
		[Expense].[Price] = ROUND(@Price, 2),
		[Expense].[FromCurrencyCode] = @FromCurrencyCode,
		[Expense].[ToCurrencyCode] = @ToCurrencyCode,
		[Expense].[CurrencyRate] = @CurrencyRate,
		[Expense].[VATRate] = @VATRate,
		[Expense].[VAT] = ROUND(@VAT, 2),
		[Expense].[VATIsIncluded] = @VATIsIncluded,
		[Expense].[TotalWithVATPC] = @TotalWithVATPC,
		[Expense].[TotalPC] = @TotalPC,
		[Expense].[Comments] = @Comments,
		[Expense].[Modified] = GETDATE(),
		[Expense].[ModifiedBy] = dbo.adfGetCurrentUserID()
	WHERE
		[Expense].[ID] = @ID

	IF @@ERROR != 0
	BEGIN
		RETURN 1
	END
	

	RETURN 0
GO

GRANT EXECUTE ON pjm5ExpenseUpdateInternal TO PUBLIC
GO
  