IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm6trExpenseForTfaCreate')
	BEGIN
		PRINT 'Dropping Trigger pjm6trExpenseForTfaCreate'
		DROP  Trigger pjm6trExpenseForTfaCreate
	END
GO

/******************************************************************************
**		File:	pjm6trExpenseForTfaCreate
**		Name:	pjm6trExpenseForTfaCreate
**		Desc:	    
**				     
**
**		This template can be customized:
**              
**
**		Auth: pavel.svintsov
**		Date: 02.06.2009
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		02.06.09	SPV				 
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm6trExpenseForTfaCreate'
GO
CREATE TRIGGER pjm6trExpenseForTfaCreate 
ON [Expense] FOR INSERT
AS
BEGIN
    IF @@rowcount = 0
       RETURN
	SET NOCOUNT ON

	DECLARE
		@ServiceRequestClass TClass,
		@TaskRequestClass TClass,
		@IssueClass TClass,
		@ServiceAssignmentClass TClass,
		@Invalid int

	SET @ServiceRequestClass = dbo.adfGetClassByName('Pjm5.ServiceRequest')
	SET @TaskRequestClass = dbo.adfGetClassByName('Pjm5.TaskRequest')
	SET @IssueClass = dbo.adfGetClassByName('Pjm5.Issue')
	SET @ServiceAssignmentClass = dbo.adfGetClassByName('Pjm5.ServiceAssignment')
	SET @invalid = 0
	
	DECLARE @forAdd TABLE
	(
		[ID] TIdentifier,
		[DocumentClass] TClass,
		[DocumentID] TIdentifier
	)

	INSERT INTO @forAdd
	([ID], [DocumentClass], [DocumentId])
	SELECT
		[inserted].[ID],
		[inserted].[DocumentClass],
		[inserted].[DocumentID]
	FROM
		[inserted]
	WHERE
	(	
		[inserted].[State] in (2, 3, 6)
	) AND
	(
		[inserted].[DocumentClass] in (@TaskRequestClass, @ServiceRequestClass, @IssueClass, @ServiceAssignmentClass)
	)

	------------------------- Task Request ----------------------
	SELECT @invalid = count(*)
	FROM
		[TaskRequest]
		INNER JOIN [inserted] AS [Add]
			ON [TaskRequest].[ID] = [Add].[DocumentID] AND
				[TaskRequest].[Class] = [Add].[DocumentClass] AND
				[TaskRequest].[State] not in (2)
		IF @@error != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN
			END

	IF @invalid > 0
	BEGIN
		RAISERROR('#tfaCreateInvalidJobState', 18, -1)
		ROLLBACK TRANSACTION
	END
	
	---------------------- Service Request ------------------------------
	SELECT @invalid = count(*)
	FROM
		[ServiceRequest]
		INNER JOIN [inserted] AS [Add]
			ON [ServiceRequest].[ID] = [Add].[DocumentID] AND
				[ServiceRequest].[Class] = [Add].[DocumentClass] AND
				[ServiceRequest].[State] not in (2, 3)
		IF @@error != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN
			END

	IF @invalid > 0
	BEGIN
		RAISERROR('#tfaCreateInvalidJobState', 18, -1)
		ROLLBACK TRANSACTION
	END
	------------------------- Issue ----------------------
	SELECT @invalid = count(*)
	FROM
		[Issue]
		INNER JOIN [inserted] AS [Add]
			ON [Issue].[ID] = [Add].[DocumentID] AND
				[Issue].[Class] = [Add].[DocumentClass] AND
				[Issue].[State] not in (2, 3, 4, 6)
		IF @@error != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN
			END

	IF @invalid > 0
	BEGIN
		RAISERROR('#tfaCreateInvalidJobState', 18, -1)
		ROLLBACK TRANSACTION
	END
	---------------------- Service Assignment ------------------------------
	SELECT @invalid = count(*)
	FROM
		[ServiceAssignment]
		INNER JOIN [inserted] AS [Add]
			ON [ServiceAssignment].[ID] = [Add].[DocumentID] AND
				[ServiceAssignment].[Class] = [Add].[DocumentClass] AND
				[ServiceAssignment].[State] not in (1)
		IF @@error != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN
			END

	IF @invalid > 0
	BEGIN
		RAISERROR('#tfaCreateInvalidJobState', 18, -1)
		ROLLBACK TRANSACTION
	END
	
END
GO
