IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TimeEntryCreateFromMeetingRequest]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5TimeEntryCreateFromMeetingRequest'
		DROP PROCEDURE [dbo].[pjm5TimeEntryCreateFromMeetingRequest]
	END
GO

PRINT 'Creating procedure pjm5TimeEntryCreateFromMeetingRequest'
GO

/******************************************************************************
**		File: pjm5TimeEntryCreateFromMeetingRequest.sql
**		Name: pjm5TimeEntryCreateFromMeetingRequest
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Dmitry.Kolchev
**		Date: 06/09/2006 15:32:39
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		01.12.09	syv				  [CreatedBy]  [ModifiedBy]   
**		29.07.13	SAP				 ,           
**		07.10.13	BAO				      
**		16.10.13	SOV				    [AmountBeforeFinanceDocumentInsert]
**		21.10.13	SOV				   " ",    
**		19.12.13	SAP				             /
*******************************************************************************/
CREATE PROCEDURE pjm5TimeEntryCreateFromMeetingRequest
	@MeetingRequestID TIdentifier
WITH EXECUTE AS OWNER
AS
	SET NOCOUNT ON
	DECLARE @StartTime TDateTime, @Duration TCount, @ProjectID TIdentifier, @ActivityTypeID TIdentifier,
			@FileAs TName, @Comments TNotes, @Color TColor,
			@BillableForParticipant TBool --  " "      ?

	DECLARE @VATRate TPercent
	SET @VATRate = dbo.fnPjm5GetVATRate()
	
	DECLARE @Employees TABLE
		(ID int)
	
	INSERT INTO @Employees
	SELECT
		[Employee].[ID]
	FROM
		[Employee]		
	WHERE
		[Employee].[CompanyID] IN (SELECT [ID] FROM [Company] WHERE [Own] != 0)
	
	DECLARE curAttendee CURSOR LOCAL FORWARD_ONLY READ_ONLY FOR 
		SELECT [EmployeeID], [Billable] FROM [Attendee] WHERE [MeetingRequestID] = @MeetingRequestID AND [Present] = 1 AND [EmployeeID] IN (SELECT * FROM @Employees)
	OPEN curAttendee
	
	DECLARE @EmployeeID TIdentifier, @OriginatorUserID TIdentifier
	
	DECLARE @OriginatorEmployeeID TIdentifier, @OriginatorPresent bit
	SELECT
		@OriginatorEmployeeID = [OriginatorEmployeeID],
		@OriginatorPresent = [OriginatorPresent], 
		@EmployeeID = [OriginatorEmployeeID],
		@BillableForParticipant = [OriginatorTimeEntryIsBillable]
	FROM [MeetingRequest]
	WHERE [ID] = @MeetingRequestID
	
	SELECT
		@OriginatorUserID = [UserID]
	FROM
		[Employee]
	WHERE
		[ID] = @EmployeeID
	
	WHILE 1 = 1
	BEGIN
		SELECT
			@StartTime = [StartTime],
			@Duration = [Duration],
			@ProjectID = [ProjectID],
			@ActivityTypeID = [ActivityTypeID],
			@FileAs = [FileAs],
			@Comments = [Comments],
			@Color = [Color]
		FROM
			[MeetingRequest]
		WHERE
			[ID] = @MeetingRequestID
			
		DECLARE @AssignmentID TIdentifier, @Rate TMoney, @CurrencyCode TCode3, @RoundedDuration TCount, @Billable TBool

		IF dbo.fnPjm5IsProjectMember(@ProjectID, @EmployeeID) != 1
			SET @ProjectID = NULL

		IF @ProjectID IS NOT NULL
		BEGIN
			SET @AssignmentID = dbo.fnPjm5GetProjectAssignment(@ProjectID, @EmployeeID)
			SET @Rate = dbo.fnPjm5GetEmployeeRate(@EmployeeID, @ProjectID, 0, NULL, 0)
			
			SELECT @CurrencyCode = [CurrencyCode] FROM [Project] WHERE [ID] = @ProjectID
			
			SELECT
				@RoundedDuration = dbo.fnPjm5RoundedDuration(@Duration, [RoundingInterval], [RoundingMode])
			FROM
				[Project]
			WHERE
				[ID] = @ProjectID

			DECLARE @ProjectBillable bit
			
			SET @ProjectBillable = (SELECT [Billable] FROM [Project] WHERE [Project].[ID] = @ProjectID)
			
			IF (@ProjectBillable = 1)
			BEGIN	
				IF @ActivityTypeID IS NOT NULL
				BEGIN
					SELECT @Billable = [Billable] 
					FROM [ProjectActivityType] 
					WHERE [ProjectID] = @ProjectID AND [ActivityTypeID] = @ActivityTypeID
					IF @Billable IS NULL
					BEGIN
						SET @ActivityTypeID = NULL
					END
				END

				IF @ActivityTypeID IS NULL
				BEGIN
					DECLARE @var sql_variant, @ActivityTypeIsMandatory bit
					
					EXEC adfParameterGet 'ActivityTypeIsMandatory', 'Pjm5', @var OUTPUT
					IF @var IS NULL
						SET @ActivityTypeIsMandatory = 1
					ELSE
						SET @ActivityTypeIsMandatory = CAST(@var as BIT)
			
					SELECT @Billable = [Billable] 
					FROM [ProjectActivityType] 
					WHERE [ProjectID] = @ProjectID AND [ActivityTypeID] = @ActivityTypeID
					
					IF (@ActivityTypeID IS NULL AND @Billable IS NULL)
					BEGIN
						SELECT @Billable = [Billable]
						FROM [Project]
						WHERE [Project].[ID] = @ProjectID AND [Project].[ProjectTypeID] = 1
					END
				END
			END
			ELSE
			BEGIN
			SET @Billable = 0
			END
		END
		ELSE
		BEGIN
			DECLARE
				@value				TVariant,	
				@NationalCurrency	TCode3
			
			EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @value OUTPUT
			SET @NationalCurrency = CAST(@value as varchar(3))
			
			SET @AssignmentID = NULL
			SET @Rate = 0
			SET @CurrencyCode = @NationalCurrency
			SET @RoundedDuration = @Duration
			SET @Billable = 0
		END
		
		IF @Billable IS NULL
			SET @Billable = 0

		SET @Billable = @Billable & @BillableForParticipant

		IF @EmployeeID <> @OriginatorEmployeeID OR (@EmployeeID = @OriginatorEmployeeID AND @OriginatorPresent <> 0)
		BEGIN
		INSERT INTO [TimeEntry]
			([Flag], [State], [FileAs], [ActivityTypeID], [EmployeeID], [AssignmentID], [ProjectID], [TaskID], 
				[StartTime], [Duration], [RoundedDuration], [Billable], 
				[Overtime], [Rate], [CurrencyCode], [VATRate], [Color],
				[Comments], [MeetingRequestID], [CreatedBy], [ModifiedBy])
		VALUES
			(0, 1, @FileAs, @ActivityTypeID, @EmployeeID, @AssignmentID, @ProjectID, NULL, 
				@StartTime, @Duration, @RoundedDuration, @Billable, 
				0, @Rate, @CurrencyCode, @VATRate, @Color,
				@Comments, @MeetingRequestID, @OriginatorUserID, @OriginatorUserID)
		END

		IF @@ERROR != 0
		BEGIN
			CLOSE curAttendee
			DEALLOCATE curAttendee
			RETURN 1
		END

		DECLARE @TimeEntryID TIdentifier
		
		SET @TimeEntryID = SCOPE_IDENTITY()

		IF @TimeEntryID IS NOT NULL
		BEGIN
			EXEC pjm5TimeEntryAutoApprove @TimeEntryID, @OriginatorUserID
			IF @@ERROR != 0
			BEGIN
				CLOSE curAttendee
				DEALLOCATE curAttendee
				RETURN 1
			END
		
			INSERT [DocumentContact] ([DocumentClass], [DocumentID], [BusinessCardClass], [BusinessCardID])
			SELECT
				dbo.adfGetClassByName('Pjm5.TimeEntry'),
				@TimeEntryID,
				[BusinessCardClass], 
				[BusinessCardID]
			FROM
				[DocumentContact]
			WHERE
				[DocumentClass] = dbo.adfGetClassByName('Pjm5.MeetingRequest') AND [DocumentID] = @MeetingRequestID
			IF @@ERROR != 0
			BEGIN
				CLOSE curAttendee
				DEALLOCATE curAttendee
				RETURN 1
			END
		END
		FETCH NEXT FROM curAttendee INTO @EmployeeID, @BillableForParticipant
		IF @@FETCH_STATUS != 0	
			BREAK		
	END

	CLOSE curAttendee
	DEALLOCATE curAttendee

	RETURN 0
GO

  
