﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7ReminderForUserCreate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7ReminderForUserCreate'
		DROP PROCEDURE [dbo].[pjm7ReminderForUserCreate]
	END
GO

PRINT 'Creating procedure pjm7ReminderForUserCreate'
GO

/******************************************************************************
**		File: pjm7ReminderForUserCreate.sql
**		Name: pjm7ReminderForUserCreate
**		Desc: Процедура создает напоминание для пользователя
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 12.04.2012 17:55:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		09.04.13	SOV				Удаление пробелов в начале и конце описания напоминания    
*******************************************************************************/
CREATE PROCEDURE [pjm7ReminderForUserCreate]
	@DocumentClass TClass,
	@DocumentID TIdentifier,
	@UserID TIdentifier,
	@ReminderSubtype TCode2,
	@ReminderEventTime TDateTime,
	@ReminderState TState,
	@ReminderInterval TTimeSpan,
	@ReminderDescription TName = NULL,					--Текст напоминания
	@AutoExecute TBool = 0,								--Признак автоматического вызова процедуры
	@Now TDate = NULL									--Время клиента
AS
	SET NOCOUNT ON

	IF @DocumentClass IS NULL OR @DocumentID IS NULL OR @UserID IS NULL
	BEGIN
		RETURN 1
	END

	IF @Now IS NULL
		SET @Now = GETDATE()
	
	--IF DATEADD(minute, -@ReminderInterval, @ReminderEventTime) < @Now
	--	IF @AutoExecute = 0
	--	BEGIN
	--		RAISERROR('#ReminderDateInPast', 18, -1)	
	--		RETURN 1
	--	END
			
		--ELSE
		--	RETURN 0

--TODO: Не создавать объект напоминание, при создании записей, а создавать только по требованию.	
--	IF @ReminderState = 0
--		RETURN 0

	DECLARE 
		@ReminderID TIdentifier, 
		@rv int
		
	EXEC @rv = pjm7ReminderForUserCreateInternal @ReminderID OUTPUT,
		@DocumentClass, @DocumentID, @ReminderSubtype, @ReminderEventTime		
	IF @rv != 0 OR @ReminderID IS NULL
	BEGIN
		RETURN 1
	END
	
	SET @ReminderDescription = RTRIM(LTRIM(@ReminderDescription))	

	IF NOT EXISTS (
		SELECT * FROM [UserReminder]
		WHERE [ReminderID] = @ReminderID AND [UserID] = @UserID
	)
	BEGIN
		IF @ReminderEventTime IS NOT NULL
		BEGIN
			INSERT INTO [UserReminder] ([ReminderID], [UserID], [State],
				[OriginalInterval], [NextInterval], [Description])
			VALUES (@ReminderID, @UserID, @ReminderState, @ReminderInterval,
				@ReminderInterval, @ReminderDescription)
			IF @@ERROR != 0
			BEGIN
				RETURN 1
			END
		END
	END
	ELSE
	BEGIN
		UPDATE [UserReminder] SET
			[State] =	CASE
							WHEN @ReminderEventTime IS NOT NULL THEN @ReminderState
							ELSE 0
						END,
			[OriginalInterval] = @ReminderInterval,
			[NextInterval] = @ReminderInterval,
			[Description] = @ReminderDescription,
			[Modified] = DEFAULT
		WHERE [ReminderID] = @ReminderID AND [UserID] = @UserID
		IF @@ERROR != 0
		BEGIN
			RETURN 1
		END
	END
	
	RETURN 0
GO

GRANT EXECUTE ON [pjm7ReminderForUserCreate] TO PUBLIC
GO