IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7ReminderForUserDismiss]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7ReminderForUserDismiss'
		DROP PROCEDURE [dbo].[pjm7ReminderForUserDismiss]
	END
GO

PRINT 'Creating procedure pjm7ReminderForUserDismiss'
GO

/******************************************************************************
**		File: pjm7ReminderForUserDismiss.sql
**		Name: pjm7ReminderForUserDismiss
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 02.05.2012 11:54:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		16.01.13	SAP				     /
**		07.02.13	SAP				 ,    
*******************************************************************************/
CREATE PROCEDURE [pjm7ReminderForUserDismiss]
	@ReminderID TIdentifier
AS
	SET NOCOUNT ON

	DECLARE 
		@UserID TIdentifier,
		@Subtype TCode2
		
	SET @UserID = dbo.adfGetCurrentUserID()
	
	SELECT
		@Subtype = [Subtype]
	FROM
		[Reminder]
	WHERE
		[ID] = @ReminderID
	
	 
	IF @Subtype = 'CB'
	BEGIN
		DECLARE
			@BirthDate TDate,
			@BirthDateCurrentYear TDate,
			@BirthDateNextYear TDate,
			@CurrentDate TDate = CAST(GETDATE() AS date),
			@HasRights bit = 1
		

		SELECT
			@BirthDate = 
			CASE
				WHEN @HasRights = 0 THEN NULL
				ELSE [Employee].[BirthDate]
			END
		FROM
			[Employee]
			LEFT OUTER JOIN [Reminder]
				ON ([Reminder].[DocumentClass] = [Employee].[Class] AND
					[Reminder].[DocumentID] = [Employee].[ID] AND
					[Reminder].[Subtype] = 'CB')			
		WHERE
			[Reminder].[ID] = @ReminderID

		--  
		SET @BirthDate = CAST(@BirthDate AS date)

		SET @BirthDateCurrentYear = DATEADD(Year,DATEDIFF(Year,@BirthDate,@CurrentDate),@BirthDate)
		SET @BirthDateNextYear = DATEADD(Year,1,@BirthDateCurrentYear)

		DECLARE @t1 TTimeSpan

		SELECT
			@t1 = [OriginalInterval] - DATEDIFF(MINUTE, @BirthDateCurrentYear, @BirthDateNextYear)
		FROM [UserReminder]
		WHERE [ReminderID] = @ReminderID
		AND [UserID] = @UserID



		IF (@t1 IS NOT NULL)
		BEGIN
			UPDATE [UserReminder]
			SET	[OriginalInterval] = @t1,
				[NextInterval] = @t1,
				[Modified] = GETDATE()
			WHERE [ReminderID] = @ReminderID
			AND [UserID] = @UserID
		END
		ELSE
		BEGIN
			DELETE FROM [UserReminder]
			WHERE [ReminderID] = @ReminderID
				AND [UserID] = @UserID
		END


		IF @@ERROR != 0
			RETURN  1
	END
	ELSE
	BEGIN
		UPDATE [UserReminder]
		SET [State] = 0,
			[Modified] = GETDATE()
		WHERE
			[ReminderID] = @ReminderID AND [UserID] = @UserID
		IF @@ERROR != 0
			RETURN  1
	END


	
	RETURN 0
GO

GRANT EXECUTE ON [pjm7ReminderForUserDismiss] TO PUBLIC
GO 
