/*=======================================================================*/
/* Stored procedure:  "" .   . */
/*=======================================================================*/
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pjm5SnapshotInsert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[pjm5SnapshotInsert]
go

create procedure pjm5SnapshotInsert
	@SubscriptionTypeID TIdentifier,
	@DocumentClass TClass,
	@DocumentID TIdentifier,
	@ContainerClass TClass,
	@ContainerID TIdentifier,
	@UserID TIdentifier,
	@Value int,
	@OwnerUserID TIdentifier
as

IF NOT EXISTS
	( SELECT [ID] FROM [User] WHERE [User].[ID] = @OwnerUserID )
	BEGIN
		SET @OwnerUserID = 1
	END

INSERT INTO [Snapshot]
([SubscriptionTypeID], [DocumentClass], [DocumentID],
 [ContainerClass], [ContainerID], [UserID], [Value], [OwnerUserID])
VALUES (@SubscriptionTypeID, @DocumentClass, @DocumentID,
 @ContainerClass, @ContainerID,	@UserID, @Value, @OwnerUserID)
IF @@error != 0
	RETURN 1
 
go

grant execute on [dbo].[pjm5SnapshotInsert] to [public]
go

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pjm5SnapshotDelete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[pjm5SnapshotDelete]
go

create procedure pjm5SnapshotDelete
	@ID TIdentifier
as

DELETE FROM [Snapshot] WHERE [ID] = @ID
IF @@error != 0
	RETURN 1

go

grant execute on [dbo].[pjm5SnapshotDelete] to [public]
go

/*==============================================================*/
/* Stored procedure:  "" .  . */
/*==============================================================*/
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pjm5SnapshotInsert1]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[pjm5SnapshotInsert1]
go

create procedure pjm5SnapshotInsert1
	@SubscriptionTypeID TIdentifier,
	@Xml XML
as
	BEGIN TRANSACTION
	
	INSERT INTO [Snapshot]
	([SubscriptionTypeID], [DocumentClass], [DocumentID],
	 [ContainerClass], [ContainerID], [UserID], [Value], [OwnerUserID])
	SELECT
		@SubscriptionTypeID,
		T.c.value('DocumentClass[1]','smallint'),
		T.c.value('DocumentID[1]','int'),
		T.c.value('ContainerClass[1]','smallint'),
		T.c.value('ContainerID[1]','int'),
		T.c.value('UserID[1]','int'),
		T.c.value('Value[1]','int'),
		CASE WHEN [User].[ID] IS NULL THEN 1 ELSE T.c.value('OwnerUserID[1]','int') END
	FROM
		@Xml.nodes('/SubscriptionTask/SnapshotInsert') AS T(c)
		LEFT OUTER JOIN [User]
			ON [User].[ID] = T.c.value('OwnerUserID[1]','int')
	WHERE
		T.c Is NOT NULL

	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	COMMIT TRANSACTION
	RETURN 0

go

grant execute on [dbo].[pjm5SnapshotInsert1] to [public]
go

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pjm5SnapshotDelete1]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[pjm5SnapshotDelete1]
go

create procedure pjm5SnapshotDelete1
	@Xml XML
as

	DECLARE @tableID TABLE ([ID] int)
	INSERT INTO @tableID ([ID])
	SELECT
		T.c.value('ID[1]','int')
	FROM
		@Xml.nodes('/SubscriptionTask/SnapshotDelete') AS T(c)
	WHERE
		T.c IS NOT NULL

	IF @@ERROR != 0
	BEGIN
		RETURN 1
	END
 
	BEGIN TRANSACTION
	
	DELETE FROM [Snapshot] WHERE [ID] IN (SELECT [ID] FROM @tableID)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	COMMIT TRANSACTION
	
	RETURN 0

go

grant execute on [dbo].[pjm5SnapshotDelete1] to [public]
go