IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7ProjectBrowseSelectorDialogForCalculation]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7ProjectBrowseSelectorDialogForCalculation'
		DROP PROCEDURE [dbo].[pjm7ProjectBrowseSelectorDialogForCalculation]
	END
GO

PRINT 'Creating procedure pjm7ProjectBrowseSelectorDialogForCalculation'
GO

/******************************************************************************
**		File: ProjectBrowseSelectorDialogForCalculation.sql
**		Name: pjm7ProjectBrowseSelectorDialogForCalculation
**		Desc:        
**		       
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      	----------						-----------
**
**		Auth: Oleg.Safarov
**		Date: 03/05/2013 17:26:32
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------
**    	07.04.13	SOV			      
**								  					
*******************************************************************************/
CREATE PROCEDURE [dbo].[pjm7ProjectBrowseSelectorDialogForCalculation]
	@EmployeeID TIdentifier,
	@OnlyActive bit,
	@ContractOnly bit,
	@OnlyProjectMember bit,
	@ProjectState int = 2,
	@ProjectSelector bit = 0,
	@SupportsRequestManagement bit,
	@CurrencyCode TCode3 = NULL,
	@ApplyVAT TBool = NULL,
	@RatesWithVAT TBool = NULL
AS
	SET NOCOUNT ON

DECLARE @ProjectClass TClass
SET @ProjectClass = dbo.adfGetClassByName('Pjm5.Project')
	
IF(@ProjectState < 10)
SELECT DISTINCT
		[Project].[ID],
		[Project].[Class],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		CASE @ContractOnly
			WHEN 1 THEN ISNULL(''+[Project].[ContractNumber]+'  '+CONVERT(varchar(10), [Project].[ContractDate], 104) + ' .', [Project].[FileAs])
			ELSE [Project].[FileAs]
		END AS [FileAs],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[Employee].[FileAs] AS [Manager],
		[Supplier].[FileAs] AS [Supplier],
		[Customer].[FileAs] AS [Customer]
	FROM
		[Project]
		LEFT OUTER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
		LEFT OUTER JOIN [Company] AS [Supplier]
			ON [Supplier].[ID] = [Project].[SupplierCompanyID]
		LEFT OUTER JOIN [Company] AS [Customer]
			ON [Customer].[ID] = [Project].[CustomerCompanyID]
		INNER JOIN 
		dbo.fnPjm7GetAvailableProjectsForCalculationProjectSelectorDialog (
			@EmployeeID,
			@OnlyActive,
			@ContractOnly,
			@OnlyProjectMember,
			@ProjectState,
			@ProjectSelector,
			@SupportsRequestManagement) AS [AvialableProject]
		ON [Project].[ID] = [AvialableProject].[ID]
	WHERE
		(@CurrencyCode IS NULL OR [Project].[CurrencyCode] = @CurrencyCode) AND 
		(@ApplyVAT IS NULL OR [Project].[ApplyVAT] = @ApplyVAT) AND
		(@RatesWithVAT IS NULL OR [Project].[RatesWithVAT] = @RatesWithVAT)
ELSE
BEGIN
	IF(@ProjectState = 11)	
		SELECT DISTINCT
				[Project].[ID],
				[Project].[Class],
				[Project].[State],
				[Project].[Flag],
				[Project].[Date],
				[Project].[Number],
				CASE @ContractOnly
					WHEN 1 THEN ISNULL(''+[Project].[ContractNumber]+'  '+CONVERT(varchar(10), [Project].[ContractDate], 104) + ' .', [Project].[FileAs])
					ELSE [Project].[FileAs]
				END AS [FileAs],
				[Project].[SupplierCompanyID],
				[Project].[ProjectManagerEmployeeID],
				[Project].[CustomerCompanyID],
				[Project].[CustomerFinanceManagerID],
				[Project].[ResponsiblePersonEmployeeID],
				[Project].[Created],
				[Project].[CreatedBy],
				[Project].[Modified],
				[Project].[ModifiedBy],
				[Project].[Timestamp],
				[Employee].[FileAs] AS [Manager],
				[Supplier].[FileAs] AS [Supplier],
				[Customer].[FileAs] AS [Customer],
				[LastDocument].[TimeStamp] 
			FROM
				[Project]
				INNER JOIN dbo.fnPjm7GetAvailableProjectsForCalculationProjectSelectorDialog (
					@EmployeeID,
					@OnlyActive,
					@ContractOnly,
					@OnlyProjectMember,
					0,
					@ProjectSelector,
					@SupportsRequestManagement) AS [AvialableProject]
					ON [Project].[ID] = [AvialableProject].[ID]
				INNER JOIN [LastDocument] 
					ON [LastDocument].[EmployeeID] = @EmployeeID AND 
					[LastDocument].[DocumentClass] = @ProjectClass AND
					[Project].[ID] = [LastDocument].[DocumentID]
				LEFT OUTER JOIN [Employee]
					ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
				LEFT OUTER JOIN [Company] AS [Supplier]
					ON [Supplier].[ID] = [Project].[SupplierCompanyID]
				LEFT OUTER JOIN [Company] AS [Customer]
					ON [Customer].[ID] = [Project].[CustomerCompanyID]
				WHERE [Project].[SupportsRequestManagement] = 1 AND
					(@CurrencyCode IS NULL OR [Project].[CurrencyCode] = @CurrencyCode) AND 
					(@ApplyVAT IS NULL OR [Project].[ApplyVAT] = @ApplyVAT) AND
					(@RatesWithVAT IS NULL OR [Project].[RatesWithVAT] = @RatesWithVAT)
				ORDER BY [LastDocument].[TimeStamp] 

	ELSE
		SELECT DISTINCT
			[Project].[ID],
			[Project].[Class],
			[Project].[State],
			[Project].[Flag],
			[Project].[Date],
			[Project].[Number],
			CASE @ContractOnly
				WHEN 1 THEN ISNULL(''+[Project].[ContractNumber]+'  '+CONVERT(varchar(10), [Project].[ContractDate], 104) + ' .', [Project].[FileAs])
				ELSE [Project].[FileAs]
			END AS [FileAs],
			[Project].[SupplierCompanyID],
			[Project].[ProjectManagerEmployeeID],
			[Project].[CustomerCompanyID],
			[Project].[CustomerFinanceManagerID],
			[Project].[ResponsiblePersonEmployeeID],
			[Project].[Created],
			[Project].[CreatedBy],
			[Project].[Modified],
			[Project].[ModifiedBy],
			[Project].[Timestamp],
			[Employee].[FileAs] AS [Manager],
			[Supplier].[FileAs] AS [Supplier],
			[Customer].[FileAs] AS [Customer],
			[LastDocument].[TimeStamp] 
		FROM
			[Project]
			INNER JOIN dbo.fnPjm7GetAvailableProjectsForCalculationProjectSelectorDialog (
				@EmployeeID,
				@OnlyActive,
				@ContractOnly,
				@OnlyProjectMember,
				0,
				@ProjectSelector,
				@SupportsRequestManagement) AS [AvialableProject]
				ON [Project].[ID] = [AvialableProject].[ID]
			INNER JOIN [LastDocument] 
				ON [LastDocument].[EmployeeID] = @EmployeeID AND 
				[LastDocument].[DocumentClass] = @ProjectClass AND
				[Project].[ID] = [LastDocument].[DocumentID]
			LEFT OUTER JOIN [Employee]
				ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
			LEFT OUTER JOIN [Company] AS [Supplier]
				ON [Supplier].[ID] = [Project].[SupplierCompanyID]
			LEFT OUTER JOIN [Company] AS [Customer]
				ON [Customer].[ID] = [Project].[CustomerCompanyID]
		WHERE
			(@CurrencyCode IS NULL OR [Project].[CurrencyCode] = @CurrencyCode) AND 
			(@ApplyVAT IS NULL OR [Project].[ApplyVAT] = @ApplyVAT) AND
			(@RatesWithVAT IS NULL OR [Project].[RatesWithVAT] = @RatesWithVAT)
		ORDER BY [LastDocument].[TimeStamp] 
END	 
		
RETURN 0
GO

GRANT EXECUTE ON [pjm7ProjectBrowseSelectorDialogForCalculation] TO PUBLIC
GO
