IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm7ProjectBrowseMyControlByState')
	BEGIN
		PRINT 'Dropping Procedure pjm7ProjectBrowseMyControlByState'
		DROP  Procedure  pjm7ProjectBrowseMyControlByState
	END

GO

PRINT 'Creating Procedure pjm7ProjectBrowseMyControlByState'
GO
/******************************************************************************
**		File: pjm7ProjectBrowseMyControlByState.sql
**		Name: pjm7ProjectBrowseMyControlByState
**		Desc:         . -
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		29.04.13	SOV				    
**		05.05.14	BAO				    
*******************************************************************************/
CREATE Procedure [dbo].[pjm7ProjectBrowseMyControlByState]
(
	@StateSelector INT,
	@ForManagerAssistant TBool = 1
)
AS
	SET NOCOUNT ON
	
--    
	IF @ForManagerAssistant = 1 AND dbo.adfHasAccessRight(dbo.adfGetRightID('CanBeProjectManagerAssistant')) = 0 BEGIN
	    RAISERROR('#NotEnoughPermissions', 18, -1)
		RETURN 1
	END

	IF @ForManagerAssistant = 0 AND dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance')) = 0 AND
		dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance')) = 0 BEGIN
	    RAISERROR('#NotEnoughPermissions', 18, -1)
		RETURN 1
	END

	DECLARE @CurrentEmployeeID TIdentifier = dbo.adfGetCurrentEmployeeID()

	SELECT
		[Project].[Class],
		[Project].[ID],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
		[Project].[ProjectTypeID],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[PriorityID],
		[ProjectDetail].[DueDate],
		[Project].[EndDate],
		[Project].[CurrencyCode],
		[Project].[CostCenterID],
		[Project].[ProjectStageID],
		[Budgets].[PlannedManHour] / 60.0 AS [ManHour],
		CASE
			WHEN [AP].[ViewFinance] = 1
			THEN [Project].[Budget]
			ELSE -1
		END AS [Budget],
		[Budgets].[PlannedManHour],
		CASE
			WHEN [AP].[ViewFinance] = 1
			THEN [Budgets].[PlannedBudget]
			ELSE -1
		END AS [PlannedBudget],
		[Project].[Billable],
		[Project].[RoundingInterval],
		[Project].[RoundingMode],
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[ContractEndDate],
		[Project].[ContractSubject],
		[Project].[ServiceLevelID],
		[Project].[ApplyVAT],
		[Project].[InvoiceExpirationPeriod],
		[Project].[InvoiceExpirationPeriodType],
		[Project].[Comments],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[ProjectDetail].[PercentComplete],
		(CAST([ProjectDetail].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[Project].[PaymentCurrencyPoint],
		[Project].[ExchangeSystemName],
		[Project].[IsConsignor],
		[BusinessCard].[FileAs] as 'Consignor',
		[Project].[ConsignorContract],
		[AP].[ParentProjectID] AS [ParentProjectID],
		[Project].[ManagerAssistantEmployeeID],
		[Project].[FinanceManagerEmployeeID]
	FROM
		[Project]
		INNER JOIN dbo.fnPjm7GetAvailableProjectsForProjectManagerAssistantOrFinanceManager(
			@CurrentEmployeeID,
			@StateSelector,
			@ForManagerAssistant) AS AP
			ON [Project].[ID] = AP.ID
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT OUTER JOIN [BusinessCard]
			ON [BusinessCard].[Class] = [Project].[ConsignorClass] AND [BusinessCard].[ID] = [Project].[ConsignorID]
		INNER JOIN dbo.fnPjm7GetProjectsBudgets() AS [Budgets]
			ON [Budgets].[ProjectID] = [Project].[ID]
		
	RETURN 0
GO

GRANT EXEC ON pjm7ProjectBrowseMyControlByState TO PUBLIC
GO