IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportRevenueByClient')
	BEGIN
		PRINT 'Dropping Procedure ReportRevenueByClient'
		DROP  Procedure  ReportRevenueByClient
	END

GO

PRINT 'Creating Procedure ReportRevenueByClient'
GO
/******************************************************************************
**		File: ReportRevenueByClient.sql
**		Name: ReportRevenueByClient
**
**         
**		Return values:
**
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**		Auth: Pavel Svintsov			Date: 13.09.10
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		15.09.14	GNV			    
*******************************************************************************/
CREATE Procedure ReportRevenueByClient
		@CompanyID TIdentifier,
		@ServiceTypeSelector int,
		@ServiceTypeID TIdentifier,		
		@CostCenterSelector int,
		@CostCenterID TIdentifier,
		@DateSelector int,
		@QuartalSelector int,
		@PeriodStart TDate,
		@PeriodEnd TDate,
		@SumByCompanyGroups bit, --   
		@TopN int,
		@InvoiceSelector int,
		@Count int = 0
AS
BEGIN
	SET NOCOUNT ON
	
	IF @CompanyID IS NULL
	BEGIN
		RAISERROR('#CompanyIsNotSelected', 16, -1)
		RETURN 1
	END
	
	DECLARE
		@CostCenterName TName,
		@UserID TIdentifier,
		@ServiceTypeName TName,
		@UserName TName,
		@Sum float,
		@InvoiceState TName,
		@Value TVariant,
		@CustomersCount int			
		
	EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @Value OUTPUT
		
	IF @DateSelector = 0
		BEGIN
			SET @PeriodStart = CAST(YEAR(GETDATE()) AS char(4))+'0101'
			SET @PeriodEnd = CAST((YEAR(GETDATE()) + 1) AS char(4))+'0101'
		END
	ELSE 
		IF @DateSelector = 1
		BEGIN
			SET @PeriodStart = CAST((YEAR(GETDATE()) - 1) AS char(4))+'0101'
			SET @PeriodEnd = CAST(YEAR(GETDATE()) AS char(4))+'0101'
		END 
		ELSE 
			SET @PeriodEnd = DATEADD(day, 1, @PeriodEnd)	
	IF @QuartalSelector = 2 
		SET @PeriodStart = DATEADD(month, 3, @PeriodStart)
	IF @QuartalSelector = 3 
		SET @PeriodStart = DATEADD(month, 6, @PeriodStart)
    IF @QuartalSelector = 4 
		SET @PeriodStart = DATEADD(month, 9, @PeriodStart)
	IF @QuartalSelector != 0 
		SET @PeriodEnd = DATEADD(month, 3, @PeriodStart)

    SET @PeriodEnd = DATEADD(day, -1, @PeriodEnd)		
		
	IF @InvoiceSelector = 0
		SET @InvoiceState = ' '
	ELSE 
		SET @InvoiceState = ' '
		
	IF(@CostCenterSelector = 1 AND @CostCenterID IS NOT NULL)				
		SELECT
			@CostCenterName = [FileAs]
		FROM
			[CostCenter]
		WHERE
			[ID] = @CostCenterID
			
	IF @ServiceTypeSelector = 3 AND @ServiceTypeID IS NOT NULL					
		SELECT
			@ServiceTypeName = [FileAs]
		FROM
			[ServiceType]
		WHERE
			[ID] = @ServiceTypeID
			
	IF @ServiceTypeSelector = 0 
		SET @ServiceTypeName = '    '
	IF @ServiceTypeSelector = 1 
		SET @ServiceTypeName = ''
	IF @ServiceTypeSelector = 2 
		SET @ServiceTypeName = '  '
			
	SET @UserID = dbo.adfGetCurrentUserID()

	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID	
		


	DECLARE @Customers TABLE
	(
		[CustomerID] TIdentifier, 
		[CustomerName] TName NULL, 
		[Value] TMoney NULL
	)

	INSERT INTO @Customers
	([CustomerID], [CustomerName], [Value]) 
	SELECT 	
		[Invoice].[CustomerCompanyID],
		[Company].[FileAs],
		SUM ([InvoiceLine].[TotalBC])
		
	FROM 
		[Invoice]
		INNER JOIN [Company]
			ON [Company].[ID] = [Invoice].[CustomerCompanyID]
		INNER JOIN [InvoiceLine]
			ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
		LEFT OUTER JOIN [ServiceType]
			ON [ServiceType].[ID] = [InvoiceLine].[ServiceTypeID]
		INNER JOIN [Project]
			ON [Project].[ID] = [Invoice].[ProjectID]
		LEFT OUTER JOIN [AdvanceInvoice]
			ON [AdvanceInvoice].[AdvanceInvoiceID] = [Invoice].[ID]
		LEFT OUTER JOIN [Invoice] AS [BaseInvoice]
			ON [AdvanceInvoice].[InvoiceID] = [BaseInvoice].[ID]
	WHERE
		[Invoice].[SupplierCompanyID] = @CompanyID AND
		([BaseInvoice].[State] NOT IN (2,5) OR [BaseInvoice].[State] IS NULL)  AND
		[Invoice].[Date] BETWEEN @PeriodStart AND @PeriodEnd 
		AND
		(
			@CostCenterSelector = 0 OR
			
			@CostCenterID IS NULL AND [Project].[CostCenterID] IS NULL OR
			[Project].[CostCenterID] = @CostCenterID
		) 
		AND
		( 
				@ServiceTypeSelector = 0 
				OR
				@ServiceTypeSelector = 1 AND (([InvoiceLine].[ServiceTypeID] IS NOT NULL AND [ServiceType].[RatesDepended] = 1) OR [InvoiceLine].[ServiceTypeID] IS NULL)
				OR
				@ServiceTypeSelector = 2 AND [ServiceType].[RatesDepended] = 0 
				OR
				@ServiceTypeSelector = 3 AND ISNULL(@ServiceTypeID, 0) = ISNULL([InvoiceLine].[ServiceTypeID], 0)
		) 
		AND
		(
			@InvoiceSelector = 0 AND [Invoice].[State] = 5 OR
			@InvoiceSelector = 1 AND [Invoice].[State] IN (2,5)
		)
	GROUP BY
		[Invoice].[CustomerCompanyID],
		[Company].[FileAs]

	SELECT 
		@CustomersCount = COUNT(*) 
	FROM 
		@Customers
	
	IF @TopN = 0
		SET @TopN = 5		
	ELSE IF @TopN = 1
		SET @TopN = 10
	ELSE IF @TopN = 2
		SET @TopN = @Count
	ELSE
		SELECT @TopN =  @CustomersCount

	SELECT 
		@Sum = SUM([Value]) 
	FROM 
		@Customers



	DECLARE @Result TABLE
	(
		[SortID] int, 
		[CustomerID] TIdentifier, 
		[CustomerName] TName NULL, 
		[Value] int NULL,
		[ParentCompanyID] int			--ID  
	)

	INSERT INTO @Result
	([SortID], [CustomerID], [CustomerName], [Value], [ParentCompanyID])
	SELECT TOP(@TopN)
		1,
		[CustomerID], 
		[CustomerName], 
		[Value],
		[dbo].[fnpjm7CompanyFindSingleParent]([CustomerID])
	FROM
		 @Customers
	ORDER BY 
		[Value] DESC 

	DELETE FROM @Customers
	FROM
		@Customers [C]
		INNER JOIN @Result [R]
			ON [C].[CustomerID] = [R].[CustomerID]

	IF @TopN < @CustomersCount
	BEGIN
		INSERT INTO @Result
		([SortID],[CustomerID], [CustomerName], [Value], [ParentCompanyID])
		SELECT
			2,
			NULL,
			'()',
			SUM([Value]),
			NULL
		FROM 
			@Customers
	END
			
	IF @SumByCompanyGroups = 1
	BEGIN
		--      
		INSERT INTO @Result
		SELECT
			1,
			(
				SELECT
				[C].[ID]
				FROM
				[Company] AS [C]
				WHERE
				[C].[ID] = [R].[ParentCompanyID]
			),
			(
				SELECT
				[C].[FileAs]
				FROM
				[Company] AS [C]
				WHERE
				[C].[ID] = [R].[ParentCompanyID]
			),
			SUM([R].[Value]),
			NULL
		FROM
			@Result AS [R]
		WHERE
			[R].[ParentCompanyID] IS NOT NULL
		GROUP BY
			[R].[ParentCompanyID]

		DELETE FROM @Result WHERE [ParentCompanyID] IS NOT NULL
	END




	SELECT 
		@CostCenterSelector AS [CostCenterSelector],
		ISNULL(@CostCenterName, '( )') AS [CostCenterName],
		@ServiceTypeSelector AS [ServiceTypeSelector],
		ISNULL(@ServiceTypeName, '( )') AS [ServiceTypeName],
		CASE WHEN @QuartalSelector != 0 THEN (CAST(@QuartalSelector AS Char(1)) + '  ') ELSE '' END + CAST(YEAR(@PeriodStart) AS Char(4)) + ' .' AS [Year],
		@UserName AS [UserName],
		@InvoiceState AS [InvoiceState],
		CAST(@Value as nvarchar(32)) AS [CurrencyCode],
		@SumByCompanyGroups AS [SumByCompanyGroups] 
		--CASE WHEN @QuartalSelector != 0 THEN (' ' + CAST(@QuartalSelector AS Char(1)) + ' ') ELSE NULL END
		
	SELECT 
		[CustomerName], 
		[Value],
		[Value]/@Sum AS [Percent],
		[ParentCompanyID]
	FROM 
		@Result
	ORDER BY 
		[SortID], 
		[Value] DESC  
	
	RETURN 0
END
GO

GRANT EXEC ON ReportRevenueByClient TO PUBLIC

GO


