IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportStatement')
	BEGIN
		PRINT 'Dropping Procedure ReportStatement'
		DROP  Procedure  ReportStatement
	END

GO

PRINT 'Creating Procedure ReportStatement'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportStatement
	@ID int,
	@Language TName = NULL	
AS
	SET NOCOUNT ON
	DECLARE
		@TotalValue money,
		@TotalValueWithVAT money,
		@TotalVAT money	,
		@TotalCount int,
		@VATRate decimal(18,4),
		@VATRateCount int,
		@CurrencyCode varchar(8),
		@Currency Tname,
		@AdvanceValue TMoney,
		@AdvanceVAT TMoney,
		@PaymentValue TMoney,
		@PaymentVAT TMoney,
		@Class TClass,
		@Code TName
	SET @Code = CASE WHEN @Language = 'en' THEN 'Act; ' ELSE '; ' END
		
	SELECT
		@Currency = CASE [Project].[StatementCurrency] WHEN 0 THEN 'Project' ELSE 'Payment' END,
		@Class = [Statement].[Class],
		@TotalValue = CASE [Project].[StatementCurrency]
			WHEN 0 THEN [Statement].[TotalPC]
			ELSE [Statement].[Total]
		END,
		@TotalVAT = CASE [Project].[StatementCurrency]
			WHEN 0 THEN [Statement].[VATPC]
			ELSE [Statement].[VAT]
		END,
		@TotalValueWithVAT = CASE [Project].[StatementCurrency]
			WHEN 0 THEN [Statement].[TotalWithVATPC]
			ELSE [Statement].[TotalWithVAT]
		END,
		@CurrencyCode = CASE [Project].[StatementCurrency]
			WHEN 0 THEN [Project].[CurrencyCode]
			ELSE [Statement].[CurrencyCode]
		END	 	
		FROM
		[Statement]
		INNER JOIN [Project]
			ON [Statement].[ProjectID] = [Project].[ID]
	WHERE
		[Statement].[ID] = @ID	
		
	SELECT 
		@AdvanceValue = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [Invoice].[TotalWithVAT]
				WHEN @Currency = 'Project'
					THEN [Invoice].[TotalWithVATPC]
			END, 0.0)),
		@AdvanceVAT = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [Invoice].[VAT]
				WHEN @Currency = 'Project'
					THEN [Invoice].[VATPC]
			END, 0.0))
	FROM
		[StatementAdvanceInvoice] 
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [StatementAdvanceInvoice].[AdvanceInvoiceID]
	WHERE
		[StatementAdvanceInvoice].[StatementID] = @ID
		
	SELECT 
		@PaymentValue = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [StatementAdvanceInvoice].[StatementPaymentValue]
				WHEN @Currency = 'Project'
					THEN [StatementAdvanceInvoice].[StatementPaymentValuePC]
			END, 0.0)),
		@PaymentVAT = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [StatementAdvanceInvoice].[StatementPaymentVAT]
				WHEN @Currency = 'Project'
					THEN [StatementAdvanceInvoice].[StatementPaymentVATPC]
			END, 0.0))
	FROM
		[StatementAdvanceInvoice] 
	WHERE
		[StatementAdvanceInvoice].[StatementID] = @ID
	
	DECLARE @t TABLE(
		[Description] nvarchar(max),
		[Amount] decimal(18,4),
		[Price] money,
		[Sum] money,
		[VAT] money,
		[VATRate] decimal(18,4),
		[PriceWithVAT] money,
		[SumWithVAT] money,
		[UOM] nvarchar(64),
		[ServiceTypeName] nvarchar(256)
	)
	INSERT INTO @t
		(
		[Description],
		[Amount],
		[Price],
		[Sum],
		[VAT],
		[VATRate],
		[PriceWithVAT],
		[SumWithVAT],
		[UOM],
		[ServiceTypeName]
		)
	SELECT
		[StatementLine].[Description] AS [Description],
		[StatementLine].[Amount] AS [Amount],
		CASE 
			WHEN [StatementLine].[VATIsIncluded] = 1 AND @Currency = 'Payment' AND [StatementLine].[Amount] != 0
				THEN ([StatementLine].[Price] * [StatementLine].[Amount] - [StatementLine].[VAT]) / [StatementLine].[Amount]
			WHEN [StatementLine].[VATIsIncluded] = 1 AND @Currency = 'Project' AND [StatementLine].[Amount] != 0
				THEN ([StatementLine].[PricePC] * [StatementLine].[Amount] - [StatementLine].[VATPC]) / [StatementLine].[Amount]	
			WHEN [StatementLine].[VATIsIncluded] = 0 AND @Currency = 'Payment' 
				THEN [StatementLine].[Price]
			WHEN [StatementLine].[VATIsIncluded] = 0 AND @Currency = 'Project' 
				THEN [StatementLine].[PricePC] 	 
		END AS [Price],
		[StatementLine].[Amount] * 	
			CASE 
				WHEN [StatementLine].[VATIsIncluded] = 1 AND @Currency = 'Payment' AND [StatementLine].[Amount] != 0
					THEN ([StatementLine].[Price] * [StatementLine].[Amount] - [StatementLine].[VAT]) / [StatementLine].[Amount]
				WHEN [StatementLine].[VATIsIncluded] = 1 AND @Currency = 'Project' AND [StatementLine].[Amount] != 0
					THEN ([StatementLine].[PricePC] * [StatementLine].[Amount] - [StatementLine].[VATPC]) / [StatementLine].[Amount]	
				WHEN [StatementLine].[VATIsIncluded] = 0 AND @Currency = 'Payment' 
					THEN [StatementLine].[Price]
				WHEN [StatementLine].[VATIsIncluded] = 0 AND @Currency = 'Project' 
					THEN [StatementLine].[PricePC] 
			END AS [Sum],
		CASE	
			WHEN @Currency = 'Payment' 
				THEN [StatementLine].[VAT]
			WHEN @Currency = 'Project' 
				THEN [StatementLine].[VATPC]
		END AS [VAT],		
		[StatementLine].[VATRate],
		CASE 
			WHEN [StatementLine].[VATIsIncluded] = 0 AND @Currency = 'Payment' AND [StatementLine].[Amount] != 0
				THEN ([StatementLine].[Price] * [StatementLine].[Amount] + [StatementLine].[VAT]) / [StatementLine].[Amount]
			WHEN [StatementLine].[VATIsIncluded] = 0 AND @Currency = 'Project' AND [StatementLine].[Amount] != 0
				THEN ([StatementLine].[PricePC] * [StatementLine].[Amount] + [StatementLine].[VATPC]) / [StatementLine].[Amount]	
			WHEN [StatementLine].[VATIsIncluded] = 1 AND @Currency = 'Payment' 
				THEN [StatementLine].[Price]
			WHEN [StatementLine].[VATIsIncluded] = 1 AND @Currency = 'Project' 
				THEN [StatementLine].[PricePC] 	 
		END AS [PriceWithVAT],
		[StatementLine].[Amount] * 	
			CASE 
				WHEN [StatementLine].[VATIsIncluded] = 0 AND @Currency = 'Payment' AND [StatementLine].[Amount] != 0
					THEN ([StatementLine].[Price] * [StatementLine].[Amount] + [StatementLine].[VAT]) / [StatementLine].[Amount]
				WHEN [StatementLine].[VATIsIncluded] = 0 AND @Currency = 'Project' AND [StatementLine].[Amount] != 0
					THEN ([StatementLine].[PricePC] * [StatementLine].[Amount] + [StatementLine].[VATPC]) / [StatementLine].[Amount]	
				WHEN [StatementLine].[VATIsIncluded] = 1 AND @Currency = 'Payment' 
					THEN [StatementLine].[Price]
				WHEN [StatementLine].[VATIsIncluded] = 1 AND @Currency = 'Project' 
					THEN [StatementLine].[PricePC] 
			END AS [SumWithVAT],
		[UOM].[Code],
		[ServiceType].[FileAs]
	FROM
		[StatementLine]		
		LEFT OUTER JOIN [UOM]
			ON [UOM].[ID] = [StatementLine].[UOMID]
		LEFT OUTER JOIN [ServiceType]
			ON [StatementLine].[ServiceTypeID] = [ServiceType].[ID]
	WHERE 
		[StatementLine].[StatementID] = @ID	
	
	SELECT
		@TotalCount = COUNT(*),
		@VATRate = MAX([VATRate]),
		@VATRateCount = COUNT(DISTINCT [VATRate])
	FROM
		@t

	DECLARE @CurrencyClass TClass, @CurrencyID TIdentifier, @CurrencyMale TBool
	SET @CurrencyClass = dbo.adfGetClassByName('Adf.Currency')
	SELECT @CurrencyID = [ID] FROM [Currency] WHERE [Code] = @CurrencyCode
	SET @CurrencyMale = CASE 
		WHEN dbo.adfPropertyValueGetText(@CurrencyClass, @CurrencyID, '00000001-0000-0000-0000-000000000000') = 'False'
			THEN 0
		ELSE 1
	END
	
	SELECT
		[Statement].[FileAs],
		[Statement].[Number],
		[Statement].[Date],
		
		[Project].[FileAs] AS [ProjectName],
		[Project].[Number] AS [ProjectNumber],
		[Project].[ContractNumber] AS [ContractNumber],
		[Project].[ContractDate] AS [ContractDate],

		[Statement].[PeriodStart] AS [PeriodStart],
		[Statement].[PeriodEnd] AS [PeriodEnd],
		@CurrencyCode AS [CurrencyCode],
		@CurrencyMale AS [CurrencyMale],

		CASE
			WHEN [Address].[AddressTypeID] IS NOT NULL 
				THEN [Address].[City] 
			WHEN [LegalAddress].[AddressTypeID] IS NOT NULL 
				THEN [LegalAddress].[City] 
		END AS [City],
		
		[CustomerCompany].[LegalName] AS [CustomerCompany],
		ISNULL(dbo.adfPropertyValueGetText([CustomerExecutivePosition].[Class], 
				[CustomerExecutivePosition].[ID], 
				'00000001-0000-0000-0000-000000000000'),
				[CustomerExecutivePosition].[FileAs]) 
			AS [CustomerExecutivePositionCase],		
		
		COALESCE(dbo.adfPropertyValueGetText([CustomerExecutiveEmployee].[Class], [CustomerExecutiveEmployee].[ID], '00000001-0000-0000-0000-000000000000'),
				[CustomerExecutiveEmployee].[LastName] + ISNULL(' ' + [CustomerExecutiveEmployee].[FirstName], '') + ISNULL(' ' + [CustomerExecutiveEmployee].[MiddleName], ''), 
				[CustomerExecutiveEmployee].[FileAs]) 
			AS [CustomerExecutiveEmployeeCase],
			
		[SupplierCompany].[LegalName] AS [SupplierCompany],
		ISNULL(dbo.adfPropertyValueGetText([SupplierExecutivePosition].[Class], [SupplierExecutivePosition].[ID], '00000001-0000-0000-0000-000000000000'),
				[SupplierExecutivePosition].[FileAs]) 
			AS [SupplierExecutivePositionCase],
		COALESCE(dbo.adfPropertyValueGetText([SupplierExecutiveEmployee].[Class], [SupplierExecutiveEmployee].[ID], '00000001-0000-0000-0000-000000000000'),
				[SupplierExecutiveEmployee].[LastName] + ISNULL(' ' + [SupplierExecutiveEmployee].[FirstName], '') + ISNULL(' ' + [SupplierExecutiveEmployee].[MiddleName], ''), 
				[SupplierExecutiveEmployee].[FileAs])
			AS [SupplierExecutiveEmployeeCase],
			
		@TotalValue AS [TotalValue],
		@TotalVAT AS [TotalVAT],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN @TotalValue
			ELSE @TotalValue + @TotalVAT
		END AS [TotalValueWithVAT],
		CASE
			WHEN @TotalValue IS NULL THEN 0
			ELSE 1
		END	AS [TotalFlag],
		dbo.fnPjm5CurrencyToString(@TotalValue, @CurrencyCode) AS [TotalValueCurrencyCode],
		dbo.fnPjm5CurrencyToString(@TotalVAT, @CurrencyCode) AS [TotalVATCurrencyCode],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN dbo.fnPjm5CurrencyToString(@TotalValue, @CurrencyCode)
			ELSE dbo.fnPjm5CurrencyToString((@TotalValue + @TotalVAT), @CurrencyCode)
		END AS [TotalValueWithVATCurrencyCode],

		@AdvanceValue AS [AdvanceValue],
		@AdvanceVAT AS [AdvanceVAT],
		CASE
			WHEN @AdvanceValue IS NULL THEN 0
			WHEN @AdvanceValue = 0 THEN 0
			ELSE 1 
		END	AS [AdvanceFlag],
		dbo.fnPjm5CurrencyToString(@AdvanceValue, @CurrencyCode) AS [AdvanceValueCurrencyCode],
		dbo.fnPjm5CurrencyToString(@AdvanceVAT, @CurrencyCode) AS [AdvanceVATCurrencyCode],

		@PaymentValue AS [PaymentValue],
		@PaymentVAT AS [PaymentVAT],
		CASE
			WHEN @PaymentValue IS NULL THEN 0
			WHEN @PaymentValue = 0 THEN 0
			ELSE 1 
		END	AS [PaymentFlag],
		dbo.fnPjm5CurrencyToString(ISNULL(@PaymentValue, 0.0), @CurrencyCode) AS [PaymentValueCurrencyCode],
		dbo.fnPjm5CurrencyToString(ISNULL(@PaymentVAT, 0.0), @CurrencyCode) AS [PaymentVATCurrencyCode],

		CASE 
			WHEN @TotalValueWithVAT > ISNULL(@PaymentValue, 0.0)
				THEN @TotalValueWithVAT - ISNULL(@PaymentValue, 0.0) 
			ELSE 0.0
		END AS [RemainValue],
		CASE
			WHEN @TotalVAT > ISNULL(@PaymentVAT, 0.0)
				THEN @TotalVAT - ISNULL(@PaymentVAT, 0.0) 
			ELSE 0.0
		END AS [RemainVAT],
		CASE
			WHEN ISNULL(@PaymentValue, 0.0) > 0 AND 
				ISNULL(@PaymentValue, 0.0) < @TotalValueWithVAT
					THEN 1
			WHEN ISNULL(@PaymentValue, 0.0) > 0 AND 
				ISNULL(@PaymentValue, 0.0) >= @TotalValueWithVAT
					THEN 2
			ELSE 0
		END	AS [RemainFlag],
		CASE
			WHEN @TotalValueWithVAT > ISNULL(@PaymentValue, 0.0)
				THEN dbo.fnPjm5CurrencyToString(@TotalValueWithVAT - ISNULL(@PaymentValue, 0.0), @CurrencyCode) 
			ELSE dbo.fnPjm5CurrencyToString(0.0, @CurrencyCode) 
		END AS [RemainValueCurrencyCode],
		CASE
			WHEN @TotalVAT > ISNULL(@PaymentVAT, 0.0)
				THEN dbo.fnPjm5CurrencyToString(@TotalVAT - ISNULL(@PaymentVAT, 0.0), @CurrencyCode)
			ELSE dbo.fnPjm5CurrencyToString(0.0, @CurrencyCode)
		END AS [RemainVATCurrencyCode],

		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN 0
			WHEN [Project].[ApplyVAT] = 1 AND @VATRateCount = 1 THEN (@VATRate * 100)
			ELSE NULL
		END AS [VATRate],
		CASE
			WHEN [Project].[ApplyVAT] = 1 AND @VATRateCount = 1 THEN 1
			ELSE 0
		END AS [VATFlag],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN 0
			ELSE 1
		END	AS [VATRateFlag],

		dbo.fnPjm5MoneyToString(@TotalValue, @CurrencyCode, 1) AS [TotalValueText],
		dbo.fnPjm5MoneyToString(@TotalVAT, @CurrencyCode, 1) AS [TotalVATText],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN dbo.fnPjm5MoneyToString(@TotalValue, @CurrencyCode, 1)
			ELSE dbo.fnPjm5MoneyToString((@TotalValue + @TotalVAT), @CurrencyCode, 1)
		END AS [TotalValueWithVATText],

		dbo.fnPjm5MoneyToString(ISNULL(@PaymentValue, 0.0), @CurrencyCode, 1) AS [PaymentValueText],
		dbo.fnPjm5MoneyToString(ISNULL(@PaymentVAT, 0.0), @CurrencyCode, 1) AS [PaymentVATText],

		CASE 
			WHEN @TotalValueWithVAT > ISNULL(@PaymentValue, 0.0)
				THEN dbo.fnPjm5MoneyToString(@TotalValueWithVAT - ISNULL(@PaymentValue, 0.0), @CurrencyCode, 1)
			ELSE dbo.fnPjm5MoneyToString(0.0, @CurrencyCode, 1)
		END AS [RemainValueText],
		CASE
			WHEN @TotalVAT > ISNULL(@PaymentVAT, 0.0)
				THEN dbo.fnPjm5MoneyToString(@TotalVAT - ISNULL(@PaymentVAT, 0.0), @CurrencyCode, 1)
			ELSE dbo.fnPjm5MoneyToString(0.0, @CurrencyCode, 1)
		END AS [RemainVATText],
		
		[CustomerExecutivePosition].[FileAs] AS [CustomerExecutivePosition],
		COALESCE(dbo.adfPropertyValueGetText([CustomerExecutiveEmployee].[Class], [CustomerExecutiveEmployee].[ID], '00000002-0000-0000-0000-000000000000'), 
			[CustomerExecutiveEmployee].[LastName] + ISNULL(' ' + [CustomerExecutiveEmployee].[FirstName], '') + ISNULL(' ' + [CustomerExecutiveEmployee].[MiddleName], ''), [CustomerExecutiveEmployee].[FileAs], '                            ') AS [CustomerExecutiveEmployee],
		[SupplierExecutivePosition].[FileAs] AS [SupplierExecutivePosition],
		COALESCE(dbo.adfPropertyValueGetText([SupplierExecutiveEmployee].[Class], [SupplierExecutiveEmployee].[ID], '00000002-0000-0000-0000-000000000000'), 
			[SupplierExecutiveEmployee].[LastName] + ISNULL(' ' + [SupplierExecutiveEmployee].[FirstName], '') + ISNULL(' ' + [SupplierExecutiveEmployee].[MiddleName], ''), [SupplierExecutiveEmployee].[FileAs], '                            ') AS [SupplierExecutiveEmployee],
		dbo.adfPropertyValueGetText([CustomerExecutiveEmployee].[Class], [CustomerExecutiveEmployee].[ID], '00000003-0000-0000-0000-000000000000') AS [CustomerExecutiveEmployeeReason],
		dbo.adfPropertyValueGetText([SupplierExecutiveEmployee].[Class], [SupplierExecutiveEmployee].[ID], '00000003-0000-0000-0000-000000000000') AS [SupplierExecutiveEmployeeReason],
		CASE
			WHEN dbo.adfPropertyValueGetText([CustomerExecutiveEmployee].[Class], [CustomerExecutiveEmployee].[ID], '00000003-0000-0000-0000-000000000000') IS NULL THEN 0
			ELSE 1
		END AS [CustomerExecutiveEmployeeReasonFlag],
		CASE
			WHEN dbo.adfPropertyValueGetText([SupplierExecutiveEmployee].[Class], [SupplierExecutiveEmployee].[ID], '00000003-0000-0000-0000-000000000000') IS NULL THEN 0
			ELSE 1
		END AS [SupplierExecutiveEmployeeReasonFlag],
		
		ISNULL(dbo.adfPropertyValueGetText([CustomerCompany].[Class], 
				[CustomerCompany].[ID], 
				'00000001-0000-0000-0000-000000000000'),
				[CustomerCompany].[FileAs]) 
			AS [CustomerEnglName],
		
		ISNULL(dbo.adfPropertyValueGetText([CustomerExecutivePosition].[Class], 
				[CustomerExecutivePosition].[ID], 
				'00000003-0000-0000-0000-000000000000'),
				[CustomerExecutivePosition].[FileAs]) 
			AS [CustomerExecutiveEnglPositionCase],
			
		ISNULL(dbo.adfPropertyValueGetText([CustomerExecutiveEmployee].[Class], 
				[CustomerExecutiveEmployee].[ID], 
				'00000005-0000-0000-0000-000000000000'),
				[CustomerExecutiveEmployee].[FileAs]) 
			AS [CustomerExecutiveEnglName],
		
		ISNULL(dbo.adfPropertyValueGetText([SupplierCompany].[Class], 
				[SupplierCompany].[ID], 
				'00000005-0000-0000-0000-000000000000'),
				[CustomerExecutiveEmployee].[FileAs]) 
			AS [CustomerExecutiveEnglName]		
						
	FROM
		[Statement]
		INNER JOIN [Project]
			ON [Statement].[ProjectID] = [Project].[ID]
		LEFT OUTER JOIN [Company] AS [CustomerCompany]	
			ON [Statement].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Company] AS [SupplierCompany]	
			ON [Statement].[SupplierCompanyID] = [SupplierCompany].[ID]
		LEFT OUTER JOIN [Employee] AS [SupplierExecutiveEmployee]
			ON [SupplierCompany].[ExecutiveEmployeeID] = [SupplierExecutiveEmployee].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierExecutivePosition]
			ON [SupplierExecutiveEmployee].[PositionID] = [SupplierExecutivePosition].[ID]
		LEFT OUTER JOIN [Employee] AS [CustomerExecutiveEmployee]
			ON [CustomerCompany].[ExecutiveEmployeeID] = [CustomerExecutiveEmployee].[ID]
		LEFT OUTER JOIN [Position] AS [CustomerExecutivePosition]
			ON [CustomerExecutiveEmployee].[PositionID] = [CustomerExecutivePosition].[ID]
		LEFT OUTER JOIN [BusinessCard]
			ON [SupplierCompany].[ID] = [BusinessCard].[ID]	AND
			   [SupplierCompany].[Class] = [BusinessCard].[Class]
		LEFT OUTER JOIN [Address]
			ON [BusinessCard].[ID] = [Address].[BusinessCardID]	AND
			   [BusinessCard].[Class] = [Address].[BusinessCardClass] AND
			   [Address].[AddressTypeID] = 3   
		LEFT OUTER JOIN [Address] as [LegalAddress]
			ON [BusinessCard].[ID] = [LegalAddress].[BusinessCardID]	AND
			   [BusinessCard].[Class] = [LegalAddress].[BusinessCardClass] AND
			   [LegalAddress].[AddressTypeID] = 1 	   	
		
	WHERE 
		[Statement].[ID] = @ID		

	SELECT
		[Description],
		[Amount],
		[Price],
		[Sum],
		[VAT],
		[PriceWithVAT],
		[SumWithVAT],
		[UOM],
		[ServiceTypeName]
	FROM
		@t
	ORDER BY
		[ServiceTypeName] ASC,
		[Description] ASC
			
	DECLARE @author TName
	SELECT @author = [FileAs] FROM [Employee] WHERE [ID] = dbo.adfGetCurrentEmployeeID()
	
	SELECT
      [Statement].[FileAs] AS [Title],
      [Project].[FileAs] AS [Subject],
      @author AS [Author],
      [Employee].[FileAs] AS [Manager],
      [Company].[FileAs] AS [Company],
      dbo.fnPjm5GetCategoryList(@ID, @Class) AS [Category],
      @Code + [Project].[Number] AS [Keywords]
     FROM
		[Statement]
		INNER JOIN [Project]
			ON [Statement].[ProjectID] = [Project].[ID]
		INNER JOIN [Company]
			ON [Project].[SupplierCompanyID] = [Company].[ID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
     WHERE
		[Statement].[ID] = @ID

	SELECT
		[Property].[Name] as [Name],
		[PropertyValue].[Value] as [Value]
	FROM
		[Statement]
		LEFT OUTER JOIN [PropertyValue]
			ON 
			([PropertyValue].[DocumentID] = [Statement].[ID] AND
				[PropertyValue].[DocumentClass] = [Statement].[Class])
		LEFT OUTER JOIN [Property]
			ON ([PropertyValue].[PropertyID] = [Property].[ID] )
		WHERE
		[Statement].[ID] = @ID

	SELECT 
		[Property].[Name] as [Name],
		[PropertyValue].[Value] as [Value]
	FROM
		[Statement]
		INNER JOIN [Project]
			ON [Statement].[ProjectID] = [Project].[ID]
		LEFT OUTER JOIN [PropertyValue]
			ON 
			([PropertyValue].[DocumentID] = [Project].[ID] AND
				[PropertyValue].[DocumentClass] = [Project].[Class])
		LEFT OUTER JOIN [Property]
			ON ([PropertyValue].[PropertyID] = [Property].[ID] )
	WHERE
		[Statement].[ID] = @ID
		
	SELECT 
		[Property].[Name] as [Name],
		[PropertyValue].[Value] as [Value]
	FROM
		[Statement]
		INNER JOIN [Project]
			ON [Statement].[ProjectID] = [Project].[ID]
		INNER JOIN [Company]
			ON [Company].[ID] = [Project].[SupplierCompanyID]
		LEFT OUTER JOIN [PropertyValue]
			ON 
			([PropertyValue].[DocumentID] = [Company].[ID] AND
				[PropertyValue].[DocumentClass] = [Company].[Class])
		LEFT OUTER JOIN [Property]
			ON ([PropertyValue].[PropertyID] = [Property].[ID] )
			WHERE
		[Statement].[ID] = @ID

	SELECT 
		[Property].[Name] as [Name],
		[PropertyValue].[Value] as [Value]
	FROM
		[Statement]
		INNER JOIN [Project]
			ON [Statement].[ProjectID] = [Project].[ID]
		INNER JOIN [Company]
			ON [Company].[ID] = [Project].[CustomerCompanyID]
		LEFT OUTER JOIN [PropertyValue]
			ON 
			([PropertyValue].[DocumentID] = [Company].[ID] AND
				[PropertyValue].[DocumentClass] = [Company].[Class])
		LEFT OUTER JOIN [Property]
			ON ([PropertyValue].[PropertyID] = [Property].[ID] )
		WHERE
		[Statement].[ID] = @ID
		
RETURN 0
GO

GRANT EXEC ON ReportStatement TO PUBLIC

GO
