IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportBillOfProjectPeriod')
	BEGIN
		PRINT 'Dropping Procedure ReportBillOfProjectPeriod'
		DROP  Procedure  ReportBillOfProjectPeriod
	END

GO

PRINT 'Creating Procedure ReportBillOfProjectPeriod'
GO

/******************************************************************************
**		File: ReportEmployeeActivityResult.sql
**		Name: ReportEmployeeActivityResult
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		23.08.2013	BAO				    ,
**									..   
**									(@TypeSelector, @PeriodStart, @PeriodEnd)
**		23.08.2013	BAO				   (
**									  )
**		23.08.2013	BAO				      
**		23.08.2013	BAO				  
**		26.09.2014	BAO				   
*******************************************************************************/
CREATE Procedure ReportBillOfProjectPeriod
	@Date				TDatetime,
	@TypeSelector		int,
	@DateSelector		int,
	@PeriodStart		TDateTime,
	@PeriodEnd			TDateTime,
	@ProjectSelector	int,
	@ActiveProjectID	TIdentifier,
	@NotActiveProjectID TIdentifier
	
AS
	SET NOCOUNT ON
	
	IF @ProjectSelector = 0 AND @ActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	IF @ProjectSelector = 1 AND @NotActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	DECLARE 
		@ProjectID TIdentifier,
		@value1 TVariant,
		@value2 TVariant,
		@EmployeeExpenceCode varchar(256),
		@EmployeeExpenceName varchar(256)		
		
	SET @ProjectID = CASE @ProjectSelector
			WHEN 0 THEN @ActiveProjectID
			WHEN 1 THEN @NotActiveProjectID
			END	
	
	EXEC adfParameterGet 'EmployeeExpenceCode', 'Pjm5', @value1 OUTPUT  
	SET @EmployeeExpenceCode = CAST(@value1 AS varchar(256))
	EXEC adfParameterGet 'EmployeeExpenceName', 'Pjm5', @value2 OUTPUT  
	SET @EmployeeExpenceName = CAST(@value2 AS varchar(256))				
		
	EXECUTE ReportBillOfProjectPeriodHeader @ProjectID, @PeriodStart, @PeriodEnd, @DateSelector, @TypeSelector
	
	SELECT
		[ExpenseCode].[Code] AS [ExpenseGroupCode],
		[ExpenseCode].[FileAs] AS [ExpenseGroupName],
		[Expense].[FileAs] AS [ExpenseName],
		[Expense].[Amount],
		[Expense].[Billable] * [Expense].[TotalWithVATPC] AS [Sum]	
	FROM
		[ExpenseCode]
		INNER JOIN	[Expense]
			ON [Expense].[ExpenseCodeID] = [ExpenseCode].[ID]
		INNER JOIN [Project]
			ON [Expense].[ProjectID] = [Project].[ID]		
	WHERE
		[ExpenseCode].[State] = 1 AND		
		[Expense].[ProjectID] = @ProjectID AND
		([Expense].[Date] >= @PeriodStart AND [Expense].[Date] < @PeriodEnd) AND
		[Expense].[State] IN (2,3,6)
	UNION ALL
	SELECT
		' ',
		NULL,
		[Expense].[FileAs],
		[Expense].[Amount],
		[Expense].[Billable] * [Expense].[TotalWithVATPC] AS [Sum]			
	FROM
		[Expense]
		INNER JOIN [Project]
			ON [Expense].[ProjectID] = [Project].[ID]
	WHERE
		[Expense].[ProjectID] = @ProjectID AND
		[Expense].[ExpenseCodeID] IS NULL AND
		([Expense].[Date] >= @PeriodStart AND [Expense].[Date] < @PeriodEnd) AND
		[Expense].[State] IN (2,3,6)
	UNION ALL
	SELECT
		@EmployeeExpenceCode,
		@EmployeeExpenceName,
		[Employee].[FileAs],
		ISNULL(SUM([TimeEntry].[BillableDuration] / 60.00 * [TimeEntry].[Billable]),0),
		CASE 
			WHEN [Project].[RatesWithVAT] = 1 AND [Project].[ApplyVAT] = 1
			THEN ISNULL([TimeEntry].[Rate] / (1 + [TimeEntry].[VATRate]),0) * ISNULL(SUM([TimeEntry].[BillableDuration] / 60.00 * [TimeEntry].[Billable]),0)		
			ELSE ISNULL([TimeEntry].[Rate],0) * ISNULL(SUM([TimeEntry].[BillableDuration] / 60.00 * [TimeEntry].[Billable]),0)
		END
	FROM
		[Employee] INNER JOIN [vwTimeEntry] as [TimeEntry]
			ON ([TimeEntry].[EmployeeID] = [Employee].[ID])
		INNER JOIN [Project]
			ON [Project].[ID] = [TimeEntry].[ProjectID]
	WHERE
		[TimeEntry].[ProjectID] = @ProjectID AND
		([TimeEntry].[StartTime] >= @PeriodStart AND [TimeEntry].[StartTime] < @PeriodEnd) AND
		[TimeEntry].[State] IN (2,3,6)
	GROUP BY
		[Employee].[FileAs],
		[Project].[RatesWithVAT],
		[Project].[ApplyVAT],
		[TimeEntry].[Rate],
		[TimeEntry].[VATRate]
	
RETURN 0
GO

GRANT EXEC ON ReportBillOfProjectPeriod TO PUBLIC

GO
