IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportMRCT')
	BEGIN
		PRINT 'Dropping Procedure ReportMRCT'
		DROP  Procedure  ReportMRCT
	END

GO

PRINT 'Creating Procedure ReportMRCT'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/

CREATE Procedure ReportMRCT
	@CompanyID		TIdentifier,
	@DateSelector   int,
	@MonthStart	    Tdatetime,
	@EntrySelector  int
AS

	SET NOCOUNT ON
	SET DATEFIRST 1
	DECLARE 
		@Date		TDate,
		@NextDate	TDate
		
	IF @CompanyID IS NULL
	BEGIN
		RAISERROR('#CompanyIsNotSelected', 16, -1)
		RETURN 1
	END
				
		SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
		
		SET @MonthStart = CASE @DateSelector
			WHEN 0 THEN DATEADD(day, 1 - DATEPART(day, @Date), @Date)
			WHEN 1 THEN DATEADD(month, -1, DATEADD(day, 1 - DATEPART(day, @Date), @Date))
			ELSE CAST(CONVERT(varchar(8), @MonthStart, 112) AS datetime)
		END
		
		SET @NextDate = CASE @DateSelector
		WHEN 0 THEN DATEADD(day, 1, @Date)
		ELSE DATEADD(month, 1, @MonthStart)
		END		
		
	DECLARE
		@Name		varchar(256),
		@Logged		int,
		@NotLogged	nvarchar(max)
			
	DECLARE my_cursor CURSOR READ_ONLY FAST_FORWARD LOCAL FOR
		SELECT
			[Employee].[FileAs],
			COUNT([TimeEntry].[ID])
		FROM
			[Employee]
			LEFT OUTER JOIN	[TimeEntry]
				ON ([Employee].[ID] = [TimeEntry].[EmployeeID])AND
				   ([TimeEntry].[StartTime] >= @MonthStart AND [TimeEntry].[StartTime] < @NextDate)
		WHERE
			[Employee].[CompanyID] = @CompanyID AND
			[Employee].[State] = 1
		GROUP BY
			[Employee].[FileAs]	
			
	OPEN my_cursor
	FETCH NEXT FROM my_cursor INTO @Name, @Logged
	
	WHILE @@FETCH_STATUS = 0
	BEGIN
		IF @Logged <= 0
		BEGIN
			IF @NotLogged IS NULL
				SET @NotLogged = @Name
			ELSE
				SET @NotLogged = @NotLogged + ', ' + @Name
		END
		FETCH NEXT FROM my_cursor INTO @Name, @Logged
	END
	CLOSE my_cursor
	DEALLOCATE my_cursor	
		
	EXECUTE ReportMRCTHeader @CompanyID, @MonthStart, @NextDate, @NotLogged				
		
	SELECT
	[Employee].[FileAs] AS [Name],
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = DATEPART(WEEK,@MonthStart)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
			ELSE 0 END) AS [Total1],
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = DATEPART(WEEK,@MonthStart)
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
			ELSE 0 END) AS [Calculation1],
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = DATEPART(WEEK,@MonthStart)
				 THEN [TimeEntry].[Rate] * [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Sum1],		
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 1)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END ) AS [Total2],
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 1)
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Calculation2],
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 1)
				 THEN [TimeEntry].[Rate] * [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Sum2],			
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 2)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Total3],
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 2)
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Calculation3],
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 2)
				 THEN [TimeEntry].[Rate] * [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Sum3],			
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 3)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Total4],
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 3)
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Calculation4],
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 3)
				 THEN [TimeEntry].[Rate] * [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Sum4],			
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 4)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Total5],
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 4)
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Calculation5],
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 4)
				 THEN [TimeEntry].[Rate] * [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Sum5],			
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 5)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Total6],
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 5)
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Calculation6],
	SUM(CASE WHEN DATEPART(WEEK,[TimeEntry].[StartTime]) = (DATEPART(WEEK,@MonthStart) + 5)
				 THEN [TimeEntry].[Rate] * [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Sum6]			
		
	FROM
		[vwTimeEntry] as [TimeEntry]
		INNER JOIN [Employee]
			ON [Employee].[ID]	= [TimeEntry].[EmployeeID]
	WHERE
		([TimeEntry].[StartTime] >= @MonthStart AND [TimeEntry].[StartTime] < @NextDate) AND
		[Employee].[CompanyID] = @CompanyID AND
		((@EntrySelector = 1 AND [TimeEntry].[State]in(3,6)) OR (@EntrySelector = 2 AND [TimeEntry].[State] = 6) OR @EntrySelector = 0)
	GROUP BY
		[Employee].[FileAs]
	UNION
	SELECT NULL,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0			
			
			
RETURN 0
GO

GRANT EXEC ON ReportMRCT TO PUBLIC

GO
