IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportPaymentCard')
	BEGIN
		PRINT 'Dropping Procedure ReportPaymentCard'
		DROP  Procedure  ReportPaymentCard
	END

GO

PRINT 'Creating Procedure ReportPaymentCard'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportPaymentCard
	@ID TIdentifier
AS
	DECLARE
		@UserID			TIdentifier,
		@UserName		TName,
		@EmployeeID TIdentifier,
		@value TVariant,
		@NationalCurrency varchar(8),
		@x                 int
		
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @value OUTPUT	
	SET @NationalCurrency = CAST(@value AS varchar(8))
	
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()	
	SET @UserID = dbo.adfGetCurrentUserID()	
	
	IF (dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects')) != 1 AND 
	NOT EXISTS(SELECT * FROM [Project] 
			WHERE [Project].[ID] = @ID AND
			[State] IN (1, 2, 3, 4) AND
			[ProjectManagerEmployeeID] = @EmployeeID))
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END			
	
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID		
		

	DECLARE @table TABLE
	(
		[Date]		datetime,
		[Type]		varchar(8),
		[Number]	nvarchar(256),
		[Reason]	nvarchar(max),
		[Out]		money,
		[In]		money		
	)
	
	INSERT INTO @table
	(
		[Date],
		[Type],
		[Number],
		[Reason],
		[Out],
		[In]
	)	
	
	SELECT
		[Invoice].[Date],
		'',
		[Invoice].[Number],
		[Invoice].[Comments],
		[Invoice].[TotalWithVATPC] - 
			ISNULL((
			SELECT 
				SUM(i.[TotalWithVATPC])
			FROM
				[Invoice] i
				INNER JOIN [AdvanceInvoice]
					ON [AdvanceInvoice].[AdvanceInvoiceID] = i.[ID]
			WHERE
				[AdvanceInvoice].[InvoiceID] = [Invoice].[ID]
			), 0),
		NULL	
	FROM
		[Invoice]	
	WHERE
		[Invoice].[ProjectID] = @ID AND
		[Invoice].[State] IN (2,5)
		
	INSERT INTO @table
	(
		[Date],
		[Type],
		[Number],
		[Reason],
		[Out],
		[In]
	)	
	
	SELECT
		[Payment].[Date],
		CASE [Payment].[PaymentTypeID]
			WHEN 1 THEN ''
			WHEN 2 THEN ''
		END,
		[Payment].[Number],
		[Payment].[Reason],
		NULL,
		[PaymentDetail].[Value]			
	FROM
		[Payment]
		INNER JOIN [PaymentDetail]
			ON [Payment].[ID] = [PaymentDetail].[PaymentID]
		INNER JOIN [Invoice]
			ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]		
	WHERE
		[Invoice].[ProjectID] = @ID AND
		[Invoice].[State] IN (2,5)	AND
		[Payment].[State] IN (2,3)	
		
	INSERT INTO @table
	(
		[Date],
		[Type],
		[Number],
		[Reason],
		[Out],
		[In]
	)	
	
	SELECT
		[CreditMemo].[Date],
		'',
		[CreditMemo].[Number],
		[CreditMemo].[Comments],
		[CreditMemo].[TotalWithVATPC],
		NULL					
	FROM
		[CreditMemo]				
	WHERE
		[CreditMemo].[ProjectID] = @ID AND
		[CreditMemo].[State] = 2
		
	DECLARE @head TABLE([ContractNumber] varchar(256), [ContractDate] datetime, [FileAs] varchar(256), [UserName] varchar(256), [CurrencyCode] varchar(256))	
	INSERT INTO @head ([ContractNumber], [ContractDate], [FileAs], [UserName], [CurrencyCode])
	SELECT NULL, NULL, NULL, NULL, NULL
	
	UPDATE @head
	SET
	[ContractNumber] = [Project].[ContractNumber],
	[ContractDate] = [Project].[ContractDate],
	[FileAs] = [Company].[FileAs],
	[UserName] = @UserName,
	[CurrencyCode] = [Project].[CurrencyCode]	
	FROM
		[Project]
		INNER JOIN [Company]
			ON [Project].[CustomerCompanyID] = [Company].[ID]
	WHERE 
		[Project].[ID] = @ID
	
	 
	 SELECT @x = COUNT(ALL Number) FROM @table		
	 
	SELECT * FROM @head		
	
IF 	@x=0 
BEGIN
	SELECT * FROM @table
	UNION ALL
	SELECT NULL, NULL, NULL, NULL, 0, 0
	ORDER BY [Date]
END
ELSE 
SELECT * FROM @table
ORDER BY [Date]

RETURN 0
GO

GRANT EXEC ON ReportPaymentCard TO PUBLIC

GO
