IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportWRTM')
	BEGIN
		PRINT 'Dropping Procedure ReportWRTM'
		DROP  Procedure  ReportWRTM
	END

GO

PRINT 'Creating Procedure ReportWRTM'
GO
--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/

CREATE Procedure ReportWRTM
	@ProjectSelector INT,
	@ActiveProjectID TIdentifier,
	@NotActiveProjectID TIdentifier,
	@DateSelector   int,
	@WeekStart	    Tdatetime	
AS
	SET NOCOUNT ON
	SET DATEFIRST 1
	DECLARE 
		@Date		TDate,
		@NextDate	TDate,
		@ProjectID TIdentifier
		
	IF @ProjectSelector = 0 AND @ActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	IF @ProjectSelector = 1 AND @NotActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
		SET @ProjectID = CASE @ProjectSelector
			WHEN 0 THEN @ActiveProjectID
			WHEN 1 THEN @NotActiveProjectID
			END		
		
		SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
	
		SET @WeekStart = CASE @DateSelector
			WHEN 0 THEN DATEADD(day, 1 - DATEPART(weekday, @Date), @Date)
			WHEN 1 THEN DATEADD(week, -1, DATEADD(day, 1 - DATEPART(weekday, @Date), @Date))
			ELSE CAST(CONVERT(varchar(8), @WeekStart, 112) AS datetime)
		END
		
		SET @NextDate = CASE @DateSelector
		WHEN 0 THEN DATEADD(day, 1, @Date)
		ELSE DATEADD(week, 1, @WeekStart)
		END	
	
	DECLARE
		@Name		varchar(256),
		@Logged		int,
		@NotLogged	nvarchar(max)
			
	DECLARE my_cursor CURSOR READ_ONLY FAST_FORWARD LOCAL FOR
		SELECT
			[Employee].[FileAs],
			COUNT([TimeEntry].[ID])
		FROM 
			[Employee]
			LEFT OUTER JOIN	[TimeEntry]
				ON ([Employee].[ID] = [TimeEntry].[EmployeeID])AND
				   ([TimeEntry].[StartTime] >= @WeekStart AND [TimeEntry].[StartTime] < @NextDate) AND
				   [TimeEntry].[State] in (2,3,5,6)
		WHERE
			[TimeEntry].[ProjectID] = @ProjectID AND
			[Employee].[State] = 1
		GROUP BY
			[Employee].[FileAs]	
			
	OPEN my_cursor
	FETCH NEXT FROM my_cursor INTO @Name, @Logged
	
	WHILE @@FETCH_STATUS = 0
	BEGIN
		IF @Logged <= 0
		BEGIN
			IF @NotLogged IS NULL
				SET @NotLogged = @Name
			ELSE
				SET @NotLogged = @NotLogged + ', ' + @Name
		END
		FETCH NEXT FROM my_cursor INTO @Name, @Logged
	END
	CLOSE my_cursor
	DEALLOCATE my_cursor	
		
	EXECUTE ReportWRTMHeader @ProjectID, @WeekStart, @NotLogged	

	SELECT
	[Employee].[FileAs] AS [Name],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 1 AND [TimeEntry].[State] in (2,3,5,6)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Total1],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 1 AND [TimeEntry].[State] in (3,6)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Calculation1],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 1 AND [TimeEntry].[State] in (3,6)
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Sum1],
						
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 2 AND [TimeEntry].[State] in (2,3,5,6)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END ) AS [Total2],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 2 AND [TimeEntry].[State] in (3,6)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Calculation2],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 2 AND [TimeEntry].[State] in (3,6)
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Sum2],	
						
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 3 AND [TimeEntry].[State] in (2,3,5,6)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Total3],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 3 AND [TimeEntry].[State] in (3,6)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Calculation3],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 3 AND [TimeEntry].[State] in (3,6)
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Sum3],	
						
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 4 AND [TimeEntry].[State] in (2,3,5,6)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Total4],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 4 AND [TimeEntry].[State] in (3,6)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Calculation4],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 4 AND [TimeEntry].[State] in (3,6)
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Sum4],		
					
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 5 AND [TimeEntry].[State] in (2,3,5,6)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Total5],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 5 AND [TimeEntry].[State] in (3,6)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Calculation5],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 5 AND [TimeEntry].[State] in (3,6)
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Sum5],	
						
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 6 AND [TimeEntry].[State] in (2,3,5,6)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Total6],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 6 AND [TimeEntry].[State] in (3,6)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Calculation6],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 6 AND [TimeEntry].[State] in (3,6)
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Sum6],		
					
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 7 AND [TimeEntry].[State] in (2,3,5,6)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Total7],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 7 AND [TimeEntry].[State] in (3,6)
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END) AS [Calculation7],														
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 7 AND [TimeEntry].[State] in (3,6)
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Sum7]			
		
	FROM 
		[vwTimeEntry] as [TimeEntry]
		INNER JOIN [Employee]
			ON [Employee].[ID]	= [TimeEntry].[EmployeeID]	
	WHERE
		([TimeEntry].[StartTime] >= @WeekStart AND [TimeEntry].[StartTime] < @NextDate) AND
		[TimeEntry].[ProjectID] = @ProjectID AND
		[TimeEntry].[State] in (2,3,5,6)		
	GROUP BY
		[Employee].[FileAs]
	UNION
	SELECT NULL,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0	


RETURN 0
GO

GRANT EXEC ON ReportWRTM TO PUBLIC

GO
