IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'VistaWordCalculationExpense')
	BEGIN
		PRINT 'Dropping Procedure VistaWordCalculationExpense'
		DROP  Procedure  VistaWordCalculationExpense
	END

GO

PRINT 'Creating Procedure VistaWordCalculationExpense'
GO

CREATE Procedure VistaWordCalculationExpense
	@ID int,
	@Language TName = NULL
AS
	SET NOCOUNT ON
	
	DECLARE
		@calculationClass TClass,
		@DocumentCalculationClass TClass,
		@TotalLines	decimal(18,2),
		@Total money,
		@TotalLinesVAT money,
		@VATRate decimal(18,4),
		@VATRateCount int,
		@VATIsIncluded TBool,
		@Code TName,
		@ApplyVAT TBool,
		@RatesWithVAT TBool,
		@NationalCurrencyCode TCode3,
		@val TVariant

	
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @val OUTPUT	
	SET @NationalCurrencyCode = CAST(@val AS varchar(3))	

	SELECT
		@DocumentCalculationClass = [Calculation].[DocumentClass],
		@ApplyVAT = [Project].[ApplyVAT],
		@RatesWithVAT = [Project].[RatesWithVAT],
		@VATRate = [Calculation].[VATRate]
	FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Project].[ID] = [Calculation].[ProjectID]
	WHERE
		[Calculation].[ID] = @ID
		
	SET @VATIsIncluded = 0
	
	DECLARE @t TABLE(
		[DocumentID] TIdentifier,
		[DocumentClass] TClass,
		[ID] TIdentifier,
		[Date] TDate,
		[EmployeeID] TIdentifier,
		[EmployeeInitials] TCode,
		[Description] TNotes,
		[Price] Tmoney,
		[Amount] TAmount,
		[Total] Tmoney,
		[VAT] Tmoney,
		[ExpenseCode] TCode,
		[ExpenseCodeFileAs] TName,
		[ExpenseCodeComments] TNotes,
		[CurrencyRate] TMoney,
		[FromCurrencyCode] TName,
		[ToCurrencyCode] TName,
		[ExpenseVAT] Tmoney,
		[ExpenseTotal] Tmoney,
		[ExpenseTotalWithVAT] Tmoney
	)
	
		INSERT INTO @t
			([DocumentID],
			[DocumentClass],
			[ID], 
			[Date],
			[EmployeeID],
			[EmployeeInitials],
			[Description],
			[Price],
			[Amount],
			[Total],
			[VAT],
			[ExpenseCode],
			[ExpenseCodeFileAs],
			[ExpenseCodeComments],
			[CurrencyRate],
			[FromCurrencyCode],
			[ToCurrencyCode],
			[ExpenseVAT],
			[ExpenseTotal],
			[ExpenseTotalWithVAT])
		
		SELECT
			[CalculationLine].[DocumentID],
			[CalculationLine].[DocumentClass],
			[CalculationLine].[ID],
			[Expense].[Date],
			[Employee].[ID],
			[Employee].[Initials],
			[CalculationLine].[Description],
			CASE WHEN [Expense].[Amount] != 0
			THEN
				CASE 
					WHEN [Expense].[VATIsIncluded] = 1
						THEN ([Expense].[TotalPC] - [Expense].[VATPC]) / [Expense].[Amount]
					ELSE [Expense].[TotalPC]/[Expense].[Amount]
				END
			ELSE [Expense].[TotalPC]
			END,
			[Expense].[Amount],
			[Expense].[TotalPC],
			[Expense].[VATPC],
			[ExpenseCode].[Code],
			[ExpenseCode].[FileAs],
			[ExpenseCode].[Comments],
			[Expense].[CurrencyRate],
			[Expense].[FromCurrencyCode],
			[Expense].[ToCurrencyCode],
			[Expense].[VAT],
			CASE 
				WHEN [Expense].[VATIsIncluded] = 1
					THEN ([Expense].[Price] * [Expense].[Amount] - [Expense].[VAT])
				ELSE ([Expense].[Price] * [Expense].[Amount])
			END AS [ExpenseTotal],
			CASE 
				WHEN [Expense].[VATIsIncluded] = 1
					THEN ([Expense].[Price] * [Expense].[Amount])
				ELSE ([Expense].[Price] * [Expense].[Amount] + [Expense].[VAT])
			END AS [ExpenseTotalWithVAT] 
		FROM
			[CalculationLine]
			INNER JOIN [Expense]
				ON [Expense].[Class] = [CalculationLine].[DocumentClass] AND
					[Expense].[ID] = [CalculationLine].[DocumentID]
			INNER JOIN [Employee]	
				ON [Employee].[ID] = [Expense].[EmployeeID]
			LEFT OUTER JOIN [ExpenseCode]
				ON [ExpenseCode].[ID] = [Expense].[ExpenseCodeID]
		WHERE 
			[CalculationLine].[CalculationID] = @ID

		SELECT @Total = SUM(ROUND([Total], 2)) FROM @t				
		IF @RatesWithVAT = 0
		BEGIN
			SET @TotalLines = @Total
			SET @TotalLinesVAT = ROUND(@Total * @VATRate * @ApplyVAT, 2)
		END
		ELSE
		BEGIN
			SET @TotalLines = ROUND(@Total / (1 + @VATRate * @ApplyVAT), 2)
			SET @TotalLinesVAT = @Total - @TotalLines
		END
		
	DECLARE @AdvanceFlag TBool
	IF EXISTS(SELECT * FROM [CalculationAdvance] WHERE [CalculationID] = @ID)
		SET @AdvanceFlag = 1
	ELSE
		SET @AdvanceFlag = 0

	SELECT
		[Calculation].[ID],
		[Calculation].[Number],
		[Calculation].[Date],
		[Calculation].[FileAs],
		[Calculation].[PeriodStart],
		[Calculation].[PeriodEnd],

		[Calculation].[ProjectID],
		[Project].[FileAs] AS [ProjectFileAs],
		[Project].[Number] AS [ProjectNumber],
		[Project].[ContractNumber] AS [ContractNumber],
		[Project].[ContractDate] AS [ContractDate],
		[Project].[SupplierCompanyID],
		[Project].[CustomerCompanyID],
		
		[CustomerCompany].[LegalName] AS [CustomerCompanyLegalName],
		[SupplierCompany].[LegalName] AS [SupplierCompanyLegalName],
		
		[SupplierCompany].[ExecutiveEmployeeID],
		[SupplierEmployee].[LastName] + 
			ISNULL(' ' + [SupplierEmployee].[FirstName], '') + 
				ISNULL(' ' + [SupplierEmployee].[MiddleName], '') AS [ExecutiveName],
		[SupplierEmployee].[FileAs] AS [ExecutiveFileAs],
		[SupplierEmployeePosition].[ID] AS [ExecutivePositionID],
		[SupplierEmployeePosition].[FileAs] AS [ExecutivePositionFileAs],

		[Calculation].[TotalPC] AS [Total],
		[Calculation].[VATRate] * 100 AS [VATRate],
		[Calculation].[VATPC] AS [VAT],
		[Calculation].[TotalWithVATPC] AS [TotalWithVAT],
		CASE
			WHEN [Project].[ApplyVAT] = 1 THEN @VATIsIncluded
			ELSE 2		 
		END AS [VATFlag],

		@TotalLines AS [TotalLines],
		@TotalLinesVAT AS [TotalLinesVAT],
		@TotalLines + @TotalLinesVAT AS [TotalLinesWithVAT],
		@AdvanceFlag AS [AdvanceFlag],

		[Calculation].[TotalPC] - @TotalLines AS [TotalAdvance],
		[Calculation].[VATPC] - @TotalLinesVAT AS [TotalAdvanceVAT],
		[Calculation].[TotalWithVATPC] - @TotalLines - @TotalLinesVAT AS [TotalAdvanceWithVAT],
		
		[Currency].[ID] AS [CurrencyID],
		[Currency].[FileAs] AS [CurrencyFileAs],
		[Currency].[Code] AS [CurrencyCode],
		CASE 
			WHEN dbo.adfPropertyValueGetText([Currency].[Class], [Currency].[ID], '00000001-0000-0000-0000-000000000000') = 'False' 
				THEN 0
			ELSE 1 
		END AS [CurrencyMale],
		CASE WHEN @NationalCurrencyCode = [Calculation].[CurrencyCode]
			THEN 1 ELSE 0 END AS [CurrencyFlag]
	FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Calculation].[ProjectID] = [Project].[ID]
		INNER JOIN [Currency]
			ON [Project].[CurrencyCode] = [Currency].[Code]
		LEFT OUTER JOIN [Company] AS [CustomerCompany]	
			ON [Project].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Company] AS [SupplierCompany]	
			ON [Project].[SupplierCompanyID] = [SupplierCompany].[ID]
		LEFT OUTER JOIN [Employee] AS [SupplierEmployee]
			ON [SupplierCompany].[ExecutiveEmployeeID] = [SupplierEmployee].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierEmployeePosition]
			ON [SupplierEmployee].[PositionID] = [SupplierEmployeePosition].[ID]
	WHERE 
		[Calculation].[ID] = @ID	
	
	SELECT
		[ID], 
		[Date],
		[EmployeeID],
		[EmployeeInitials],
		[Description],
		[Price],
		[Amount],
		[Total],
		[VAT],
		[ExpenseCode],
		[DocumentID],
		[DocumentClass],
		[CurrencyRate],
		[FromCurrencyCode],
		[ToCurrencyCode],
		[ExpenseVAT],
		[ExpenseTotal],
		[ExpenseTotalWithVAT]
	FROM @t
	ORDER BY [Date]
	
	DECLARE @author TName
	SELECT @author = [FileAs] FROM [Employee] WHERE [ID] = dbo.adfGetCurrentEmployeeID()
	SELECT
      [Calculation].[FileAs] AS [Title],
      [Project].[FileAs] AS [Subject],
      @author AS [Author],
      [Employee].[FileAs] AS [Manager],
      [Company].[FileAs] AS [Company],
      dbo.fnPjm5GetCategoryList(@ID, @calculationClass) AS [Category],
      @Code + [Project].[Number] AS [Keywords]
     FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Calculation].[ProjectID] = [Project].[ID]
		INNER JOIN [Company]
			ON [Project].[SupplierCompanyID] = [Company].[ID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
     WHERE
		[Calculation].[ID] = @ID
		
	SELECT 
		[ExpenseCode],
		[ExpenseCodeFileAs],
		[ExpenseCodeComments]
	FROM @t
	GROUP BY [ExpenseCode],
			[ExpenseCodeFileAs],
			[ExpenseCodeComments]
	ORDER BY [ExpenseCode]
	
	RETURN 0
GO

GRANT EXEC ON VistaWordCalculationExpense TO PUBLIC
GO

