IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'VistaWordCalculationServiceRequest')
	BEGIN
		PRINT 'Dropping Procedure VistaWordCalculationServiceRequest'
		DROP  Procedure  VistaWordCalculationServiceRequest
	END

GO

PRINT 'Creating Procedure VistaWordCalculationServiceRequest'
GO

CREATE Procedure VistaWordCalculationServiceRequest
	@ID int,
	@Language TName = NULL
AS
	SET NOCOUNT ON
	
	DECLARE
		@calculationClass TClass,
		@DocumentCalculationClass TClass,
		@TotalLines	decimal(18,2),
		@Total money,
		@TotalLinesVAT money,
		@VATRate decimal(18,4),
		@VATRateCount int,
		@VATIsIncluded TBool,
		@Code TName,
		@ApplyVAT TBool,
		@RatesWithVAT TBool

		
	SELECT
		@DocumentCalculationClass = [Calculation].[DocumentClass],
		@ApplyVAT = [Project].[ApplyVAT],
		@RatesWithVAT = [Project].[RatesWithVAT],
		@VATRate = [Calculation].[VATRate]
	FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Project].[ID] = [Calculation].[ProjectID]
	WHERE
		[Calculation].[ID] = @ID
		
	SET @VATIsIncluded = 0
	
	DECLARE @t TABLE(
		[EmployeeInitials] TCode,
		[Date] TDate,		
		[ServiceCode] TCode,
		[Description] TNotes,
		[PriceListID] TIdentifier,
		[ServiceName] TNotes,
		[Price] Tmoney,
		[Amount] TAmount,
		[Total] Tmoney,
		[VAT] Tmoney,
		[ServiceNameOtherLang] TNotes 
	)
	
		INSERT INTO @t
			([EmployeeInitials], 
			[Date],			
			[ServiceCode],
			[Description],
			[PriceListID],
			[ServiceName],
			[Price],
			[Amount],
			[Total],
			[VAT],
			[ServiceNameOtherLang])
		SELECT
			[Employee].[Initials],
			[ServiceRequest].[DueDate],
			[Service].[Code],
			ISNULL([ServiceRequestLine].[Description], [ServiceRequest].[FileAs]),
			[ServiceAssignment].[ID],
			COALESCE(
				dbo.adfPropertyValueGetTextByName([ServiceAssignment].[Class], [ServiceAssignment].[ID], 
					'    '),
				dbo.adfPropertyValueGetTextByName([Service].[Class], [Service].[ID], 
					'    '),
				[Service].[FileAs]),
			CASE 
				WHEN [ServiceRequest].[VATIsIncluded] = 1 
					THEN [ServiceRequestLine].[Price]/(1+ @VatRate)
				ELSE 
			[ServiceRequestLine].[Price]
			END,
			[ServiceRequestLine].[FactAmount],
			CASE 
				WHEN [ServiceRequest].[VATIsIncluded] = 1 
					THEN [ServiceRequestLine].[FactAmount] * [ServiceRequestLine].[Price]/(1+ @VatRate)
				ELSE 
				[ServiceRequestLine].[FactAmount] * [ServiceRequestLine].[Price]			
			END,
			CASE 
				WHEN [ServiceRequest].[VATIsIncluded] = 1 
					THEN [ServiceRequestLine].[FactAmount] * [ServiceRequestLine].[Price]/(1+ @VatRate)
				ELSE 
				[ServiceRequestLine].[FactAmount] * [ServiceRequestLine].[Price]			
			END * @VatRate as [VAT],
			COALESCE(
			dbo.adfPropertyValueGetText([ServiceAssignment].[Class], [ServiceAssignment].[ID],
				'00000001-0000-0000-0000-000000000000'),
			 dbo.adfPropertyValueGetText([Service].[Class],[Service].[ID],
				'00000001-0000-0000-0000-000000000000'),[Service].[FileAs])						
		FROM
			[CalculationLine]
			INNER JOIN [ServiceRequest]
				ON [ServiceRequest].[Class] = [CalculationLine].[DocumentClass] AND
					[ServiceRequest].[ID] = [CalculationLine].[DocumentID]
			INNER JOIN [ServiceRequestLine]	
				ON [ServiceRequestLine].[ServiceRequestID] = [ServiceRequest].[ID]
			INNER JOIN [ServiceAssignment]
				ON [ServiceAssignment].[ID] = [ServiceRequestLine].[ServiceAssignmentID]
			INNER JOIN [Service]
				ON [Service].[ID] = [ServiceAssignment].[ServiceID]
			INNER JOIN [Employee]
				ON [Employee].[ID] = [ServiceRequest].[EmployeeID]
		WHERE 
			[CalculationLine].[CalculationID] = @ID

		SELECT @Total = SUM(ROUND([Total], 2)) FROM @t				
		IF @RatesWithVAT = 0
		BEGIN
			SET @TotalLines = @Total
			SET @TotalLinesVAT = ROUND(@Total * @VATRate * @ApplyVAT, 2)
		END
		ELSE
		BEGIN
			SET @TotalLines = ROUND(@Total / (1 + @VATRate * @ApplyVAT), 2)
			SET @TotalLinesVAT = @Total - @TotalLines
		END
		
	DECLARE @AdvanceFlag TBool
	IF EXISTS(SELECT * FROM [CalculationAdvance] WHERE [CalculationID] = @ID)
		SET @AdvanceFlag = 1
	ELSE
		SET @AdvanceFlag = 0
	
	SELECT
		[Calculation].[ID],
		[Calculation].[Number],
		[Calculation].[Date],
		[Calculation].[FileAs],
		[Calculation].[PeriodStart],
		[Calculation].[PeriodEnd],

		[Calculation].[ProjectID],
		[Project].[FileAs] AS [ProjectFileAs],
		[Project].[Number] AS [ProjectNumber],
		[Project].[ContractNumber] AS [ContractNumber],
		[Project].[ContractDate] AS [ContractDate],
		[Project].[SupplierCompanyID],
		[Project].[CustomerCompanyID],
		
		[CustomerCompany].[LegalName] AS [CustomerCompanyLegalName],
		[SupplierCompany].[LegalName] AS [SupplierCompanyLegalName],
		
		[SupplierCompany].[ExecutiveEmployeeID],
		[SupplierEmployee].[LastName] + 
			ISNULL(' ' + [SupplierEmployee].[FirstName], '') + 
				ISNULL(' ' + [SupplierEmployee].[MiddleName], '') AS [ExecutiveName],
		[SupplierEmployee].[FileAs] AS [ExecutiveFileAs],
		[SupplierEmployeePosition].[ID] AS [ExecutivePositionID],
		[SupplierEmployeePosition].[FileAs] AS [ExecutivePositionFileAs],

		[Calculation].[Total],
		[Calculation].[VATRate] * 100 AS [VATRate],
		[Calculation].[VAT],
		[Calculation].[TotalWithVAT],
		CASE
			WHEN [Project].[ApplyVAT] = 1 THEN @VATIsIncluded
			ELSE 2		 
		END AS [VATFlag],

		@TotalLines AS [TotalLines],
		@TotalLinesVAT AS [TotalLinesVAT],
		@TotalLines + @TotalLinesVAT AS [TotalLinesWithVAT],
		@AdvanceFlag AS [AdvanceFlag],

		[Calculation].[Total] - @TotalLines AS [TotalAdvance],
		[Calculation].[VAT] - @TotalLinesVAT AS [TotalAdvanceVAT],
		[Calculation].[TotalWithVAT] - @TotalLines - @TotalLinesVAT AS [TotalAdvanceWithVAT],
		
		[Currency].[ID] AS [CurrencyID],
		[Currency].[FileAs] AS [CurrencyFileAs],
		[Currency].[Code] AS [CurrencyCode],
		CASE 
			WHEN dbo.adfPropertyValueGetText([Currency].[Class], [Currency].[ID], '00000001-0000-0000-0000-000000000000') = 'False' 
				THEN 0
			ELSE 1 
		END AS [CurrencyMale]
	FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Calculation].[ProjectID] = [Project].[ID]
		INNER JOIN [Currency]
			ON [Calculation].[CurrencyCode] = [Currency].[Code]
		LEFT OUTER JOIN [Company] AS [CustomerCompany]	
			ON [Project].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Company] AS [SupplierCompany]	
			ON [Project].[SupplierCompanyID] = [SupplierCompany].[ID]
		LEFT OUTER JOIN [Employee] AS [SupplierEmployee]
			ON [SupplierCompany].[ExecutiveEmployeeID] = [SupplierEmployee].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierEmployeePosition]
			ON [SupplierEmployee].[PositionID] = [SupplierEmployeePosition].[ID]
	WHERE 
		[Calculation].[ID] = @ID	
	
	SELECT
		[ServiceCode], 
		[ServiceName],
		[Price],
		SUM([Amount]) AS [Amount],
		SUM([Total]) AS [Total],
		[PriceListID],
		[ServiceNameOtherLang]
	FROM @t
	GROUP BY [ServiceCode],
			[ServiceName],
			[PriceListID],
			[Price],
			[ServiceNameOtherLang]		

	SELECT
		[EmployeeInitials],
		[Date],
		[ServiceCode], 
		[Description],
		[Amount]		
	FROM @t
	ORDER BY [Date],
			[Description]
	
	DECLARE @author TName
	SELECT @author = [FileAs] FROM [Employee] WHERE [ID] = dbo.adfGetCurrentEmployeeID()
	SELECT
      [Calculation].[FileAs] AS [Title],
      [Project].[FileAs] AS [Subject],
      @author AS [Author],
      [Employee].[FileAs] AS [Manager],
      [Company].[FileAs] AS [Company],
      dbo.fnPjm5GetCategoryList(@ID, @calculationClass) AS [Category],
      @Code + [Project].[Number] AS [Keywords]
     FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Calculation].[ProjectID] = [Project].[ID]
		INNER JOIN [Company]
			ON [Project].[SupplierCompanyID] = [Company].[ID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
     WHERE
		[Calculation].[ID] = @ID
	
	RETURN 0
GO

GRANT EXEC ON VistaWordCalculationServiceRequest TO PUBLIC
GO
