IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TaskBrowseByProject]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5TaskBrowseByProject'
		DROP PROCEDURE [dbo].[pjm5TaskBrowseByProject]
	END
GO

PRINT 'Creating procedure pjm5TaskBrowseByProject'
GO

/******************************************************************************
**		File: pjm5TaskBrowseByProject.sql
**		Name: pjm5TaskBrowseByProject
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 13:49:21
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5TaskBrowseByProject]
	@StateSelector	INT,
	@DateSelector	INT,
	@ProjectID		TIdentifier,
	@Milestone		int = 0
AS
	SET NOCOUNT ON
	
	DECLARE @PeriodStart datetime,
			@PeriodEnd datetime,
			@today datetime,
			@ViewAllFinance TBool,
			@CurrentEmployeeID TIdentifier
		
	SET @today = GETDATE()
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
			
	IF @DateSelector = 1 -- today
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, @PeriodStart)
	
	IF @DateSelector = 2 -- next seven days
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodEnd = DATEADD(day, 7, @PeriodStart)
	;
	WITH [SubProject] ([ID], [ProjectID], [RealManHour], [RealBudget], [Duration]) AS
	(
		SELECT
			[Task].[ID],
			[Project].[ID],
			dbo.fnPjm6GetProjectManHour([Project].[ID]) / 60.0,
			dbo.fnPjm6GetProjectBudget([Project].[ID]),
			dbo.fnPjm5GetWorkingDays([Project].[Date], [ProjectDetail].[DueDate])
		FROM 
			[Project]
			INNER JOIN [ProjectDetail]
				ON [ProjectDetail].[ID] = [Project].[ID]
			INNER JOIN [Task]
				ON [Task].[SubprojectID] = [Project].[ID]
		WHERE
			ISNULL(@Milestone, 0) != 1 AND
			[Task].[ProjectID] = @ProjectID AND
			(
				(@StateSelector = 0) OR 
				(@StateSelector = 1 AND [Project].[State] IN (1, 2)) OR
				(@StateSelector = 2 AND [Project].[State] = 3) OR
				(@StateSelector = 3 AND [Project].[State] = 4) OR
				(@StateSelector = 4 AND [Project].[State] = 3)
			)
	),
	[SummaryTask] ([ID], [SubCount]) AS
	(
		SELECT
			[Parent].[ID],
			COUNT([Child].[ID]) 
		FROM 
			[Task] AS [Parent] 
			LEFT OUTER JOIN [Task] AS [Child] 
				ON [Child].[ParentID] = [Parent].[ID]
		WHERE
			[Parent].[ProjectID] = @ProjectID
		GROUP BY
			[Parent].[ID]
	)
	SELECT
		[Task].[Class],
		[Task].[ID],
		[Task].[State],
		[Task].[Flag],
		[Task].[FileAs],
		[Task].[ProjectID],
		[Task].[PriorityID],
		[Task].[ParentID],
		[Task].[StartDate],
		[Task].[DueDate],
		[Task].[EndDate],
		[Task].[Duration],
		[Task].[PercentComplete],
		[Task].[Milestone],
		dbo.fnPjm5GetWorkingDays(@today, [Task].[DueDate]) AS [RestDays],
		[Task].[PlanPercent],
		[Task].[ManHour] / 60.0 AS [ManHour],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
				THEN [Task].[Budget]
			ELSE -1
		END AS [Budget],
		[Task].[RealManHour],
		CASE
			WHEN [Task].[ManHour] != 0 THEN
				CAST([Task].[RealManHour] as decimal(18,2))/[Task].[ManHour]
			ELSE 0
		END AS [RealManHourPercent],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
				THEN [Task].[TimeRealBudget]+[Task].[ExpenseRealBudget]
			ELSE -1
		END AS [RealBudget],
		CASE
			WHEN [Task].[Budget] != 0 THEN
				CAST([Task].[TimeRealBudget]+[Task].[ExpenseRealBudget] as decimal(18,2))/[Task].[Budget]
			ELSE 0
		END AS [RealBudgetPercent],
		[Task].[Comments],
		[Task].[Created],
		[Task].[CreatedBy],
		[Task].[Modified],
		[Task].[ModifiedBy],
		[Task].[Timestamp],
		[Project].[FileAs],
		CAST(CASE
			WHEN [SummaryTask].[SubCount] > 0 THEN 2
			ELSE [Task].[Milestone]
		END as tinyint) as M,
		(CAST([Task].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[Class].[Guid],
		[SummaryTask].[SubCount],
		[TaskWbs].[TaskIndex],
		[TaskWbs].[Wbs],
		[TaskWbs].[TaskID]
	FROM
		[pjm5vwTask] AS [Task]
		INNER JOIN [TaskWbs]
			ON [TaskWbs].[TaskID] = [Task].[ID]
		INNER JOIN [Project]
			ON [Task].[ProjectID] = [Project].[ID]
		INNER JOIN [Priority]
			ON [Priority].[ID] = [Project].[PriorityID]
		INNER JOIN [Class]
			ON [Class].[Class] = [Task].[Class]
		INNER JOIN [SummaryTask]
			ON [SummaryTask].[ID] = [Task].[ID]
	WHERE
		[Task].[ProjectID] = @ProjectID AND 
		(
			(@StateSelector = 0) OR 
			(@StateSelector = 1 AND [Task].[State] IN (1, 2, 8)) OR
			(@StateSelector = 2 AND [Task].[State] IN (4, 5)) OR
			(@StateSelector = 3 AND [Task].[State] = 3) OR
			(@StateSelector = 4 AND [Task].[State] = 6)
		) AND
		(
			ISNULL(@Milestone, 0) != 1 OR [Task].[Milestone] = 1
		) AND [Task].[SubprojectID] IS NULL
	UNION ALL
	SELECT
		[Project].[Class],
		[Project].[ID],
		[Project].[State],
		[Project].[Flag],
		[Project].[FileAs],
		[Project].[ID],
		[Project].[PriorityID],
		[SubProject].[ProjectID],
		[Project].[Date],
		[ProjectDetail].[DueDate],
		[Project].[EndDate],
		[SubProject].[Duration],
		[ProjectDetail].[PercentComplete],
		0,--[Task].[Milestone],
		dbo.fnPjm5GetWorkingDays(@today, [ProjectDetail].[DueDate]) AS [RestDays],
		CASE
			WHEN [ProjectDetail].[DueDate] <= @today THEN 1
			WHEN [SubProject].[Duration] != 0 AND [Project].[Date] <= @today THEN
				1.0 - CAST((dbo.fnPjm5GetWorkingDays(@today, [ProjectDetail].[DueDate])-1) as decimal(18,2))/[SubProject].[Duration]
			ELSE 0
		END AS [PlanPercent],
		[ProjectDetail].[PlannedManHour] / 60.0 AS [ManHour],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
				THEN ISNULL([Project].[Budget], [ProjectDetail].[PlannedBudget])
			ELSE -1
		END AS [Budget],
		[SubProject].[RealManHour],
		CASE
			WHEN [ProjectDetail].[PlannedManHour] != 0 THEN
				CAST([SubProject].[RealManHour] as decimal(18,2))/[ProjectDetail].[PlannedManHour]
			ELSE 0
		END AS [RealManHourPercent],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
				THEN [SubProject].[RealBudget]
			ELSE -1
		END AS [RealBudget],
		CASE
			WHEN ISNULL([Project].[Budget], [ProjectDetail].[PlannedBudget]) != 0 THEN
				CAST([SubProject].[RealBudget] as decimal(18,2))/ISNULL([Project].[Budget], [ProjectDetail].[PlannedBudget])
			ELSE 0
		END AS [RealBudgetPercent],
		[Project].[Comments],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[Project].[FileAs] AS [Project],
		CAST(2 as tinyint) as M,
		(CAST([ProjectDetail].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[Class].[Guid],
		0 AS [SubCount],
		[TaskWbs].[TaskIndex],
		[TaskWbs].[Wbs],
		[TaskWbs].[TaskID]
	FROM 
		[SubProject]
		INNER JOIN [TaskWbs]
			ON [TaskWbs].[TaskID] = [SubProject].[ID]
		INNER JOIN [Project]
			ON [Project].[ID] = [SubProject].[ProjectID]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		INNER JOIN [Class]
			ON [Class].[Class] = [Project].[Class]
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm5TaskBrowseByProject] TO PUBLIC
GO
 