IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm6DeactivateTaskAssignments')
	BEGIN
		PRINT 'Dropping Procedure pjm6DeactivateTaskAssignments'
		DROP  Procedure  pjm6DeactivateTaskAssignments
	END

GO

PRINT 'Creating Procedure pjm6DeactivateTaskAssignments'
GO
/******************************************************************************
**		File: 
**		Name: pjm6DeactivateTaskAssignments
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    06.10.09		syv				  pjm6AssignmentCheckBudgetOverdraft
*******************************************************************************/
CREATE Procedure pjm6DeactivateTaskAssignments
	@AssignmentID TIdentifier,
	@TaskID TIdentifier = NULL
AS
	SET NOCOUNT ON

	DECLARE
		@rv int,
		@DeactivateDate TDateTime
	
	BEGIN TRANSACTION

	SET @DeactivateDate = DATEADD(day, 1, CAST(CONVERT(varchar(8), GETDATE(), 112) AS DateTime))
	DECLARE	@Tasks TABLE([ID] int)
	
	-- Task list to update
	;
	WITH [PreTasks] ([ID], [ActualWork]) AS
	(
		SELECT 
			[Task].[ID],
			SUM(ISNULL([BusyEntry].[ActualWork], 0) + ISNULL([BusyEntry].[ActualOvertimeWork], 0))
		FROM 
			[Task]
			LEFT OUTER JOIN [BusyEntry]
				ON [BusyEntry].[TaskID] = [Task].[ID]
				AND [BusyEntry].[AssignmentID] = @AssignmentID
		WHERE
			[Task].[State] IN (8,2) AND
			(@TaskID IS NULL OR [Task].[ID] = @TaskID)
		GROUP BY
			[Task].[ID]
	)
	INSERT INTO @Tasks 
	SELECT 
		[PreTasks].[ID]
	FROM 
		[PreTasks]
	WHERE
		[PreTasks].[ActualWork] > 0

	-- Delete BusyEntry later then @DeactivateDate
	DELETE 
		[BusyEntry]
	FROM
		[BusyEntry]
		INNER JOIN @Tasks as [Tasks]
			ON [Tasks].[ID] = [BusyEntry].[TaskID]
	WHERE 
		[BusyEntry].[AssignmentID] = @AssignmentID AND
		[BusyEntry].[Date] >= @DeactivateDate AND
		[BusyEntry].[ActualWork] = 0
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	-- Update to 0 planned in busyentry where actualwork
	UPDATE 
		[BusyEntry]
	SET
		[Planned] = 0
	FROM
		[BusyEntry]
		INNER JOIN @Tasks as [Tasks]
			ON [Tasks].[ID] = [BusyEntry].[TaskID]
	WHERE 
		[BusyEntry].[AssignmentID] = @AssignmentID AND
		[BusyEntry].[Date] >= @DeactivateDate AND
		[BusyEntry].[ActualWork] > 0
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	-- UPDATE TaskAssignments
	;
	WITH [TaskAssignmentWork] ([TaskID], [Work]) AS
	(
		SELECT
			[Tasks].[ID],
			SUM([BusyEntry].[Planned])
		FROM
			@Tasks as [Tasks]
			INNER JOIN [BusyEntry]
				ON [BusyEntry].[TaskID] = [Tasks].[ID]
				AND [BusyEntry].[AssignmentID] = @AssignmentID
		GROUP BY
			[Tasks].[ID]
	)
	UPDATE
		[TaskAssignment]
	SET
		[State] = 2,
		[Work] = [TaskAssignmentWork].[Work],
		[RemainingWork] = 0
	FROM
		[TaskAssignment]
		INNER JOIN [TaskAssignmentWork]
			ON [TaskAssignmentWork].[TaskID] = [TaskAssignment].[TaskID]
	WHERE
		[TaskAssignment].[AssignmentID] = @AssignmentID
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	-- DELETE TaskAssignments Without ActualWork AND timeEntry not like actual

	DELETE
		[TaskAssignment]
	FROM
		[TaskAssignment]
			INNER JOIN [Task]
				ON [Task].[ID] = [TaskAssignment].[TaskID]
				AND [Task].[State] IN (2,8)
	WHERE
		[TaskAssignment].[State] = 1 AND
		[TaskAssignment].[AssignmentID] = @AssignmentID AND
		(@TaskID IS NULL OR [TaskAssignment].[TaskID] = @TaskID)
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END		
	
		
	/*DELETE 
		[TimeEntry]
	FROM
		[TimeEntry]
			INNER JOIN [Task]
				ON [Task].[ID] = [TimeEntry].[TaskID]
				AND [Task].[State] IN (2,8)
	WHERE
		[TimeEntry].[State] NOT IN (2,3,6) AND
		[TimeEntry].[AssignmentID] = @AssignmentID AND
		(@TaskID IS NULL OR [TimeEntry].[TaskID] = @TaskID)
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END*/

-------------------------------

	DECLARE @DueDate TDateTime, @TaskClass TClass
	SET @TaskClass = dbo.adfGetClassByName('Pjm5.Task')
					
	;
	WITH [TaskUpdates] ([TaskID], [DueDate], [ManHour], [Budget]) AS
	(
		SELECT
			[Tasks].[ID],
			(SELECT ISNULL(MAX([Date]), [Task].[StartDate]) FROM [BusyEntry] WHERE [BusyEntry].[TaskID] = [Tasks].[ID]),
			SUM([TaskAssignment].[Work]),
			SUM([TaskAssignment].[Work] * [Assignment].[StandardRate]) / 60
		FROM
			@Tasks as [Tasks]
			INNER JOIN [Task]
				ON [Task].[ID] = [Tasks].[ID]
			INNER JOIN [TaskAssignment]
				ON [TaskAssignment].[TaskID] = [Tasks].[ID]
			INNER JOIN [Assignment]
				ON [Assignment].[ID] = [TaskAssignment].[AssignmentID]
		GROUP BY
			[Tasks].[ID],
			[Task].[StartDate]
	)
	UPDATE 
		[Task]
	SET
		[Task].[DueDate] = [TaskUpdates].[DueDate],
		[Task].[Duration] = dbo.fnPjm5GetWorkingDays([Task].[StartDate], [TaskUpdates].[DueDate]),
		[ManHour] = [TaskUpdates].[ManHour],
		[Budget] = [TaskUpdates].[Budget]
	FROM
		[Task]
		INNER JOIN [TaskUpdates]
			ON [TaskUpdates].[TaskID] = [Task].[ID]
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	-------------------------------

	IF EXISTS (
			SELECT
				*
			FROM
				[Reminder]
				INNER JOIN @Tasks as [Tasks]
					ON [DocumentID] = [Tasks].[ID]			
			WHERE 
				[DocumentClass] = @TaskClass AND
				[Subtype] = 'TD'
		)
	BEGIN
		UPDATE 
			[Reminder]
		SET 
			[EventTime] = [Task].[DueDate]
		FROM 
			[Reminder]
			INNER JOIN @Tasks as [Tasks]
				ON [Tasks].[ID] = [Reminder].[DocumentID]
			INNER JOIN [Task]
				ON [Task].[ID] = [Tasks].[ID]
		WHERE
			[DocumentClass] = @TaskClass AND
			[Subtype] = 'TD'
		IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END
	
	DECLARE @taskpcID TIdentifier
	DECLARE itemspc CURSOR LOCAL FAST_FORWARD FOR 
	SELECT 
		[ID] 
	FROM 
		@Tasks as [Tasks]
	OPEN itemspc
	FETCH NEXT FROM itemspc INTO @taskpcID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		EXEC @rv = pjm6TaskPercentUpdate @taskpcID

		--EXEC pjm6AssignmentCheckBudgetOverdraft @taskpcID, @AssignmentID, NULL
		FETCH NEXT FROM itemspc INTO @taskpcID
	END
	CLOSE itemspc
	DEALLOCATE itemspc

	COMMIT TRANSACTION

-----------------------------
	RETURN 0
GO

GRANT EXEC ON pjm6DeactivateTaskAssignments TO PUBLIC
GO