 IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5ContactActivityBrowse')
	BEGIN
		PRINT 'Dropping Procedure pjm5ContactActivityBrowse'
		DROP  Procedure  pjm5ContactActivityBrowse
	END

GO

PRINT 'Creating Procedure pjm5ContactActivityBrowse'
GO
/******************************************************************************
**		File: 
**		Name: pjm5ContactActivityBrowse
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**     ----------							-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		10.12.12	MAB				     
**		01.04.13	SOV				. -     
**		12.09.13	SOV				   -    
*******************************************************************************/
CREATE Procedure pjm5ContactActivityBrowse
	@Class TClass,
	@ID TIdentifier
AS
	SET NOCOUNT ON
	
	DECLARE @TimeEntryClass TClass, 
			@EmployeeClass TClass,
			@CompanyClass TClass,
			@CompanyID TIdentifier
			
	DECLARE
			@ViewAllFinance TBool,
			@BillableHoursStyle TBool,
			@ParameterValue sql_variant,
			@CurrentEmployeeID TIdentifier

	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()

	SELECT 
		@TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry'),
		@CompanyClass = dbo.adfGetClassByName('Adf.Company')

	EXEC dbo.[adfParameterGet] @Name='BillableHoursStyle', @Group='Pjm7', @Value=@ParameterValue OUTPUT
	SET @BillableHoursStyle = 
		CASE
			WHEN @ParameterValue IS NULL OR @ParameterValue = 0 THEN 0
			ELSE 1
		END

	IF @Class = @CompanyClass
	BEGIN
		SELECT DISTINCT
			[TimeEntry].[Class],
			[TimeEntry].[ID],
			[TimeEntry].[State],
			[TimeEntry].[Flag],
			[TimeEntry].[FileAs],
			[TimeEntry].[ActivityTypeID],
			[TimeEntry].[EmployeeID],
			[TimeEntry].[ProjectID],
			[TimeEntry].[TaskID],
			[TimeEntry].[StartTime],
			[TimeEntry].[Duration],
			[TimeEntry].[RoundedDuration],
			[TimeEntry].[Billable],
			CASE
				WHEN [Project].[ViewFinance] = 1 OR [Project].[ViewBillableHour]=1 OR
					(@BillableHoursStyle=1 AND [TimeEntry].[EmployeeID] = @CurrentEmployeeID)
				THEN [TimeEntry].[BillableDuration]
			ELSE -60 END AS BillableDuration,
			[TimeEntry].[Overtime],
			CASE
				WHEN [Project].[ViewFinance] != 1  THEN -1 
				ELSE [TimeEntry].[Rate]
			END AS [Rate],
			[TimeEntry].[CurrencyCode],
			[TimeEntry].[VATRate],
			CASE 
				WHEN [Project].[ViewFinance] = 0 THEN -1
				ELSE CAST([TimeEntry].[Billable] AS int) * [TimeEntry].[Rate] * [TimeEntry].[BillableHour]
			END AS [Sum],
			[TimeEntry].[Comments],
			[TimeEntry].[Created],
			[TimeEntry].[CreatedBy],
			[TimeEntry].[Modified],
			[TimeEntry].[ModifiedBy],
			[TimeEntry].[Timestamp],
			CASE
				WHEN [TimeEntry].[TaskID] IS NULL
					THEN (SELECT TOP(1) [DocumentClassName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
					ELSE (SELECT dbo.adfGetDocumentClassNameByTable('Task'))
			END AS [DocumentClassName],
			CASE
				WHEN [TimeEntry].[TaskID] IS NULL
					THEN (SELECT TOP(1) [DocumentName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
					ELSE (SELECT [Task].[FileAs] FROM [Task] WHERE [Task].[ID] = [TimeEntry].[TaskID])
			END AS [DocumentName]
		FROM
			[vwTimeEntry] as [TimeEntry]
			LEFT OUTER JOIN dbo.fnPjm6GetAvailableProjectsForTimeBrowse(0,NULL,NULL) AS [Project]
				ON [Project].[ID] = ISNULL([TimeEntry].[ProjectID], -1)
			LEFT OUTER JOIN [Project] AS [Proj]
				ON [Proj].[ID] = ISNULL([TimeEntry].[ProjectID], -1)
			INNER JOIN [DocumentContact]
				ON ([TimeEntry].[ID] = [DocumentContact].[DocumentID] AND 
					[DocumentContact].[DocumentClass] = @TimeEntryClass)
			INNER JOIN 
				(SELECT 
						@ID as [ID], 
						@Class as [Class]
				UNION ALL
				SELECT
					[ID],
					[Class]
				FROM
					[Employee]
				WHERE
					[Employee].[CompanyID] = @ID) as [Contact]
				ON ([DocumentContact].[BusinessCardClass] = [Contact].[Class] AND
					[DocumentContact].[BusinessCardID] = [Contact].[ID])
		WHERE 			
			[Project].[ID] IS NOT NULL 
			OR 
			[TimeEntry].[ProjectID] IS NULL
	END
	ELSE
	BEGIN
		SELECT
			[TimeEntry].[Class],
			[TimeEntry].[ID],
			[TimeEntry].[State],
			[TimeEntry].[Flag],
			[TimeEntry].[FileAs],
			[TimeEntry].[ActivityTypeID],
			[TimeEntry].[EmployeeID],
			[TimeEntry].[ProjectID],
			[TimeEntry].[TaskID],
			[TimeEntry].[StartTime],
			[TimeEntry].[Duration],
			[TimeEntry].[RoundedDuration],
			[TimeEntry].[Billable],
			CASE
				WHEN [Project].[ViewFinance] = 1 OR [Project].[ViewBillableHour]=1 OR
					(@BillableHoursStyle=1 AND [TimeEntry].[EmployeeID] = @CurrentEmployeeID)
				THEN [TimeEntry].[BillableDuration]
			ELSE -60 END AS BillableDuration,
			[TimeEntry].[Overtime],
			CASE
				WHEN [Project].[ViewFinance] != 1  THEN -1 
				ELSE [TimeEntry].[Rate]
			END AS [Rate],
			[TimeEntry].[CurrencyCode],
			[TimeEntry].[VATRate],
			CASE 
				WHEN [Project].[ViewFinance] = 0 THEN -1
				ELSE CAST([TimeEntry].[Billable] AS int) * [TimeEntry].[Rate] * [TimeEntry].[BillableHour]
			END AS [Sum],
			[TimeEntry].[Comments],
			[TimeEntry].[Created],
			[TimeEntry].[CreatedBy],
			[TimeEntry].[Modified],
			[TimeEntry].[ModifiedBy],
			[TimeEntry].[Timestamp],
			CASE
				WHEN [TimeEntry].[TaskID] IS NULL
					THEN (SELECT TOP(1) [DocumentClassName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
					ELSE (SELECT dbo.adfGetDocumentClassNameByTable('Task'))
			END AS [DocumentClassName],
			CASE
				WHEN [TimeEntry].[TaskID] IS NULL
					THEN (SELECT TOP(1) [DocumentName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
					ELSE (SELECT [Task].[FileAs] FROM [Task] WHERE [Task].[ID] = [TimeEntry].[TaskID])
			END AS [DocumentName]
			
		FROM
			[vwTimeEntry] as [TimeEntry]
			INNER JOIN [DocumentContact]
				ON ([TimeEntry].[ID] = [DocumentContact].[DocumentID] AND 
					[DocumentContact].[DocumentClass] = @TimeEntryClass)
			LEFT OUTER JOIN dbo.fnPjm6GetAvailableProjectsForTimeBrowse(0,NULL,NULL) AS [Project]
				ON [Project].[ID] = ISNULL([TimeEntry].[ProjectID], -1)
			LEFT OUTER JOIN [Project] AS [Proj]
				ON [Proj].[ID] = ISNULL([TimeEntry].[ProjectID], -1)
			LEFT OUTER JOIN [vwAssignment]
				ON [vwAssignment].[ProjectID] = [Project].[ID] AND
					[vwAssignment].[EmployeeID] = @CurrentEmployeeID AND
					[vwAssignment].[State] = 1
		WHERE
			[BusinessCardClass] = @Class AND [BusinessCardID] = @ID
			AND
			([Project].[ID] IS NOT NULL OR [TimeEntry].[ProjectID] IS NULL)
	END
	RETURN 0
GO

GRANT EXEC ON pjm5ContactActivityBrowse TO PUBLIC
GO
