﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6TimeEntryOwnAddedFromExchangeBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6TimeEntryOwnAddedFromExchangeBrowse'
		DROP PROCEDURE [dbo].[pjm6TimeEntryOwnAddedFromExchangeBrowse]
	END
GO

PRINT 'Creating procedure pjm6TimeEntryOwnAddedFromExchangeBrowse'
GO

/******************************************************************************
**		File: TimeEntryOwnAddedFromExchangeBrowse.sql
**		Name: pjm6TimeEntryOwnAddedFromExchangeBrowse
**		Desc: Процедура возвращает список импортированных ЗОВ из MS Exchange для
**				сотрудника (текущего)
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      @DateSelector:					-----------
**			0 - не важно
**			1 - вчера и сегодня
**			2 - последние 7 дней
**
**		Auth: anton.paramonov
**		Date: 05.03.2012 14:50:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
*******************************************************************************/
CREATE PROCEDURE [dbo].[pjm6TimeEntryOwnAddedFromExchangeBrowse]
	@DateSelector		int
AS

	SET NOCOUNT ON	

	DECLARE
		@CurrentEmployeeID	TIdentifier,
		@CurrentUserID		TIdentifier,
		@PeriodStart		TDate,
		@PeriodEnd			TDate,
		@Date				TDate


--	Установка значений параметров для выборки
	SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
	IF @DateSelector = 1 -- yesterday and today
		SELECT
			@PeriodEnd = GETDATE(),
			@PeriodStart = DATEADD(day, -1, @Date)
	IF @DateSelector = 2 -- last seven days
		SELECT
			@PeriodEnd = GETDATE(),
			@PeriodStart = DATEADD(day, -6, @Date)
			

	
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @CurrentUserID = dbo.adfGetCurrentUserID()
	

--	Выборка данных
	SELECT
		[TimeEntry].[Class],
		[TimeEntry].[ID],
		[TimeEntry].[State],
		[TimeEntry].[Flag],
		[TimeEntry].[FileAs],
		[TimeEntry].[EmployeeID],
		[TimeEntry].[StartTime],
		[TimeEntry].[Duration],
		[TimeEntry].[Color],
		[TimeEntry].[Comments],
		[TimeEntry].[Created],
		[TimeEntry].[CreatedBy],
		[TimeEntry].[Modified],
		[TimeEntry].[ModifiedBy],
		[TimeEntry].[Timestamp]
	FROM
		[ExchangeNewImportDocument]
		INNER JOIN [vwTimeEntry] as [TimeEntry]
			ON	[TimeEntry].[ID] = [ExchangeNewImportDocument].[DocumentID] AND
				[TimeEntry].[Class] = [ExchangeNewImportDocument].[DocumentClass] AND
				[ExchangeNewImportDocument].[UserID] = @CurrentUserID
	WHERE
		[TimeEntry].[EmployeeID] = @CurrentEmployeeID
		AND 
		(
			@DateSelector = 0 OR
			[ExchangeNewImportDocument].[Date] BETWEEN @PeriodStart AND @PeriodEnd
		)  
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm6TimeEntryOwnAddedFromExchangeBrowse] TO PUBLIC
GO
 
