IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'TimeEntryOwnBrowse')
	BEGIN
		PRINT 'Dropping Procedure TimeEntryOwnBrowse'
		DROP  Procedure  TimeEntryOwnBrowse
	END

GO

PRINT 'Creating Procedure TimeEntryOwnBrowse'
GO
/******************************************************************************
**		File: 
**		Name: TimeEntryOwnBrowse
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		09.09.13	SOV				    
**		11.09.13	SOV				  
*******************************************************************************/
CREATE Procedure TimeEntryOwnBrowse
	@ProjectSelector INT,
	@ActiveProjectID TIdentifier,
	@NotActiveProjectID TIdentifier,
	@StateSelector INT,
	@DateSelector INT,
	@PeriodStart TDate,
	@PeriodEnd TDate
AS
	SET NOCOUNT ON
	DECLARE
		@CurrentEmployeeID TIdentifier

	EXEC 
		pjm6TimeEntryBrowseParameters 
			@DateSelector, 
			@PeriodStart	OUTPUT,		
			@PeriodEnd		OUTPUT
			
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()

	DECLARE
		@ParameterValue sql_variant,
		@BillableHoursStyle int
				
	EXEC dbo.[adfParameterGet] @Name='BillableHoursStyle', @Group='Pjm7', @Value=@ParameterValue OUTPUT
	SET @BillableHoursStyle = 
		CASE
			WHEN @ParameterValue IS NULL OR @ParameterValue = 0 THEN 0
			ELSE 1
		END

	SELECT
		[TimeEntry].[Class],
		[TimeEntry].[ID],
		[TimeEntry].[State],
		[TimeEntry].[Flag],
		[TimeEntry].[FileAs],
		[TimeEntry].[ActivityTypeID],
		[TimeEntry].[EmployeeID],
		[AvailableProjects].[CustomerCompanyID],
		[TimeEntry].[ProjectID],
		[TimeEntry].[TaskID],
		[TimeEntry].[StartTime],
		[TimeEntry].[Duration],
		[TimeEntry].[RoundedDuration],
		[TimeEntry].[Billable],
		CASE
			WHEN [AvailableProjects].[ViewFinance] = 1 OR [AvailableProjects].[ViewBillableHour]=1 OR @BillableHoursStyle=1
			THEN [TimeEntry].[BillableDuration]
		ELSE -60 END AS BillableDuration,
		[TimeEntry].[Overtime],
		CASE
			WHEN [AvailableProjects].[ViewFinance] != 1  THEN -1 
			ELSE [TimeEntry].[Rate]
		END AS [Rate],
		[TimeEntry].[CurrencyCode],
		[TimeEntry].[VATRate],
		CASE 
			WHEN ([AvailableProjects].[ViewFinance] = 1)
			THEN 
				CAST([TimeEntry].[Billable] AS int) * [TimeEntry].[Rate] * [TimeEntry].[BillableHour]
			ELSE 
				-1 
		END AS [Sum],
		[TimeEntry].[Color],
		[TimeEntry].[Comments],
		[TimeEntry].[Created],
		[TimeEntry].[CreatedBy],
		[TimeEntry].[Modified],
		[TimeEntry].[ModifiedBy],
		[TimeEntry].[Timestamp],
		CASE
			WHEN [TimeEntry].[TaskID] IS NULL
				THEN (SELECT TOP(1) [DocumentClassName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
				ELSE (SELECT dbo.adfGetDocumentClassNameByTable('Task'))
		END AS [DocumentClassName],
		CASE
			WHEN [TimeEntry].[TaskID] IS NULL
				THEN (SELECT TOP(1) [DocumentName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
				ELSE (SELECT [Task].[FileAs] FROM [Task] WHERE [Task].[ID] = [TimeEntry].[TaskID])
		END AS [DocumentName]
	FROM
		[vwTimeEntry] as [TimeEntry]
		LEFT OUTER JOIN [Task]
			ON [TimeEntry].[TaskID] = [Task].[ID]
		LEFT OUTER JOIN 
		dbo.fnPjm6GetAvailableProjectsForTimeBrowse (
			@ProjectSelector,
			@ActiveProjectID,
			@NotActiveProjectID) as [AvailableProjects]
		ON [AvailableProjects].[ID] = ISNULL([TimeEntry].[ProjectID], -1)
	WHERE
		[TimeEntry].[EmployeeID] = @CurrentEmployeeID AND
		(
			@DateSelector = 0 OR
			[TimeEntry].[StartTime] BETWEEN @PeriodStart AND @PeriodEnd
		) AND
		(
			(@StateSelector = 0) OR										--  
			(@StateSelector = 1 AND [TimeEntry].[State] IN (1, 5)) OR	-- / 
			(@StateSelector = 2 AND [TimeEntry].[State] = 2) OR			-- .  
			(@StateSelector = 3 AND [TimeEntry].[State] = 3) OR			-- 
			(@StateSelector = 4 AND [TimeEntry].[State] = 6) OR			--   
			(@StateSelector = 5 AND [TimeEntry].[State] = 4)			-- 
		) AND
		(
			[AvailableProjects].[ID] IS NOT NULL OR
			[TimeEntry].[ProjectID] IS NULL AND @ProjectSelector = 0
		)
	
	RETURN 0
GO

GRANT EXEC ON TimeEntryOwnBrowse TO PUBLIC
GO
