IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TimeEntryUpdateInternal]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5TimeEntryUpdateInternal'
		DROP PROCEDURE [dbo].[pjm5TimeEntryUpdateInternal]
	END
GO

PRINT 'Creating procedure pjm5TimeEntryUpdateInternal'
GO

/******************************************************************************
**		File: pjm5TimeEntryUpdateInternal.sql
**		Name: pjm5TimeEntryUpdateInternal
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: pavel.boruroev
**		Date: 01/20/2005 16:11:01 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		06.10.09	syv				   pjm6AssignmentCheckBudgetOverdraft
**		26.01.10	syv				    
**									Assignment,     
**		22.10.10	SYV				 ,     
**		01.12.10	SYV				 Rate    1
**		19.01.10	SPV				  Rate   , , , 
**		12.07.11	SYV				   
**		29.12.12	SOV				         
**		31.01.12	SAP				    BillableHour
**		18.03.13	SAP				   AmountBeforeFinanceDocumentInsert 
**									 EntryAmount
**		05.02.13	SAP				    ,     ,
**									        	
*******************************************************************************/
CREATE PROCEDURE pjm5TimeEntryUpdateInternal
	@ID TIdentifier,
	@FileAs TName,
	@ActivityTypeID TIdentifier,
	@EmployeeID TIdentifier,
	@ProjectID TIdentifier,
	@DocumentClass TClass,
	@DocumentID TIdentifier,
	@TaskID TIdentifier,
	@StartTime TDateTime,
	@Duration TCount,
	@Billable TBool,
	
	@BillableHour decimal(18,4),
	
	@Overtime TBool,
	@CurrencyCode TCode3,
	@VATRate TPercent,
	@Color TColor,
	@Comments TNotes,
	@PrevEmployeeID TIdentifier
AS
	SET NOCOUNT ON
	DECLARE 
		@RoundedDuration TCount,
		@ProjectState TState,
		@Rate TMoney,
		@var TVariant,
		@ActivityTypeIsMandatory bit,
		@CurrentEmployeeID TIdentifier,
		@State TState,
		@rv int,
		@result TBool,
		@OldDuration TCount,
		@OldTaskID TIdentifier,
		@OldAssignmentID TIdentifier,
		@OldProjectID TIdentifier,
		@OldSuperTimerID TIdentifier,
		@IsAssignmentDeactivate TBool,
		@ServiceAssignment TClass
		
	SELECT @State = [State] FROM [TimeEntry] WHERE [ID] = @ID
	IF @State NOT IN (1, 5) AND @ProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotDefined', 18, -1)
		RETURN 1
	END
	
	SET @ServiceAssignment = dbo.adfGetClassByName('Pjm5.ServiceAssignment')

	SELECT 
		@OldDuration = [Duration],
		@OldTaskID = [TaskID],
		@OldAssignmentID = [AssignmentID],
		@OldProjectID = [ProjectID],
		@OldSuperTimerID = [SuperTimerID],
		@Rate = [Rate]
	FROM
		[TimeEntry]
	WHERE
		[ID]=@ID
	
	--          , 
	--      ,   
	--  
	IF @ProjectID <> @OldProjectID AND @OldSuperTimerID IS NOT NULL
	BEGIN
		UPDATE [TimeEntry]
		SET [SuperTimerID] = NULL
		WHERE [ID] = @ID
	END	
	
	SET @IsAssignmentDeactivate = 0
	
	DECLARE @AssignmentID TIdentifier	

	IF(@OldTaskID IS NULL AND @TaskID IS NULL
				AND 
				EXISTS (SELECT 
							* 
						FROM 
							[Assignment]
							INNER JOIN [TimeEntry]
								ON [Assignment].[ID] = [TimeEntry].[AssignmentID]	
						WHERE
							[TimeEntry].[ID] = @ID
							AND [TimeEntry].[Created] <= [Assignment].[Modified]
							AND [TimeEntry].[ProjectID] = @ProjectID
							AND [Assignment].[State] = 2
						)
				)
	BEGIN
		SET @IsAssignmentDeactivate = 1
	END
	
	IF @ProjectID IS NOT NULL
	BEGIN
		IF (@PrevEmployeeID = @EmployeeID)
		BEGIN
			IF(dbo.fnPjm5AllowCreateProjectEntry(@ProjectID, @EmployeeID) = 0
				AND @IsAssignmentDeactivate = 0)
			BEGIN
				RAISERROR('#accessdenied', 18, -1)
				RETURN 1
			END
		END
		ELSE IF (dbo.fnPjm5AllowCreateProjectEntry(@ProjectID, @PrevEmployeeID) = 0
			OR dbo.fnPjm5AllowCreateProjectEntry(@ProjectID, @EmployeeID) = 0)
			AND @IsAssignmentDeactivate = 0
		BEGIN
			RAISERROR('#accessdenied', 18, -1)
			RETURN 1
		END

		IF @IsAssignmentDeactivate = 0
		BEGIN
			SELECT @AssignmentID = [ID] FROM vwAssignment WHERE [ProjectID] = @ProjectID AND [EmployeeID] = @EmployeeID AND [State]=1
		END
		ELSE
		BEGIN
			SET @AssignmentID = @OldAssignmentID
		END
		
		IF @AssignmentID IS NULL
		BEGIN
			RAISERROR('#assignmentnotfound', 18, -1)
			RETURN 1
		END
	END
	
	IF @Duration IS NULL OR @Duration < 0 OR @StartTime IS NULL
	BEGIN
		RAISERROR('#DurationIsInvalid', 18, -1)
		RETURN 1
	END

	IF @ActivityTypeID IS NULL
	BEGIN
		EXEC adfParameterGet 'ActivityTypeIsMandatory', 'Pjm5', @var OUTPUT
		IF (@var IS NULL OR CAST(@var as BIT) = 1) AND @State NOT IN (1, 5)
		BEGIN
			RAISERROR('#activitytypecannotbenull', 18, -1)
			RETURN 1
		END
	END

	IF @ProjectID IS NOT NULL
	BEGIN
		SELECT
			@ProjectState = [State],
			@CurrencyCode = [CurrencyCode],
			@RoundedDuration = dbo.fnPjm5RoundedDuration(@Duration, [RoundingInterval], [RoundingMode])
		FROM
			[Project]
		WHERE
			[ID] = @ProjectID
		IF @ProjectState != 2
		BEGIN
			RAISERROR('#ProjectIsNotActive', 18, -1)
			RETURN 1
		END
		IF @TaskID IS NOT NULL AND NOT EXISTS (SELECT * FROM [Task] WHERE [ID] = @TaskID AND [State] = 2)
		BEGIN
			RAISERROR('#TaskIsDraft', 18, -1)
			RETURN 1
		END
		
		-- if draft state or changed one of the next fields: Overtime, EmployeeID, ProjectID, DocumentID (for ServiceAssignment DocumentClass)
		IF @State = 1 OR EXISTS(
			SELECT * FROM [TimeEntry]
			WHERE [ID] = @ID AND
			 ([EmployeeID] <> @EmployeeID OR [ProjectID] <> @ProjectID OR [OverTime] <> @Overtime OR
				ISNULL([DocumentID], 0) <> ISNULL(@DocumentID, 0) AND ISNULL([DocumentClass], 0) = ISNULL(@DocumentClass, 0) AND ISNULL([DocumentClass], 0) = @ServiceAssignment OR
				ISNULL([DocumentClass], 0) <> ISNULL(@DocumentClass, 0) AND @ServiceAssignment IN (@DocumentClass, [DocumentClass])
			)
		)
		BEGIN
			SET @Rate = dbo.fnPjm5GetEmployeeRate(@EmployeeID, @ProjectID, @Overtime, CASE @DocumentClass WHEN dbo.adfGetClassByName('Pjm5.ServiceAssignment') THEN @DocumentID ELSE NULL END, 1)
		END
	END
	ELSE
	BEGIN
		DECLARE @RoundInterval int, @RoundingMode int
		EXEC adfParameterGet @Name='RoundInterval', @Group='Pjm5', @Value = @var OUTPUT
		SET @RoundInterval = CAST(@var as int)
		EXEC adfParameterGet @Name='RoundingMode', @Group='Pjm5', @Value = @var OUTPUT
		SET @RoundingMode = CAST(@var as int)

		EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @var OUTPUT	
		SET @CurrencyCode = CAST(@var AS varchar(3))

		SET @RoundedDuration = dbo.fnPjm5RoundedDuration(@Duration, @RoundInterval, @RoundingMode)
		SET @Rate = 0
		SET @TaskID = NULL
	END

	IF @State = 2 
		AND 
		(
			ISNULL(@OldTaskID, 0) != ISNULL(@TaskID, 0)
			OR
			(@OldTaskID IS NULL AND @TaskID IS NOT NULL)
			OR 
			ISNULL(@OldDuration, 0) != ISNULL(@Duration, 0)
			OR
			(@OldDuration IS NULL AND @Duration IS NOT NULL)
			OR
			ISNULL(@OldAssignmentID, 0) != ISNULL(@AssignmentID, 0)
			OR
			(@OldAssignmentID IS NULL AND @AssignmentID IS NOT NULL)
		)
		AND 
		@TaskID IS NOT NULL
			EXEC @result = pjm6AssignmentCheckBudgetOverdraft @TaskID, @AssignmentID, @ID, @Duration
	IF @result = 1
		RETURN 1
	
	IF @DocumentID IS NULL SET @DocumentClass = NULL

	IF (@DocumentID IS NOT NULL 
		AND @DocumentClass IS NOT NULL
		AND NOT EXISTS(SELECT TOP(1) [ID] FROM [Document] WHERE [Class] = @DocumentClass AND [ID] = @DocumentID))
	BEGIN
		RAISERROR('#CannotRetrieveDeletedDocument', 18, -1)
		RETURN 1
	END

	UPDATE [TimeEntry]
	SET
		[TimeEntry].[FileAs] = @FileAs,
		[TimeEntry].[ActivityTypeID] = @ActivityTypeID,
		[TimeEntry].[EmployeeID] = @EmployeeID,
		[TimeEntry].[AssignmentID] = @AssignmentID,
		[TimeEntry].[ProjectID] = @ProjectID,
		[TimeEntry].[DocumentClass] = @DocumentClass,
		[TimeEntry].[DocumentID] = @DocumentID,
		[TimeEntry].[TaskID] = @TaskID,
		[TimeEntry].[StartTime] = @StartTime,
		[TimeEntry].[Duration] = @Duration,
		[TimeEntry].[RoundedDuration] = @RoundedDuration,
		[TimeEntry].[Billable] = @Billable,		
		[TimeEntry].[Overtime] = @Overtime,
		[TimeEntry].[Rate] = @Rate,
		[TimeEntry].[CurrencyCode] = @CurrencyCode,
		[TimeEntry].[VATRate] = @VATRate,
		[TimeEntry].[Color] = @Color,
		[TimeEntry].[Comments] = @Comments,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	WHERE
		[TimeEntry].[ID] = @ID
	
	--  " "
	UPDATE [EntryAmount]
	SET [Amount] = ISNULL(@BillableHour, 0),
		[AmountBeforeFinanceDocumentInsert] = ISNULL(@BillableHour, 0)
	WHERE [ID] = @ID
			
	IF @@ERROR != 0
	BEGIN
		RETURN 1
	END


	RETURN 0
GO

GRANT EXECUTE ON pjm5TimeEntryUpdateInternal TO PUBLIC
GO
  