 IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm6trTimeEntryUpdateForBusyEntry')
	BEGIN
		PRINT 'Dropping Trigger pjm6trTimeEntryUpdateForBusyEntry'
		DROP  Trigger pjm6trTimeEntryUpdateForBusyEntry
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm6trTimeEntryUpdateForBusyEntry
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm6trTimeEntryUpdateForBusyEntry'
GO
CREATE TRIGGER pjm6trTimeEntryUpdateForBusyEntry 
ON [TimeEntry] FOR UPDATE, INSERT, DELETE
AS
BEGIN
    IF @@rowcount = 0
       RETURN
   SET NOCOUNT ON

	DECLARE @forSubtract TABLE
	([TaskID] TIdentifier,
 	 [AssignmentID] TIdentifier,
	 [Date] TDate,
	 [Duration] TCount,
	 [OvertimeDuration] TCount)

	 DECLARE @forAdd TABLE
	([TaskID] TIdentifier,
	[AssignmentID] TIdentifier,
	[ProjectID] TIdentifier,
	[EmployeeID] TIdentifier,
	[Date] TDate,
	[Duration] TCount,
	[OvertimeDuration] TCount)

	INSERT INTO @forSubtract
	([TaskID], [AssignmentID], [Date], [Duration], [OvertimeDuration])
	SELECT
		[deleted].[TaskID],
		[deleted].[AssignmentID],
		CAST(CONVERT(varchar(8), [deleted].[StartTime], 112) AS datetime),
		SUM(CASE WHEN [deleted].[Overtime] = 1 AND [Task].[MsTaskID] IS NOT NULL 
			THEN 0 ELSE [deleted].[Duration] END),
		SUM(CASE WHEN [deleted].[Overtime] = 1 AND [Task].[MsTaskID] IS NOT NULL 
			THEN [deleted].[Duration] ELSE 0 END)
	FROM
		[deleted]
		INNER JOIN [Task]
			ON [Task].[ID] = [deleted].[TaskID]
	WHERE
		[deleted].[State] IN (2,3,6)
	GROUP BY
		[deleted].[TaskID],
		[deleted].[AssignmentID],
		CAST(CONVERT(varchar(8), [deleted].[StartTime], 112) AS datetime),
		[deleted].[Overtime]
	
	;WITH [Subtract]([TaskID], [AssignmentID], [Duration], [OvertimeDuration]) as
	(
		SELECT
			[TaskID],
			[AssignmentID],
			SUM([Subtract].[Duration]),
			SUM([Subtract].[OvertimeDuration])
		FROM
			@forSubtract AS [Subtract]
		GROUP BY
			[TaskID],
			[AssignmentID]
	)	
	UPDATE 
		[TaskAssignment]
	SET
		[TaskAssignment].[RemainingWork] = [TaskAssignment].[RemainingWork] + [Subtract].[Duration],
		[TaskAssignment].[RemainingOvertimeWork] = [TaskAssignment].[RemainingOvertimeWork] + [Subtract].[OvertimeDuration]
	FROM
		[TaskAssignment]
			INNER JOIN [Subtract] 
				ON	[TaskAssignment].[TaskID] = [Subtract].[TaskID] AND
					[TaskAssignment].[AssignmentID] = [Subtract].[AssignmentID]

	IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN
		END
		
	UPDATE 
		[BusyEntry]
	SET
		[BusyEntry].[ActualWork] = 
			CASE WHEN [BusyEntry].[ActualWork] - [Subtract].[Duration] < 0 
			THEN 0 ELSE [BusyEntry].[ActualWork] - [Subtract].[Duration] END,
		[BusyEntry].[ActualOvertimeWork] = 
			CASE WHEN [BusyEntry].[ActualOvertimeWork] - [Subtract].[OvertimeDuration] < 0 
			THEN 0 ELSE [BusyEntry].[ActualOvertimeWork] - [Subtract].[OvertimeDuration] END
	FROM
		[BusyEntry]
			INNER JOIN @forSubtract AS [Subtract]
				ON [BusyEntry].[Date] = [Subtract].[Date] AND
				[BusyEntry].[TaskID] = [Subtract].[TaskID] AND
				[BusyEntry].[AssignmentID] = [Subtract].[AssignmentID]
	IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN
		END
		

	
	INSERT INTO @forAdd
	([TaskID], [AssignmentID], [ProjectID], [EmployeeID], [Date], [Duration], [OvertimeDuration])
	SELECT
		[inserted].[TaskID],
		[inserted].[AssignmentID],
		[inserted].[ProjectID],
		[inserted].[EmployeeID],
		CAST(CONVERT(varchar(8), [inserted].[StartTime], 112) AS datetime),
		SUM(CASE WHEN [inserted].[Overtime] = 1 AND [Task].[MsTaskID] IS NOT NULL 
			THEN 0 ELSE [inserted].[Duration] END),
		SUM(CASE WHEN [inserted].[Overtime] = 1 AND [Task].[MsTaskID] IS NOT NULL 
			THEN [inserted].[Duration] ELSE 0 END)
	FROM
		[inserted]
		INNER JOIN [Task]
			ON [Task].[ID] = [inserted].[TaskID]
	WHERE
		[inserted].[State] IN (2,3,6)
	GROUP BY
		[inserted].[TaskID],
		[inserted].[AssignmentID],
		[inserted].[ProjectID],
		[inserted].[EmployeeID],
		CAST(CONVERT(varchar(8), [inserted].[StartTime], 112) AS datetime),
		[inserted].[Overtime]
		
	IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN
		END
	
	UPDATE 
		[BusyEntry]
	SET
		[BusyEntry].[ActualWork] = [BusyEntry].[ActualWork] + [Add].[Duration],
		[BusyEntry].[ActualOvertimeWork] = [BusyEntry].[ActualOvertimeWork] + [Add].[OvertimeDuration] 
	FROM
		[BusyEntry]
			INNER JOIN @forAdd AS [Add]
				ON [Add].[Date] = [BusyEntry].[Date] AND
				[BusyEntry].[TaskID] = [Add].[TaskID] AND
				[BusyEntry].[AssignmentID] = [Add].[AssignmentID]
	IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN
		END

	;WITH [Add]([TaskID], [AssignmentID], [Duration], [OvertimeDuration]) as
	(
		SELECT
			[TaskID],
			[AssignmentID],
			SUM([Add].[Duration]),
			SUM([Add].[OvertimeDuration])
		FROM
			@forAdd AS [Add]
		GROUP BY
			[TaskID],
			[AssignmentID]
	)
	UPDATE 
		[TaskAssignment]
	SET
		[TaskAssignment].[RemainingWork] = 
			CASE WHEN [TaskAssignment].[RemainingWork] - [Add].[Duration] < 0 
			THEN 0 ELSE [TaskAssignment].[RemainingWork] - [Add].[Duration] END,
		[TaskAssignment].[RemainingOvertimeWork] = 
			CASE WHEN [TaskAssignment].[RemainingOvertimeWork] - [Add].[OvertimeDuration] < 0 
			THEN 0 ELSE [TaskAssignment].[RemainingOvertimeWork] - [Add].[OvertimeDuration] END
	FROM
		[TaskAssignment]
			INNER JOIN [Add] 
				ON	[TaskAssignment].[TaskID] = [Add].[TaskID] AND
					[TaskAssignment].[AssignmentID] = [Add].[AssignmentID]
	IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN
		END	

	DELETE
		[Add]
	FROM
		@forAdd AS [Add]
			INNER JOIN [BusyEntry]
				ON [BusyEntry].[Date] = [Add].[Date]
	WHERE
		[BusyEntry].[ProjectID] = [Add].[ProjectID] AND
		[BusyEntry].[TaskID] = [Add].[TaskID] AND
		[BusyEntry].[AssignmentID] = [Add].[AssignmentID] AND
		[BusyEntry].[EmployeeID] = [Add].[EmployeeID] 
	
	INSERT INTO [BusyEntry]
	([ProjectID],[TaskID],[AssignmentID],[Date],[EmployeeID],[Planned],[Canceled],[Committed], [ActualWork],[ActualOvertimeWork])
	SELECT
		[Add].[ProjectID],
		[Add].[TaskID],
		[Add].[AssignmentID],
		[Add].[Date],
		[Add].[EmployeeID],
		0,0,0,
		[Add].[Duration],
		[Add].[OvertimeDuration]
		FROM
			@forAdd AS [Add]
			
	IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN
		END
END
GO
